from PySide6.QtWidgets import (QWidget, QVBoxLayout, QSizePolicy, QHBoxLayout,
                               QLabel, QFrame, QScrollArea, QTextBrowser)
from PySide6.QtCore import Qt, QDateTime, QSize, QUrl, QBuffer, QByteArray
from PySide6.QtGui import QFontMetrics, QMovie, QResizeEvent
import os
import tempfile
from typing import Union
import brotli


LOADING_ANIM = b'\x1b\xd4\x7f\xa2\x086\x8e5\xc3\xb0\x9b#\xaaH\x15\xfcq\xba\xc4\x06\xe4\x9cvH\xa3\x85\x0e\x80\xdd\x1a\xb9av\xe6\x9du\xceYg\x86\xccR9\xee\xeczT\xc6X\x19;t\x87;g\x8d8\xf6\x9d5\xb2\xca\xd1b\x9fQQ\x12ZN\xc6\x0eIR\xf9\x068\x98\xcfOD\x7f_jW\xcd^\xba\xb6\xb8\xb8\xb8\x80\xe7\xfb\x8bz\'\xff\x00\x8eH\x00\xe3\xd1\x98\x074\x16\x91\x08\xc69\xc0Q\x0f\x18\x1c\x17P\xe0\xff\xfb\xd5\xbf\xb3\xbb\xaa\xab\xba02\x92\xc2"L\x86\xfe\xfd\xa5eW\xadb\x9f\x8c2.N\x9c\xbeo\x80\xd9H\x94\xc4\x82#\x0e\x19\xa7q\x96\xf9\xe3\x9e\x8a\xfc\x1a\xa3\xd0\xd3(\x8cEif\x97\xa0\x8anJ/>\x832\xa6V\x9e\xf8\x8c\xa9\xae@$\xa0M\xce\xa7\xc7\xeb3\x99\xd4\x98t\xcf\xa2\x91\x89\xa1\xb6\x8e[\x07S\x07\xd3/\xc8\x05\xc0\xb0\x85}\x13\x8eM8\xc3\x15n\x10|\x04@\t\x11!\x06\x0e\x01I\x8a\x0c\x05\x97\xa8\xd3\xa1[tc\xa0\x174\xfd\x18\xc0\xc02d\xc4\x98\tS\xe6n\xf9\x8f\x95;\xac\xd9q\xe4\xc4\x99\x0bWn\xdcy\xf0\xe4\xc5\x9b\x0f_~\xfc\x05\x08\x14$\xd8=!B\x85\t\x17!R\x94\x18\xf7%x \t\x01I\xba\x0c\x99\xb2d\'\xa74\xb74/\xf9\n\x14z\xa8\x08Y\xa9r\x95\xaaQ\xd5\xaa\xd7\x94V\xed\x1e\xe9\xd0\xa9K\xb7\x1e\x8f=\xd1\x8b\xa6O\xbf\xa7\x9ey\xee\x85\x97\x06\x0c\x1a2l\xc4\xa81\xe3\xe8&2i\xca\xb4\xd7\xde\x981\xeb\xadw\xe6\xbc7\xef\x83\x05\x8b>\xfab\xd5\x96}\x87~\xf8\xe9\xc4\xaf-\x9e\xae\xfd}]\xe2\x7f\x8e[\xd8;\xb7\xff\xff\xa7g\xd4\x94U.03\xdd#qV6V&\x10\x93\xa2Sw\xfc\xbb\xef\xad\x11\xf8\x9c\xe9"X\xd4\xb8\xa3z0\x19\xcc\'\xefH\xef\xa0\x0c\xa7B$M\xcb\x8d;\xa9\xa3\x19\xb0\xcb\xfe\x9f\xe8\x9d5\xe39\x08\x83tQ\x93\xae\xda\x89\x02\xd4\xedf\xc7\x89\xae\xba\xa9b\x15\x8f\xc9r\x93\xee\xfaWe\xda\xe1\xdb\x9f&\xba\x1b\xdeT\xe9%\xb3\x8b\x99\xf64\xce\xd6\x18\x17\xc8;M\xf64\xbdk\xb0\xa81\xad0}\xdc\xfc\xbe\xc5\xb6\xdb\xff\xf3\xe4\xe3\x96\x0f\x8f\\\x87\xd3\xc5\xcc\x9e\xb4.v\xfb\xbekv\x9az\xd2\xf6\xb17\xe4\xdbd\x85Yo\xfb\xe7\xa71?\xb6?O\xf5>rI\xd1\xba\xf3\xd7\xa9\x89:\xa7\x96Hz\xba\xd5\xa5\xb6P\xfb0\x98$i\xe4-M\x0b\xa5\xeb\xe5_\x96-r\xfb-\tyU\x1d\x19\xb9\xdf\x88\x14\xf1\x9d\t2\xbc\x17\x18.\x1c\xa1\xf5^\xd8\xe110\xe1\x82\xa6\xa1w\xb7\xc6\xfd\xce\x04\xd5\xdeu\xddgJ\xfe?\x94b\xa3C\xd2\xbb\xd2$\xdb\x13\xe2\xdd\xe1k\xa4\xb2\xdbw\x98K\xb4C\xb6\xf8\xda >\xc4\xe7\xeeM\x9f>\x93\xcf\xa3\xab\x16\xea\xfb\xd7\x9d\xca\xc7m\ng\'uox\x7fx\xefQ\xc8\xccJ\xfa\xfb\xe7\xf4\xc7\xce\xd77/_\xfe\xff? j\x19\xc7:\xf9\x8b\x89\x95G\xef@\x0f\xcf\x86E\x0c%C\xd2!\xcc\xc9\xac:*\xe8\x14\xd8\xad\x0e\x04A\xd8u\x93\x02\xe4VA\xe1S\xa5n\x85\x14\xb0\xc7v\xb8/\xa9\xb5vX\x96\xd8@rQ\xdfR\xd4\xaf\x01\xed5Ob#)\x99\xf0R\xedw\xd1\xdd\xcc+wSu\xe3\xb4\xf9\x02^\xa8>yx\x01\x9b\x0fF\x9bk\xd1>\xd8k]r\xff\xa9W\x00\xbf\xcev;l\xe4\xe1\x90@\x11\x8c\x08.(\xecV\x1a~\x9f\xed\xea\x0f)\xe0\x9c\xc1\xf6>LvMG\xa0\xcd\xab\x1e\xcb9[c4\xd9\x90\x15AG\xb7\xa5\xadU\xddM<\xcc\x83^\xcc\x0b\x94\xebr\x0b\xf3\x05O\xee\x1d\t\xb0\n\xe46\xe2\x8b._k(\xcfw\xc1B\x06\t\x02\xc6\xd5\xa8\x9b\x99\xeb\xf3\xec\xc9j\xb9%B\x0f\xf9\xbf@\xb6c\xb7,cpuo\xf2#\x0bJ[\x00\x9f\x97\xb1p\xe7O&;\xed\xcfN\xb6w\x1e\r\x00\x15v;F\x04\x03v;\x91\xb3z\xc3\xec\x03\xb7,\xc7\xa5g\x9c\xdf\x8e\xc3\xa6\xdf\xf6\x0fu\xcfz\x7f4\xca\xe6|1c\xf4dY\xff)\x80\x10\x95\x12\xd0\xde\xcet\xcb\xad\xbd/\xe1\x14\xb5\xdc\xbfsKu\x99\xe3\xa0\xd4l\x0c\xa7=\'\xd2\x0e\xbf\xd0\xdcr\x89vz^\xd6&\xf6\x83]T\t\xca*\xcc\xb9\xc7\xc3\nw\xeb\x80\xef\xb3/\x10\x07\xd4UhC\xbd?\xdd\x19\xdb\xac\x9e\xad\x1fA\xfd\x80/3\xc0\xb1\xe2\x85A\xec\xc8\xb3[\x07,]\x8a\xbd\xbbGS*\xe3\x8a?\xa6\xd5?\x04\xfex\xa5\xbd\xd1\xfa\xe3\xb5\xee\xaf\xdd\x1fo\xf4@J\xc73\x18h\xd0\xf1\xac\xb1l\xdb\xf1[s\xad\xbd\xe3w\x16FJ\x91\x0e\xcc\xcc\xffY/\x80\xef8\x95i\x85\xd9\x85\xb0\x02\x00\x0f@\xea\x06J\xf0V\x80\xddPH\xc2\x93\x88D9\rn\x8b\x87$r&\x94\x1c)yK\x8d\xb7\xb4x\xeb*]\x9b\xae\x139\x07@\x820+\x8b\xfc\xd5m\xba+\x1bO9pff\xc4`\xcf>9\r\xcc*\xf4X\xc2E\x8b\x13\xef\x01\xbcd\x04\xa9\xa5\xa4\n\xd2\xa4\xdft\x8c\xd4\xb9\xe4+T\xa4\xe4\xc4\xf75\x85Zu\xfb\xea\x06\x1a5iNvb}2I\x92\xe3t\x9e\x01@\xbd\xca\xd7\xd7\x0c\x80\xfa\x9c\x88e\xdf\xac\xd9\xb0e\xdb\xae}\xdf\x1d:\xaa\xfeG\xe9\xf1\xab\x01>g\xe2\xa1\xf5\xf7\xc3\xd7\x97\xb8w\xc1*\xee\xe3\xc6\xd9\x03\xa8o\x9eS\xe3\xe4PMm\x92\xd1\xfa\xc0{\x9a\x9a\x87c\xaa\xe4\xfdO\x1d\x0b]k\x81"\xea\xd1\x98\xb5\xbec\xb9Y\x91\xb6B\xe7=@\xa4\xe1d\xcb\xb5oaY\x9d\xe1\x81S=J\xeb4\'a\xe3\xe0t\xc3\x98\xfb\x9aG\xf7W\x80\x8c"\x03h1\x8a\xab\xef\xdb\x1a\x9f\xc9U#\x80\x93;\xf7\xc7\xde\xee\xdf\xedpU\xee#\xedO\xb2\xe7I+\\\xf2\xbaX\x85\x05\x11\x9f\x0b\xf7*\xdd\xb9\xaf\xd2\x04}\x86\xbdd\xc3\xff\x8c?\x13\xda\x1d\x80\xa01\x02a\x00\x0bY\x1eJR\x8e\xe9@\x03@\xc2R\x83@Nk\x1a\x02\xc8\xc3\xad\x8e\x07\tF5:\xa6\xb0G-H\x10A\xee\x08*\tn\x1e\x82H\x95\xcdF-\xb3*\xa5\xd3\xd17\x93\x17\xb5\x8a\x00\xaaQ\x9bxs\x9d\xf2\xb7\xe5\x1e4[\xd5\xa24\x1d{X\x81{K\xc5\x11\xc5F[pb9\xfbRV\xf1\xe7|G\x93e\xa9\xe4\xcb\xfd\xb5\xa5!\xdd\xf8Qj\x81TWDE\xf8n,\xd63\x0f\x0e[\xc8\x17{\xbdVp\xd3Vb=f\xd0\xacC\xc7h\xcdZd=\xa6\xc1t\xeb\xd0P\xd4\x96\xafr\x13MV~<A\x16\xf3p\x1a\x18,\x16\x0b\xacv7O\xf8r"k\xc7g\xebz\xbb\x82\xbe\xd7\'^\xf6\xfa\xb9\xdc2\xf9+vS\xacX\x08\x89\xf0\n\\\\\x88Yn\xac\xa3P\xfdpt\xbd\xea$\xa7\xdc:\xa4\xfaB\xd4\xe3\xf5\xe6\xf1#P\xa0\x99\x88m\xa8!<g5\x94\xc8\x1f\xbe\xed\xcf\xda\x95\x83Q\x08\x82\xdfX=#\xf4,\xb8\xb7`\x9b\x0c=w\x82z\n\x80\xa8\xe1\xde\xaf\xeb\x87\xcd\x89\x1f\xf2w\xf6\xa0 \xfd\x16\xe5\'\x91\xe0\x98\xc1\xa7_\xd9i\x17\x9e\x7f\xd9G(\xbfX\xac\xcc\x10\x7f\xf9\x0eN\x07\x0e\xe4t\x84VCXm\xee\xbb\xf6\x1fw\x890\x00\xfb\xf9eF\xdd<\xc1**}\x81\x16\xd3A#\x13\xc4\x96\x1d\xc0U\xf3\xce\xe4\xb1\xe1\xa2\xc0\xa3\tTC\xeb\xd1\xe4\xb8R\n\xd7\xe3\xf3\x8a\x815\xf3\xb0\x9c8\xbc\x06\t8l8NL^_\x84\x07\xef\xa9L\xaf\x85\x11=\x91p-i_\'\x1dE2\x91\x85"O\x91\xb2KT]\xa6A;W\x06W\xa3{\x83\xf9\xda|}\x8b\xccS\xd6\x1b\x00u7~l\x80Al-\xe71Pq\xf9V<o%\xf2\xde\xc6\xc5B\xfc\xc2\xa49Y)"*\x15\x02op\xfc>@5o\t\xb2\x8a\x13Y%*U\x99*T\xa9*U\x8b\xa2\x1a\xea\xfbj\xa4f\xb5\xf9k\xac\x1e\x1c\xa1\xac\xcf\x0fa\xbe\xb5\x90>\x8b\xa1U\xadk\x13\x0e\xaf=\xe7\xb5\xbf\xf2w\xcf)\xe1\x1a\xdf\x1f\x178\xe0\xe6sc\x02F\xad_\xfe2\xa1cj\xb9\xdc~!\xcd^\xfc\xaaW5V\x9b\x93\t\x10\xf4\x1eV3R+5\xf8\x9a\\4\x18n\x08)\xc1\x06$z\n{(\xbd\xa76\xf4<\x01;\xa8\xef,\xf2\x11\xe6\xb8\x9d8~af\x9ej\xfc)\x02\xeb\xd2V\x19<\x91"9\xba\x9c:#\x9cS\x92\xc9a\xdc\xa1\xb6\xc7\ns\xe2K\xb6_\xae\xfe\x19\xd6\x1al:W=9?\xb0\x0c\xf2\xd7\xa7\xcb\xfe\xd7\xd6w\xd7\xef\'\xcfe\xf3\xd8\xdb-\x82\x8dZ\x15\x8c\xf1\xab\xcc*\x9a\x19$\xde\xda\xc1\x02\x16s\x85\xb8\xeasG\xb8.\'_Ld\x1aL\x02`!,)\xb0v\x84>\x80\x9f\x9bU\x9f(\x94\xbe\xac\x97*\x82\x03SA\xfc\xfa\xae\xd44\x1eE\xdb\xc1tDp\x87k\x9a\x8a\xfb\xc2`\x12|\x8e\xc4\x00q\x84UK\xa6\xe8\x02I\x839\x17\'O\xad\x8072U\xc7.\xfaa\xf5j\xf1P\xda\xb1\xadow\xa6\xcd|\xea\r\xa2\n\xd2l\xb9\xc9\x90+\xca\x0b\x8b\x18\xca\x11\xed\xf2\xfc\x12\xecI\xae\xc3g\x8b\xf6\xa8\x13B\xe7V\x8d\x04\x81\x1e\xa5\xbe\xab\xa6B\x1d\xbde*>h\x0b\x04\x11\xd1\xb3\xf0V`\xf6\xb3d\x83\x9d\x80o5\x1a\xe0\xd0?\xb7\x16\xe6\xcarj\x1f\xd1kb\xef\xab\xc0\xf1\xc4\xca\xd7\x8b\xf9\xba\xbfc\x1cs0\xb4\xe2!\x93\xbf\xbfh\x03\xc7\xba\x90c\xb8\x980"\xa5r\x91\x82\x0eG\x11\x10\xe6\xc2K\x92\xdf\x1f_\x99\x11\xa8\xb6\x8d\xfeO)\x87^\xbfS\xb1?\x14]&\xc3\nd\xee\xd89*h\xbe\xac\x82\xef\xe4s\xb4\xa4?^\x10d1\x02\x8f\xbce:\x9f\x00\x13D\x12\xda\x85\xe3E\x94i\xe6=\x93\xa3}\x1b_h\x08\xee\xdd\xca\xb2\xf5\xa4\xbb#\xf7\xf7{\x98K\xdd\xee\xd1>\x01i\xf7h\xba\x8a\xa7\x97h\xcc \xda\xfe\xc0\x87\x13\x8ej~\xb0\x8b\x99\x04\x17W\xf8\xac\xc4\xf0\xffC\x14t*_\xc7\xe1%\xee\xfe\xa8\xeaKOC\xf8u\x15\xf96JC;;\x85SfZ\xf9\xb5i-\xbb\xe3m\x7f\xce\xdd\xb1\t\xfa\xf9\xde\xd6\xa7M\xc3\xaav?G\xf6,o\x01\x08\x14\x9aO\x16\xff\x04\x15,\x85\xb89\x92l[\x88\xd4\xe5%\rv/\x05R\xe2+\x15\x93\xea:j\xcb/K]\x1a\xd2\x9c\xb4\xa4\xad\xab\xba.\xb402\x92\x99\xfe\xd3m9\xcaM^\xae\x82($\n\x8d\xb9\xdb\xd1k\x8aY\x1e\xbbB\x9c\xee\xb7S\xc2 {\xea\xfeJOY)\xd0\xeb\xa1-\n\xafr[_Q\xf1\rj\xf7j\x99\xb7\xda\x1cZ\xc2I\x12\x03\x04V\xef\xd2\xbc\x16\xf5Y_\xf5\rj\x7f\xb3\xb6\xe2\xbc\xb6\xb5\xa3\xdd/\x1b\xf09\x93\x00\xc1\x7f]\xd0:\xdc2\xe4\xe7p\xf6O8\x0bK\x85S\xd1\xcd\x14\xa3>5/#Q\xe4\xbd;\x87S]>qS\x88\x801\xf0\xce\x8f\r\x97\x9aK\xb74\xff\xfd\xb6\xf4O\x97\xb7\xed\x16\xfc\'L\x85.\xd6\x0f\xcfe\xd3\x84{\xbd><\x15/:\t\x12\xb2>H}H\x82\xde\xd8\xef\xe8\r\xd3\x98\x16\xf1\xb6t^4\x8b \x8a\x92-s\x8a~\x9f\rmM\xb6\x9d\xdf\xf79%\xc54\x1e\xbe\n\xbd\xb1\x9d]\xe9\xc6\xb5WY\xe2\xe5\'\xdeI\x84j\xf8\x0f\xcd\xd4\x8f\'0Z\x04\x8d\xd0\xd3\xe7T\xc5\r0\x03\xfeW\xc2$\xf1qjn\x8ep\xedJ\x1b\xcf\x00.k\xfbR\xf8T\x10(\x8a\x1e\xff\\\x08\x83 \x15\x88\x9aI\x12w&\x0f\x12\x85\nO\x19\x89\xe7\xf8\xea\x95T\xa81x8\x03\x1a\x85\xa0\xa4\xaa_\x01\x0fe\xe9l\xa3<r\xb8\x0c\x17\xaa2\xf4\xae\xb8\xe1S\x04\xf9u\x92I\x98uX\rI\xe0-M\xd2L\xd4S\x15(\x9d\x1dK\xd1w\x10\x1c9p\')zuf\xfa\xcd<~_\x9b\xacQN\xb7\x8a\xedz\xde%\xed \x18\xc2\xc4\xc2\xa9\x14\x93\x8b\'*\xe8\x8c\x0b\xfb#\x93\x8c\x1cKx\x87\x1a>\x95\xfd\xff^O\xcc\x0bw\x16\xfd\x91\xb2!\xdd\xd8po\xca\xf8\x14\x15<m\x0c\x1b\xa3\x1c\xab\xdb\xa3\xea\xd3\xcedQ\xa1\x8a\'\x1b\r\xf7\x06\x82\xe82u\xfa\xe7\xe3h\x14\x8d\x99\xaf9e\xc6\x19cPO\x02\x85\x86\x88+v\xe8R\xc5\xdb\x9e\x9dl+\x18\xc0\xe7\x06\x08\x82\xaa1\x07;z\xf2\xb9\xcc\xf4\xae\xe9|\xb7\xc0G\xd0\x90\xc1\xdd\x9ei\xffY\x05\xd8\x9c7\x07\x18\xda3V\xdd\xf6$\xe5<zP\xe8\xab\xb7\xd9X\xc1\xff\xb1\x0e\xc1O\x18\'\r\xa3\xfd\x8bVnr\xcf\xe6\xd2\x7f\xb9\xc0\x8eoq\x10S\xde\xae?m}\xccf\xc5\xf8\xde\xa5j\xbc98\x80\xab\x9dtyy<\xa9\xb0\x02;\xde6l\x01y\xb5^%\x0e\xad\xa8\x99+\r\xbc\x8c\xab\x06\xc0\xbc\n\x99\x89\x820\xf1\x80\xda=\xf1\xe0\x12\x88\x95\xd7\xd7\xe4<\\\x9d\x8f\x86\xef\xb1\xe2K\xc2\x92\xa42/yR\xa6\x1a/M\xd2I\xf4"\xfc0s\xcd\x1b\x83\xaa\xbe\xf1w\xd9MNr\xf7\x96/\x05t\xed\xfd`\xb1N\x98\xc2\x9b\x9e_\xd1\x14\x8b\xa2S\x89\x12\x16:\xaf\xbcS\xc1\xb8>\xbfW\x1eS\x85*\xc3\xee\xe3t\x16\x1c_\xa5w5\x99^\xe9\x8d\xdej^K\xfa\xa4/Z\xd6\xca\xf4m\xfd\xd5\xf5\xd7\xb4\x9e3\xa4vhO\x07\xfa\xa1\x13\xcf\xe9\x11\x1a?\x06\x18\xc3\x18t\x8c\x9e\xe2[\x03\xb8\xf5>R\xe4\xc7\x1dB\xe8\xb8\xc0\x182`~\xd7\xaf\xd3+\xd3Q3#\xfb\x19\xe7\x88O\x86\x94a\x8bwd)\x15\xe4\xd4|\x17\xe4\xaf\xa4\x1a\x11\xf8\xbeGR\xbf\xbf\xad\x14\xb3\x9f\x9a\x1b\x9b\xf1\xfa\xe8#\xe5`\xb6;\xe3rJ\x82\xe3e\xe8\x1ag\xb4V\xce3\x96\xb3!\xbdw\x92\x0e.\x9bn\x8b\x11\xd8\x8f\xd0sk\xbf\xc4\xe9\xf0\xd3\x94\xb7\xb167^\xce<\xf1wz\xb1xY\x8a\xd9\xf4\xb8s5\xe5\x1a\x0eL9\x95L\x93W k\xd9\x82\x8d\xf8}\x97y$\x02\x11_\xf5E\x0bC\x96\x93Q`\x1a\x02-\xd2q\xb0L0\x8aP\xa1\xa0\xa5\\c\x18l"\xbc\xc7\xf8T\x18\x11B\xd5\x13\xcb\x073\xd28\xab\xdf\x15\x02{0m\xf0\xbfv\x99\xd2\xe1 \xf5\xeb\xa7\x83i:p\xfa`\x1a\xf7I\x0ck\x06\xeb\t\xcc\x85$B3\x96\xe4\x10\xee\xdaDg\xd7w\xa2 \xe0K\xd9\x08i\xb4X9N\x82\xe3\xaa\xb3\xddL"w\xa5\n\x0bX5.\xad\xc0#w`,\x1d\xf9\xa6D\xc7B\xe0K\x16\xb0\xaalkt\xbe\xbep\xbfI\xd6\xcb\xff\x95\x90GM\xfc\xcf\x9b\xa9_\x89\x8b}\xc3\xf6\xa4x\xef\xe8\x95\x18\x82\xa1\x0e\x83\x9d\xd0\xff\xc3\'\x06\xce\x1f\xc7\x991\xee\tb\xcfX\xb8i#\x941\xcd\xd6\xbbU9\xaety+I\xc1SXD!\xdby\x0b\x8f\x1cj\xfe\xac\xb3\x00\xfc\x13\x19+\x04\xc5{\x86\xae\xbaZ\x06\xe6\x8d?z\xe9\xec\xd6R,\xee\xcb\xbc\xdb\x19\x1b\xe3\x96T\x82@\xec\x04\xc2\xab\xbah\xf8Go\x90\x01\xc8\x0c\xcb;;\xadP\xaf\xe0\xc6\xbdn\xb9\xf2\x85\xdd^\xba\xe1U\x06\xdb*\xb2e4M\xae6c7M\x8a\xc6\xa1(\xb82\xf9\'\x80_q\xa9\x0cD\xda\x9d|\xda^hK\xbb\x1aH\x82\xc7\xa0\x95_\xda\x04\x87`\x1f;\xf6l{\x81mBT\xef\xb1\x7f\xee\x97\x9b\x016\xd8\xb7\x1e\x8e\x89F\xef\x1e\x8e#R\x15\x8f\xe8R\xc5\x81\xe3\x12\xbc\x11\x85h\xee\xb7\x81s\x06\xc1\xdb\x11\xdc3g\x9e\x89O\x02\x12l\xe5{\xd3\xd3)\xd6\xcdJ1\x94\xf4\xd2\xc0uk\xe9A%\xe7\xca\x94|\x03\xcc\xd6\r\xcd\xa7\x9b\\\xba\x96%\xd4\xf6\xb2%{9n-\xe7\xc8\x96$\xb9\xeb^\x120\x05\xb6\xc3\x02\x8d\x9eKZ\x7f\xd64\x98\x01\x008N\xb1n\xf5(u\xaa\x1b\xde\x06\r\t\x16\xe9G&[\xb1\xde$\x19\x7f5\x17"{}\xe2\xea\x8b\x15\xbe\xae\xbc<182"\xfc\xd4\xce\xda]\xae\xd5\xd9\xf4\x0f\xcd\xfd\xe2a\xf2GA\xe2S\xb0\xb6\x954\xcf\xe2\xcc\xb8\xb6\x0e!\xb6\x87y\xb9\xb9!}\xa6\xab\'\xba6&\x1b\xad|\xdb\xc9\xf8\xa3\x8d7\xaf\x109E1\x9b=\x017[$\xe7Cn^\xf5\xb4.R\x1b}\x9f\x12#?R\xfc>W\xdd\xbf<\xcd\xf4)\x92\x93\x91\x99Q\xd5\x8ew\xa4\x1c\xbd\xa1\x96I\xa6\xfc\xfc\xd4u\x9c\x92\xd9\\\x93\x9c\xf0\xcf5\xdd\xfb}\xce9\x87\xa0\xc4P\xd2\x98\xca\x1b\x10 \xcam8\xed\xfe/\xf5;\x0e\xd3\xdc\xa2\x02\xcb`\x8d/;\xd1\x17/H\n\x1e4hx\x94\xb9\x08nv|\xc5O;\x15\x0eI\xf4\xe1\xa3H1\x0f\xd6\xa2\x97\xf1\xca\x81R_\xe3\xf8n5\x0e\x13>s\xa5\x18\x10\xf9\xf4\x17(z<8m\xb7$Iv\xa9\xa44\xbez\xed\\\x0eE8\x0c\x9f\x01n\x85\xd5$\xaa\xb3G|\xbb\x8f\xea?ed#\xebm\x87\xb2\xaf\x90\x8b%Y\xd4?\xd9\x0e\xe5I\x9d\x83\xa9\x9c\xe6\xdc\xfchN\xa1m\x0b\xb7B\xd64\xbd\xe4\x02-\xba\xabT\x11\x10\x8b`!{\x16\x99\xbc\xf7\xf0\xe6-d\x91\x9cs\xaa7\xc9\xb1%2/\xfb\xa5\x86\x90%\x13\xfa\xd9<|\xd2mu\xc7\x9d\xb2\xbf\xde-\x1e\xcek\xbb+;\x9d\xc7e\x1d]\x1b\xf5pp\xd1\x89=\x93\x9a\x8c\xcd\xce\xbb\xb2\xe4D}\xb3\x17+V9)V\xea\xc1\xb9\xc4\x05\x83\x01D(\r\xe5\t\xb8,\\\xb2@\\\x8f?\x81k\x1c\xe6\x9a\xd2\x14\xf0\n\xb3\x01\xe5j[/\xdd\x81\xfdsR\'\x05\x97\xfa\xa6C[\xfa\x05[@\xdc\xb0Q\x15\x05E\xea\t\xa1\xa5sL\xbf\xc4\x92]\x83u\xeb\x03xF\xff\xaaa\xab\x0eoYP\'}\xfdT\xa9\xa7\xe0-i\x906\xb3Nb\xe9\x1f\xa3\xea}\xeb\xdf\xdd6\x95\xcf:\\\x9f\x1c\xcd\xb3\x9bk\x01]4\x9a\xac~\xf4\xd4(\xeej;\x97\xa5\x95\n\xb0\xdfqzJ\n\xc8\x02\x9dJ\x1e\xb2\x9d\x1c\xc0v::\x96\xc8\x00Pt\xa6\x90\xd2 .\xa5\x07?\xa4F\x07M\x96/@\x13\xd0\xdd\xe6\x0f\xe8\x9cS\xcc3H\xf1%u\x92\x95\x02*\x0b@ !I\x82R\xdeJ/\xe9\x0b+\xe3\xb8b\xcaB\xe2\xb6M,\xb7=\x93\x9d\xec\'\x87\x18l\x82]\xe7:\x1e4O\xde|\xf9\x0b\x12&J\x9c\x048)\xd2\xdeK\xeeE\x9b\x84Nn\xad\x1b\x16\xcfd\x95\x0c\x98\xbe(\xa2\xb4W\x0b\xb5\x87\xd1\x9b\xbaN\x92d29\x88\x9a\xae]\x9cb\x98y\x03\x96\xe6\xfa\x1f\xa7O\xfa\xcc\t\x80\xc6c\xdc\xca\xd6A:\xd2O\x9d\xea\x8f\xfe\xea\x9f\xce\xf5?5\xfa\x85D\xe7\xef\x83\xf3t\xccv\x1a\x1c\x0f\x0143S;\xc7\xf8\x9a\xe8~_\xcc\x95s\xd72<\xb2C\xe1{\xfe\xa3\x1bi\xd7<\x91$\x99\xf1\x96\xa3\xadT\x04\xe6\x11\xfc\xe6\xd6O\x03L\xb7\xcd\xaf\x8e\xcf*\xbf\xfc1\xcf\xa0\xed\x07mKwC\x08\x06\xa4\x96\xeb\x95!\x99G\xb3\xd3<K1/~\x0b,\xf3i\xc6;\xf6\xf1bR\xd33\xe64\xce\x03\x8e>\xa2\xc7O~l$\xd0*\x1b\xe5\xff\x92_H$UW= \xd0\xd9\xd2\x87\xabZ\x8eZ*\xce\xe3\x91;X~R\x18\xfd\xd3\xf8\x07\xf6\xf3\xdf\xe3\x06X\xc2)q:8>2\xd75\tH%N\xfb7\xdf\xa1A\xd9\xf8\xce|\xec\xb1\x08NK\x92\xfc\x0b_^pJ\xa2\xc4\x02#\xfe\n&:7V\x81\nM\xc9\x006\xc1\xbeEq\xbc5\x9ea\xd3\xaa\xfc\x95\x94\xcd\x8a\x9f\xf9\x16\x85b2\x81\\\xbc\xc6;\x8b\xcf\xbb\x80\xd7\x1b\xc9\x92R1\x81\xb0\xab\x9e\xa3\xd6\xb2\xff\x939e<d\x8dt\xbd\x90\xa0\x9b2\xe0\xa5/Q]\xad_\xe8Q\xdf\xb4^\x1a\xf8d\xcb\xdbE3Su\xa4(\xa8=w\xd1\x97\xc4\xaa\xbd\x8e\xeb\x16KF\x16\xd3x\xb4F\xc8Mr\xd1\x99D\xbd1C\'y\x1b\x19(\x9c\xaa\xae\t\xfbRu\xe5\t\xb4\xd2\xc7\xfc\x8c\x17\xae3\xa0\xea\'\x17I>#$q\xdc\xe0?L\xe6\x92\x8bw\xe5\xa9\x9a[\\\x86\x82?\xdcX\x90\xd8i\x8d\xc2YJa\tV\r\xb2\xcer8\xf4\xce\xa3(\x9a\xe9l\xc3\x08\xa1\xd9\x06\xfc\x82\xe5O\x0b\x07\x7fE\x88D\xe8\xfcO\xe9\x94\xae\xc9t\x9dY\xc8\x9b\xd7\xeb\x1c\x15\xb1mzm]7\xeeD\x0c)t\xafm\xd9\\\xfc*\xcfQ*S\x9a\xff\x83\x1dY\xb8\x1f\x89\xe9\x1f(EH?\x1f\x083\x93|\xf1\xb2\x1e\xb1\xd6\xf3w\xd2\xbf-\xef\n\xab\xe2\xceC\x14\xec\xd3\xca\xc3\xcd\x15\x11b\xb3M\xa2\xca\xa5\xe7\xbdaB,\x03\x93D\xc6\xf7Re\xdc\xd3\x1d\xb28y9\x89[\xb9\xfa\xe0\xb0,\x86\x92\xfb\x83\x04k\xbd\x7f\xcf\x9d\xcd7[\xc0X&\xdbEk\xf2\xa5\x82k\x86\n&a\x89\t!II\xbbB\x91\x9c\x14\xa5\x82\x1b\xc6JoQN\xea&\xf8\x9c\x82\xdb9\xbf\xd0r\xf6Y\x1d&\xc7\xd9I\xce\xa9\xda[\xb2R\xbe\xef\xb1\x97x\xcb\x87*\x9fz\xddb\xb4\x0c\\ty4\xf7vO\x8b\xf2\xceE+Q\x99)\'\x9fo<\x92\xadp\xdf\xcaD\xb5\x14\xc1\x9d\x1c\xa4k\xcbj0\x8dk*V\x98x!\x0f=W\x9e\x9f>h1:O1h]\xdb\xda\x8f\xd5\xa6\x8e5\xebe\xfd\xa6\xb3\x01\xbd\x9f,\xbe\xf1\x1b\x91\xd6\xf9m\x9c\xfd\xaek\xde\xea\xe4]\x99\xeb*\x08\x97\xd5om\xdd\x1b\xaf\t\xda\xbeEt\xe6\xb9\x8dw_\xa2\xbc\xe0\xff,\xf8\xfd\xe7\xda1\xdd\xde\xb4\xb5\x9f\x01\x06\xdd\xd0\xb0M\xaf??\xb7?\x81\x02\x8e\x13\x9f\x03T\xc0BZ\x89\xbb\x1d\x87\xee\xc9\xd8\xd7\xc3\xff\x99\x1d\xdd\x1f4\xac\xd8Y\xd8\t\xc9\xb3T\xbd}\xfc\xae\xfd\xec<\xe94\xefy|\x85\x18T\xc6\xf4\xec\xdc\x8e\xff+\x07f\xba\xec\x8dj\xa7\xe6\x9f\xd7\xb4_\xf6\xc5\xf7*\t\x18\xc6\xaf\xd8o\xc3\xce\x88\x03Yq(\xdf^X\xd5%\xf9]l2\xfeH\x03\xc6\x83\xfb*\xd0k\xc3\r)\x1d\xaf\xc0\x10\xe3\x8bM\\V\xbd\xc8\x15\\\xfc\x91\x0b\x0e2]{\x02T\xd2\x87<cK.\xf6\xcau\x0e\xee\x07\x9f\x07\x90Q\x97\x1cY\x93/\x12a]X.\xfcD\xc8\xb7H\x04S\xea\x0c\xd0\x80\xd7\xcdS_\xbf\x0b\xc5\xc8\x07\xed!\x90\\\x162\x11\xf8B`\xbf\xadt\x813\xd9h\xa4\xc0\xc1\xbe\x89\x85Kk\x01q\x81\xec6\xfe_\xd1zY\xc8\x98\xdcF9\xfc\xbd\xca\xa2\x97z-X6\xb3\xf1g\x12\xb6\\f\t\x98^\xe9\x0f\\\x12A\x05Y\xc1*\x08\xfectx\xa9\xc5\x10\xa4Z+\xf3,\x92\x85Scff\x08\x04\xfd\xad\xb2\x15\x91\xd8\xc64\xc2W[\xb44\xcc& t\xe6\x14\xf3\xfd\xb3\xc5v\xcb\x97\xba`\xd4l\x1c\xf3\xd0[(w\xc7\xfa\x19\xebC\xde\xc5h\xf1\xc6\xb8\xc1\xea\x96\xf6\xc6[\xdar\xe2\xf7\xbdT\xb6;:NT\xf2.1\x9f\x13m8\xa6y\x15x\xb8\x7f\xad5@\xb9\xde\xaf\xcb\xef\x19|\xc1\xf6rP\xa2\x19K{-\xcf\x0cG\xf0\x01\xcf\x07\x8f\x94\x9c\xaf\x94\xffi.z\xae\x9fQ*\xb1\xba\xe2\x95\xfc\xac\xd3\xbe\x96%\x87:\x80\x9c\x10\xfc\x0e\x9c\xba\xd44J\xfc=8\xa8W\xdb \xd3{$\xc8\xb9\x068\x8c\xba\x9f\\&~l\xa1\xc4\xcd\xdd\x1b\xcb<\xf2\xe5\xf5o<\xa7\xe6fu2\x97\x8a\xa7\xde\xc6\xf8\xcaj\xfb9\xef\x18\xbd\xa7ax\xc3\x1a\xc9\x9d2\x1e\xe0\xb5\xc1Mo\xc5\x1d.xl5\xd4\xf0Py)\xe4m\x82|i\x0f)>\x18X\xe0\xc1\x96\xf3\x1dE&\xe2\x0bg\xc0m\xab\xbd\xce\xed%wt\x97\xb3\xc4"\xe5\x94\xdb\xc9S>\xcd5\xdfp|)\x1e\xe0\xb2/bJ\x83\xd6\x8f\xaf\xd4\xe4\x86\xd5\xc6bM\xc4\xf6z\x19u{\x13bZ\xc6\x0b\xbf\xf7^yvz\xcbA\x12\xc5\xa7\x18\xd3\x9a\xb6b\xc3\xa9\xeftpP\x96?i\x02\xe37`\xaeK\x12\xe9\xd9,g\x83\xe3bW]zO\xb2\xda(_\x93Z\x86\xa0\x98_\xd7F\xaa\xa1a\xcb\xebr\x85\x11W\x1e\xc5\x90g\x90N\xe6ol\xd3-w\x1b\xd8\xffRs\xbe\x7fMH\x9fko\x94\x8f\xde\xd7H4 3\xbf.\xbf\xc9\x96\xde\x94\xb5\xb1\xff\x14\xcf\xf5c\'\x01c\x8e\x91\xba\xd6\xcb\xf1\x02\xdbq\xee\xf2\xdfeQ\xf7\x86\xfd\x96W\xbbJ\x12\xf0\xab\xdci\xb4\xd9\x0c\xc3\x1e\xad\xf8?\xeb\xbco\xa6\xa0Y\x8e\xdfK\xfe|(9\xb1\x90\xfc\x93vR\xe1\xcc\xe4\xfcK\x14\xe3\xcdO.\xc1E\x07\xe5"\xc2\xe50\xac\xfa\xf1\x9b\xd8!\x1b\x11\xbe\xf3u{\xcc\xd5\xddb\x8e\x94\x18\xc2,\xe5\x1e?\x0f\xc9\xd9\'\xfeq\x88;\x8f@\x9bD\x85"\xe8\xe4\xe7\xd7\x14\xf1D\xc14\xff>\x84\xfe\x8a\xb3\x84\xf9B\x92\xa1,\xac\xd3 \x1b_7\xe0v\xffF9\x90\x07\xac\xa5\xf6a,\xe9\x96~\xe1\x10\x87[\x0f\x0f\x90[\xa9\xd0f\xad\xd8\x95(\xb7N\xf6,\xf2[/\xf1\x1d\xbf\x8f\x84\xc0\xde\xeaaB\xb2\x01\x03\x9b\xeb\xdc\xb0\xf4"\xf6|\xdff_GeC\xc8:\x1a,\xf9\xd78/\xf3\xa8\x82\xc9\x16\xa8\xc0?;Z\x93\xb3\xe4\xbai \xcbOs\x08C\xeb5o\xd5\xdcY\xdf\xa8\x8e\x8b\'tl5:q\xea\xe4%/F\x0c\xd9\x00\xb3\xf3\xfb\xe5\xaa>p\xdd\xddvU\x8e\x1f\\\xden\xc4zB,#\xb8o\xc9\x17\x83z\xf3\x97\xfc\x0c$\xa8\xec\x9e\x1d5\xa5g\x16\xe0\xc6\xe6.\x1bvz\xb0\xff\x85xn\xcd\xae\x0f\xec\xb3\xfe\xc2\xbe\x98O\x02twgiO\x8e\xad\x1e\xc1\xc9\xae*\xe2x\xfaG,\x81\xb7\x0f\xf1\x95\x94\xd0\xf4q\x14\xcc\xcf\x90\xab\x90\xefX\x01\x04=\xb9f\xcb:\x94\xdd\xf2\xf3\x97\xcd\xc5Ya\x06\xb3!\x82\xd6\x01Dz\xcf\x81a`C\x84\xd9\xa3R\xa1\x05S\xff\x8b/\x8a\x84X8Y\xa3\xddR\xb8\x86\xfb\x9bp\xedH\xa5\xe6Hq\xdf\xc9\xaa\x9e_\xc2u\xfc\xad\x0b\x1e\xe4\xf7\x01\x128g\xfcnK\xeeYj\x96\x8e\x872\xc7\x81\x97o\xcb`\x83\xd8S\xda\xa1\xeb\x94\x01\x19\x12\xee\xa0\xa2\xfd\xe0\x98\x00\xe1y\x92\xdf\x17\x9a\xa8C\xc1\x9f\xba\x1d\xb6\xaf\xb0\x14\tQ\xa72\xcf<\xd3\x83x.)\xe3\xc3\xf0\xad\x80\xaf\xb2T\xd9\x8av\x92\xb9\xb0\xee\xeaz5\x84\xf3\x81\x99A\xef5\x9c\xc6\x9aI\xe6@\xb1\xfe\xb4^m\x19\xe9\xcd\xea\xebiE\xab\xda\xc0\x12sLz?m"\xe3g\x99\xa4\x99\xb5\xff\x10\x11\x94\xab\x99\xce\xaa\xa3+\xc5MyS\xf5\x8d<\x03K\xb9\xf3\xf8]\x83\t\x85g\x1a\xcf\xb5\xf9\xa1*/\xb0\x83N\xe1\xde\xfe\xd8\xa0\x94p:\xc5\xe0\xde\xfd\x1a\xaa\xd8>t\xf3\xaf \xe8e\xfb\x83\xff\x95\xf5y\xb8\x0f7\x8a\xce\xb8-o\xfd\x0b\xc3\x88\xbc\xe9~\xf4\xc5,\xb5?\xec\x12\xaf\xe4\xb9\xd7\x83[\xe9\x8f\xa2\xd7\x06%\xb9\xc5\xff\x8b\x7f\x94\xf6cR\xba\xeb\xc1\x0b\x9d\xef\\\xa7/\xdb\xae\x8e\\\x17\xd7\xfa\xf1\x0c\xbe\x0c*\x8b\xff\xf7\xd9{\xd8\x99%i\x8c\x88)\xe2\'\t\xbbTJ\x83\x9d1\x19\xda\xb67#\xf6\xa5c\xc6Cy\x12B2\x92\x7f\xee\x11Rp\x06\x16)\x86\xf8\xc8\xd3\xc7\xe8\x94/7\x8d-\t\xbbmC\x14\x17\xacE\xb4Q\x1a\x94r\xc8\x08\x0f\xe1\\\xc7C\x15\xbb\x18\xa3\x99\xd0\x84\x0e\xe3\xe4\x86\xb6.:>u\xeb\x17OA\x01Vn\xad\xf0\x8e\xb5\xdf\xdaC[\xef\xa6\xb5"\xc7\xa8\xad\xf1_\xc9\xd2\xa4\xf3\xe0h;\x18H\x1f\x927Zjp\xaa\xe2`(\x0eI\xf2\xd4\xa8\x85\xb8\xaf\xbb\xa8\xb765T\x1aW\xe3\xf2\xb2\x17\x7f\x9e~\x00\xfa\xef\xfb\xf9\n^\xb7\x95\x82\xdf\xaf\xcd-)\xe6N5\xdc\xde\xc0\xc8\x9e\x14#]D1\xc2M\x81\xbc\xb1`\xa4\x0b\xc1\xdf\xdf\x97\xcaoo\xfb\xc5\x99j\x98.\x89\xd9\xd1\xa1\xd9\xd4w7\xc1M\xab\t\xd1\xf3k\xe8\xd6\xd4+\xcd\x90\x07\x82\xe7\xa9\xd0V\xda\xb6\xceNC\x1c\xa0E\x96\x87\xf7\xb1=\xa2q\x0c)\\Ih9 \xe8w\xf7+\x8f\x04<\xf8\xb8\xa7\x81\xe9PW\xb7A\x10\xe3\x83p\x98V\xbau\xedn\xf8\x18W\x7f[\xfd\x95g&\x96A\xdf\xec\xac\xda\x9cQ)\xfd2<?\x0c\xf9G\xfaZ<\xcd` \xf8j\x80\xa5\xb7D\xba\xdf\xc1 X\xb6\xf5`\x88Sk\xf7`\x18b\xa4x8\xc2o\x13x8\n\xf3\xb9h\xbd\x1c\x0e\xfc\x10U\xa6\x00Q\x8c\x83\xe2\x99\xa03L\xc2q>\xe6\xbd*\xfc\x1c\xdf\x0c\xf4\xdbdw\x80\xda\x8e\x93\x06[{\xb3\xb2\x03\xea\xf4\xc1^\x073c!y\xc4\x9ev\xcb\x8a\x8e\x1f\x8a\x1e\xbfx\x05\xc0@\x00\xb6\xd0\xbc\xeex\xda\x93E*\xdf\x81\xe2\x86\x99\xca\xcaMl\xbc5f\x80\xfa\xdd\x8f$\x93\xed\xddku\xa4\x1e\xd1\xf4\\\x83\xb9D\xdd5V\x1e\xd3xj\x7f\x1c\x945\xbbDt\x17\xec2\xb5~\xda\xd0\xa6\xe7\xf8\xd4}\xda\xf8\xc6\x9f\xb6\x12\xd6\xa4V\x1e\x82\x90\x0eY\xe5\xb7\x9fG\xb2\xda(\xbb\xb7Z\x86\xa0Rj\xb2\x0fI\xf4o\xa6s\xc5\xefQ\xbf\xd4p\xdb\xee\x93p\xe6\x1a\x82\x80\xdfr\x84\x9d\x04-=p1L\xd1\x1e\xb6\xdaJ\x0b\xf5\xf1c\xfa\xff|/n%\xcba\xbc\xa6[~6z$l\xf1\xaeL\x17\xe9\xf5\xe7E%\x8e\xf8\xa0sG\x9f\xcf\x86T\x80\xfd\xe7\xbe\x8b+e^\x7f\xfdo\xf0~\xab\xfd\x9e\xe8\xf1\xe8\xde/\xea\x94Q\xca\xf5\x1bW*\x9f\xcf3\x8a\xed\x04yBg\xc4\xa3[w\xef\xe2q%\x91\xc0Y.P\xd8\xb8\x8d\xef\xe9oU!\x8c\r\x06&\x16\x13w\xb7\xba\xf4>\xca\xf8N\x12q\xec\xfd[(\xfb~\x02\x9a\'m4m\xe5\x038Zqc\x19C\xed\xd8\x1cu\x11\xf0<\xa4\xf8z\x93\xadgI\xc2\xfdj\x0b\x00\xd4\xb3eIC?_\xe3\xcf\x01\x9c\x8c\xd9\xafJ6*[3\xe1\x9f\xfb\xc2j\x0b9\xed\x96\x01p\xea\'\xa4\xa9\xb0\xa5{\x91\x8e*\xf3\xff\xc8\xeaG\xd0lJ\xcb3Cl\xe2\xc6\x07\xf5\x00\x15E\xc6F\x95\xd92\x0e]&\xba\xcc\xb4I1+\xef\xa8\x07\x904\x85\x93\x0c\xa5\x1d\xdd\x86\x1f&\x9a\xcc\xf8\xd4\x90\xc2\x8c-\xd94\xe0\xd1\x1c\xa2\xa5G\x02,\xf5Y\xcd\x16\x96\xf9[\xb3CI.J\xb9K(\xec\xd2-\xb8\xad\xb8\x8b\x0e\xad\xb4\t\x031<\xfd\xec\xcc\xbb\x90\x8e\xaa\xb3;\x822\xe2\xee\xff\x8e\xdb\xac\x86\xc4\x0eR/S\xbeD6u\x9aY@,[\xa5\xda\x9b\x8b\xd9g\x94\xf3\x921\x15\xf9\xe4rg\x98\xe7S)\xcc\x90?\x0c\xe4\xb2pf\x9a\\\xc9\x13\xd9\xc2\xc8z6\xef\x1f\x10t\xa8\x14\xb0\xe7\x1c\x9f_z\xa1\x8b\xd7\x8b\x8et\x95,\x9cT\xc6\xb6\xc7(,\x00$\nU\x86\x00\x17lF\xd0}[lM\xf5/\x7f|fi-\x91\xe6\xff\xf4\x19\xf1\xaay\x0b[<\xda\x974\xde\x1a*3\x13\x1a\xc4\xe5\x08\x07\xb02|\xc4\xf7We\xd9\x02`\x88\xc7XS\xfc\x13L"\x82S\x9e#\xb8\xc3\xf6)\xc0\x07\xe0\xb2\x15\xc2\'\xdc\x1e{\xf95N\x8a\x18\xdc\xcbt\xba)Kj\xf0\x16\xb3u\xbb\xbdm\xa2L\xb9\x8c\xc8\x9di~\x1a\xbd\xc7\x16\xdf2";\xcc\x8f\xb0\x1e\x0f$Q\xd9\xf9\xf2\x12\xf5\r \xcf\x15JT\x9a\xd2\xbe\xea\xa9M\xdd\xa2\xe9\xa9\x9e\xeb\xe5\x9a\x03\xeb\x0f\xc6NYc4\xe1\x81\xd8\x9b\xe1\x86\x9b\xd3xb\xbe\x881\xfc\x9fC/\xa4\x9a{\x98Y\xc17\x0b!9\x97\xe2N\x8f\x9a\xba7^[\xaa\xdd\x96Bovo\xfd\x17\xa6K"nR\x8e\xfd\xde\x85Y\xdfX\xfd{\xd6\xc3\xbf\xc8i2\x97\x98e\xac\xb1\x9fb\x15\xf5\xf2\xd6\xe1U7aFC\x8b-\xbf\xea\xe8M\xea\xed\xe8\xf6j&Np\xdf\x96\xba\xc0\xe3\x0e\xab\xb1\xe7O\xd5\xb4^\xfc>\x9f\xec<\xff=\x85\xb9\x98\xf6\xac\xc5&\xca\xff\x8a\xcb\xd2\xea\x8d\xcfE\xc6\xbe\xff\xe2\xee2~|!}-\x89\xc1H\x9f,\xfe\x02\xbaHH\xf1\x8aK\xf0\x05A\x97\xe3\xf6\xb7\x04Dc\xcf\xd1R\xc3I\'n\xb2\x95\x91\xeb&\xb5\x00\xc2\xce\xdel1(\x08\xdc\xf0\ts?\xa4\xf1\x8b\xdc\x83Q\xd7j\xbf\x14\x0cjVD&.\xd5\xd4U\xce\xf8p\x14\xaa\x95\x1b\xc2#\xa0\x1a\xb5\xe1\x16\n\xa2\xccHF\xdb3\xa5\xe5\xca\x1b\xa4\xbb\xae\xa2\xf9\xc6lW\xf3A\x83t7\xa4\x85\x8c\x94\x17.e\xd5\xc6\x0b\xad\x86h\x82+\xfc\x17\xdc\x94\xcbi\xff\xac\xd3HX\xcdWN\x82\xff\x7f\xa4\x11\xd9\xa3\xcc`\xa9\xd6\xdc!0bNg\x88\xcb\x94U\x1e\xc5\x9504\x81\xe7H\x92\x91od\x0bA6o\xd6\\yb2TS(o\xd9H\x16\xbbc*\xc7\x15\x98]-W\xe7/\\2\xd4\x90#\xef\xc7\xc3\xfe\n\x0b5pU\xcbmF\xd5|\xe2\x8f\xec\x83+\x98\xfe}\xdf\xdc\x92a\x15Q\x97`w2\xca\xd2\x9e\x94\xad2\xdb\xcel5\xf1\xa1v\xc0^\xde\xb2@\x86XR\x0c\x9a\xf8\xa2\x92W,\xd3\xe5\xde\xec,\xc3\x94a\x87\x99\x1e3\x06\xb8\x88\xce,\xcbs\xf0\x05i\xaf\xe2\xe2cC\x02\xea\x14C\xf4Vr\'a\x1c\xc1Or\xbe \x14\xb1?\xb9t\xbe\xb9\xc03s\x938\x95\xc9\x08}\x90`\x1d\xf3\xf7\x1c\x87\xa8\x8f\xbb\xa5p\x14\xcc#\xd9\xa14\x00\xd9\x1fX?\xcex\x11D5\xa2\xc8Cz\xe5:\xe3\xee\xa5L\xd6\x83\xedw\xf1\xec\xf2>Q\x8e\xe3\xbeS\xa4,s\xbe\x1cc\x19\xbe50(\x9e$\x00\xaf\x97$<4\xa5j\xa1\xfaB\ri\xc6d\xd3(?\xa4\xbek\xa3\x82A\xd7\x1a?\xd74{\xb30}\x93\xdb\x8d\xda\x1d.g\xe6A+b9\xfe\xf56\xc9D\xea\xf8d\xb2\x08\xe5K&w-\xd0\xe1\xfe\xf1{\xd5\xd4\xe5{\xef\x1b\xd6E\xa4\xb7j\x9f\xbaP\xe5\xc1\xaes\xb5g9R\xd0|jr\x9a\xd1{-\xe2\xac\xfc\x1cp\xfc\xc9\x82\x8e\xdf\x8d\xb6\xb2\xa9<\xb6o]\xe5\x18\x94\xc31\xc5v\xb5\x80\xa8\xb5\xfa\xae\xb5t\x04K\x10<(\x8d\xbe\x91&\x8a\xc8r\xde\x93\x1f\xdd"\xf9\xd9>z2\xc2x<\xcc\xdfeW\xd0\xf99\xd7<x\xfe\x99P\xfa\xf95aL\x08a\xc4\xa6\xecz\xb6\xca\xefM\xd44OsTe,\xe68\xb9\xb3\xe9i?i\x94[\xce{\x1au\xdev\xc8\xac\x9d~\xa2%p\xc3\x82\xe5M\xe5\xf3\x8a\xa5\xc4TY\xad\xeb\x87\x13m\'\xa7%y\xec\x8c\x0f\xc3u\xabv\x16\xc7\x83\t\xbf\x19F\x13.\x98\xbf\xc5"0\x01\r+W<\xe7\xc9/`@\xb1\xadQ\xde\xc5\x8b\xd7\xc1U.r\x9ey@\xa9{8\xf4\x08\x91\x0f\x9f\xe7\x86\x97r\xf4\xc9M\x96]\x81R\xd2/\xf4\xbdE&\x06\x0e\x18C2.\'\xfd\xa2fy\xad\xd2\xe1\xb1\x9a\xec\xc7)9\xcb\t\x90Z=Q\x88\xb6\x87\xa4\x11w\n#\xb3\x17\xb6X\xabw\xed\xc9\xe9H!k\xc9\xe9\xb2\x92\x9e\xbb\x8e\x05X\xbbk\x1c\x98\xe6\xcc\x8ba\x11\xfc\xef\xc0f\xfc?B\xff\x11<\x08\x9e;\xe1\r\x94\xa0WoT"\x17t\xbc@R\xbbr\x8d\x95Vq[\x83\xd5\xa4I\xbd\xaf\x85\xc2\xac\xa5\x9b\xd5b\xaerC5\xa4\xfc\\t\x81\xa8Ei\xa3\x0f:\xaaZ\x8e\x9a\xb1t:\xd8\x90\x9c>\xe3YY\xbb_\xb2\x92WS\xdf\xdcP:\x8f\xf6\xden\xe6$P\xd71BY\xb9\xee \xd85\xa6\xa2\xc1V5L\x1c%\x7fO\xc3j\xc7\xb9-\xdf_\x1e\x1bXN_s\x91\xcc5M\x02\xf2\xfbm\xedv\xc6\x86.o\xd6H\x81\x15,\xc1\xd7\xe1\x9b\xd0\xca\x9ct=%\xac\xdb\x13\x12\xc0U,\x05\xd2\xc6)\x952 \x87\xc5\xa8y\x18\x15H\xcd\x99\x99\x16\xd8\xceM\x99\x17\x18\xcc\xdf\xf7\x7f\xfe\xd0\xdc\xee^\xd6M\xcd\x1d\x8f\xe2N\xde2\x89\xa1\xdb\xd7c\xa9\n\x89K\xbe.\xc4\x87\x03\xdbk\xa0\xadm\xf0\x06\xe8:n\x10\x08\x93\xba#\xbaQ\xd0?\x0e\x01\xfc\xf6\xf8-\xb3$*N\xba\x8f\x918j\xb2r\xd3\x9a\x87\xab\xa8\xea\xc1`\xaf\xa6\x94\xdf\x02b\xaa\xafk\x93\xbe\x8c\x07\x97\xb0\x03U\x9dZ\x1d\x0ct\x1a\x03[\x15{\xd8=\xdfV\xa1\xce\xbea\xfc\x92\x849Q8%c\xa5\xac\x02"\xab\\\xd5\xaa\x8dD\x8e\x07\x86\xdco\x9d\xa9+\x8f\x9c\xc8\xfd\xe6\xfa\xbd\x1c\x11\xd1\xf4\xad^\x9df\xf5\x1e\xab\x0c\x8e\xc8\xcf\r\xbb\x9f&\x9e\xf1$t\xfe\x8c\x1eP\'8F\x11\x15\xda\xfa\xd8\x92\xae\x1a\xc9\\\x8d8\xe3;}\x97\xbdt`j\x0e#L\x13\xdd~F\x14\xec\x7fw<\xfb\x1f\xc3\xde\xf3V\xf4T\xb6]\xd0\xc4\x18v;\xbc\xeb\xfc\xa7\x12\x1d`\xf4Ld\xfb\xe0\xf3\x95\xc8\x83\x94\xe1\xb4\xfb\xed\t\xba\x14\xd0Ze\xd9\xa5\x14\xe7\x92\xbc\x08BDc\xcd\x95\xf0knl\xdby\xba\xe7\x11\xff\x91\x01\xfd|Y\xe2\x11*\xe2\xd3KZ\xbf2d\xf8\xc5\xcanTY\x16\x0ev9\x18\r\xc5\xe7q\xfc\xfb\x7f\x00\xf7O.\xd2\xa4Y\xb8|:I\xe2\x0b\xf6\x88\x19\\-%\xce\xaf\xe9\xfa\x80\xdb\xba\x91\x1e\x03.\xb1`\x10\x7f\xb9\xd9\xe6\n\x8bX\x9f\x92R\x01\x1a0$\x8e\xcf=\xc6\x9d\xa0\x9f\x8b\x82\x00\x15\xae,P2TY\x16\xa8\x19`\xb2\xadd6K\x96\xa5G\x82.\xf2`P\xea\xc6\xd1x\r\xaf\x860\xef\xaa\x1e\xa2\xf2\xd48]\xdb\x10\xedI\xf0\xd0\x9b\xf8\x06\xf2W\xd1\xff*I\xfcD\xf3\xd4\xd7\xb7\xfd\xbdF~f\x82X\'\xc3rqIqW\xc8\x90$\x80\'\xbb\x1438p\xbe)\x99],Wn\xb04jIh\x88,y,\x87\x02\x99\x85!\x1a\xab\xe5\x07&$\xabR\x97\xd8\xf4s\xb3\xd8MYr`\x18yT\x8e\x98\xedR\x03\xab\xb6u\xb3_\x85\xae\xe9\x81\\Y\x81\xf2\x95f\xee\x1c\xf7+\xcd\xecPE\x93\xa1\x86\xc1X\xaa\r\x19 ok\xdf\x8c\x15\xcft\xa3"\xfd\xc8\x082+\x1e\xde_\x8d55\x1eb\xb8\x8a\x91]7\xc0m\xces\x9e$(o\x1430\xdd\x9d\x1f\x9b\xe5\xa8\xf8\x1b\xdf\xa9q6\xf9\xad[U~\xa2\xa6\xe8\x06\x9c\xcf\xb3\xef\x07v\x93\n\xd9\x84\x7f\xabKU\xa1\xee\xb4e\xe4T\x8b\xd4f+\xd8\x8fK>\xbd\xf1\x9aT\x93\xc3HLC?\x97\xbd\x15\xb6\x1e\x03\x83\xb1\xb4\xf5{\xc2\xd1\x07E\xe7cr\xb9\x10\xcb\x149\xfd}\x1c\x97\xc6\x17\xc0\xea\x9e\x01\x05.^\x19\xb8\x1c\xa3$\x9di\xc6\xbd\xc3\xc8{\x88=K\xcc\xc8\\\xb1\x82\xc1\xdc\xa3\x8dMP\x9a\xe3\xc5\xd4\xd8\x85\x93y\x1d\xfd\x81\xbc\x1f\xdd\xbeLF\xa4\xc2/\x9b\xa5Q%0\x83\xf5A\x85\x87\xe9=M\x07Z\xa1^i\xa7\x8c\xbd_4\x05\x06\xac\xdd\x8e6\x10\xa37\xaa\x87\xdcg\xea\x8a\x9f\x12z\xc6<?XK^6w\xbda\xaa\xaf7\xc7OZQ~v\x89\xfc\x14\t\x8c\xa7\xac\xa5v9^O7\x8c\xad\xea\xe6,\x92/\xac\x00\xaf:\xce\x19\x8f\x0c\x98\x7f\xb6EZ\xcb\x14\xc7\x05\xc1\xc5t^md\xe4\x18\xb7T\x86\x96\xae\x88\xbco\x16\x7f\\\t\x16y\xb2\xb5x1g\xce\xfa&\xe8\x97\x81\xdaS\x13\xbe\xa3\xbd\x83\xc8\x83\xd9\x11\x91z\x9d\x17vQG\x84\xfe\x12\xa3\xb1\x1f\xe5\x94\xe3\xb7\xef\xa1o\xf3\xb8[\xc3NR\x84\x10\xe7\xe2.Gbg\xa1\xdbk\xd0\xd7\xc6m\xc2\x0b{\xc7\x9c_I\x1f\xa6S5\xfe\xa6\ne+v~\xed$\x95h\xd8\xf2\x87V\x19\x08\x8dP\xa6\xf0\xe0\xed\xae1\x1c\xbb\xc0\xa1q\x12\xe4\x84\xc1\x9c\x0c|\xce\xc4 \xf4\xbb\xae\x88\x11X\x84\x92\x18\x84\xcdP\xdf\xe5T\xa8\xfc \x85%7\x17\x8cL\x15j\x8c\xa1\x84s\n2V\x08"_\x1aF2!\xb7\xe8\xd5\x04md\x8c{\x0e\xe8,\x14\t\xd7S\xa6K\xe4\\\xd6\xb7\x92L\xf6^F-\xa7\xb1\xbcgP\x85,xkGd`\xc2G\xfa\x0f\x01^\x1d\x86b\xf03\x1e\xd0\xc30\xcb\x01<H\xf2\xd45\t$f1 \x8d\x16 /\x0f\x97G\x9cA\x86\xf3e\xc3,6*\xc3\xb7\xc1k\x80x\xe0$s!\x7f\x07\x04U\xa5z\'\xc4\x1d\x94\nd\x1fJ\xf3\xd3\x9c\xdcH\xcb\x076\xa3\x92\x05\xeeL\xcaV\xaeYVoUBC|7\x1b\xc2\xfbM$\xc0\xb5g\x03CiB\xb5K\xcc\x85\xe3\x8d\xfeq\xfa\x0f\xf9G\xaa\xb7\xeaR\x0c\x85Q\x1c\x94\x17ML5\xf1O\xb6\x14\xd0\xd0\xc0\x19f\xd0\xf3\xa8c}^l\xc8\xe4\x1a\x07F\xe6\x94\x94\xf7B\xf3\xb7\x9b\x84C\x98\\]\xc6\x7f\x951\xdf2s\xb4\x1d\x9c\x81\xe4c\xd8xZ\x00S\xd3T\xda\xc7\x93\x85=\x1c\x9c\xc5D&y[\x9eN\x11\xdf\x8e\x92\xa0\xf6/\xaa5)\x17\x1e\xbe\xd6\xbeD0nFy>\x9c\xcf\xa7\xa5UY\x08\xe6!\x891\xa4\xa9\xea\xe2S8\x98\r.\xc3\xed\x90\x0b\xe2\rx\xf2\xf4\x18\xfe\x10(\xd1\x0b\x9c8\x1cA\x10\xd3\xc5\t\x82)\xde\x89O\xfcy\xdb\xda\xd0\xe6\xf5\xe1\xb3\xf8V\xc7\x1a\xf4\xfb<\x81-\xcd\xd3\x15\xe9\xc9p2\x1b?c%[\xe6b\x15\xa4\x91$\xdcL\xc3\x02\x03\xcd\xc6\xe8Gf\xa7ho\x19\xa5&\x06\x18\x14\x99\x00 \xc1Dyi\xef\x9d\x82\xf6\xa8)\xb7\xa7\x96F\xc1\xbd\xc7\xcc\xc1\xf6\xf26\x8e\x85\xea\xa1>n^\xf7\xb6\xd0\x1c\xde$\x83\xd1\xb2\xbf\x9b2\xda\x94\xf1\xa2\xe9\x8bI\x89N\x13\x9a\x87KA\x0f\x89\xae\x8c\xeeX\x90\x05Ro\x04\xeb]n\xebZ\x9btC\x86s\x0e\xedtm\xf8\x95\x9f+\xf4\xad\x1f>f\xcfkV\r\xba\x12\xbe\x9d\x86~fEp\xca\x93\xcf\xb3\xc4\xec\x8f\xf6\x84,_\xf0H\x1d\xd6\xc3?\xb9\xc1\xd6\x8az\xd5\xef\x91X\xe3\xd6\x90\xef\x84\x82O\x01\x15\x1f\x88\xbb\x9c-\xe7\n\xe3\xdc\x95\x12\xc8\x15\xffI\xadO3e\x1a!?93"N\xa6\xe5\xc0\x7fIhj\n[\xf2\xc8\xf9{\x1a3\x80\xb6\x1f\x00\x86\x9e\xb3F\xe2.\x88\xd9d\x1c\x87\x10\xc5D\tbh;\x05\xe5\x84G\xe0Ey\xbdm\xa7$8\xac\xb5g\xa0\xc2\xfe\xda\x13\x008R\x05C\x92\xb0\xdat\x93F\x11\x17(\xb8k=0wA\x01\xa4D\r1\xfc\x0ex%\x8b\xf7\x96\x95\x9b\xa0\xae\xa9\xafh\xb2!\xab\x90[6\xe7\x98\xaf\xa7\x92\xba5\x9d\x9a\'\x17\xd3(\x95s\xb3Y\x03\x0f@\xd4Z\x0c\x01\x0513\xbc\xb9Z\xdcM\x82`\xcdB\xbfz.\x05\xdb\x99\xb7\xd9\xa83\x1e/{\xbe\xda\x90\xf5rM\xd2\xcc[\xc8\x7f\xde\x9b\xac\x0e\xf23&\xb2`%\'\x95\x14>\xcf\xe9<\x02\xcf\xbd\xec\xad\x86*\x81\x18\xdbAj\xe2[\x19DI\xee\xdbET\xb2\xec\x1d\xd3\x86R\xce\xf6\xea\xadr\\\xd4\xd9V\t\x85\x9d\xbc\xd5\xe8\x95OG\xd45:\xcb/\xd7\xbcm4\x95\xaf\x067\x86\xd9\xbb\xb1V\xfa\xfb\xfb\xa4\x81\xef\xcc\xc8\xd6\xca\xc6L\xb4\xe8\xf5\xbc]Lj\x1bf\xbf3\x08@\xd6\xe6\xb2\x80\x9dd\x14\xf6z\xe6\xe4\xdf\x1b\xe0\xedP\xb6mi\x05$\xed\x91\x1eW\xea)\xa1Y\xbak\x91*\xfa\xac\x12V\xcb\x03w\x9e\t\xca-\xcd\x15\xa9\xee7\xec\x9ar\xa5\xa1\xad\x85\x10Bf\xf3+F\x84\xc4\xe3?\xdf\x9f\xffkF\xb9\xe6\x99m\x8f\xb9\xb2\xff{\x81B\xbcP\xdb\x9er\x1dp\xe3.cA\xaaY\xaf\x84\xa4A\x8c\xb4\x95\x1f\xcby\xaa\x1aI?\x84\xf5\x1f>\xd1b\x1e\xdb\x84;\x82{\xeb"\\\xc0R\xc8C\xfa\xb0\xbc\x81\xbct\x1d\xec\xf6(\nl\xf5\x93\xa7G\xa5\xc3>\x1f\xf0.\x8a\xc2<\x06y\xb3]]\x8e\xc9H1[h\xee\x19\xdb\x02\x18\xa81A\xb0\xab\xe4\x92=?Hi\xdf\xfa\x8aU\xc1T\xa4R\xbc\xed;\x81\xd8c\xad\xd6\xa8\xa6vH\xd0s2\xcf_\xb9\x95\xb5\xe6\x8e\x87\xe8\xa1\xe9\x10to\x14\xbf\xbdW[\xd0b\x13m\xcc\xcc`\xfc\xdaK\xdfut\x11\x0b\xee?\x14\xe5?\xc6r/g\xaf`\x0e\xd1\xe4\xd5\x92{\xb9\x92\x0f>\x8e\xd2:\x8d\xc4\x9fJ\x05\x18\xae\x8f\xaa\x19\xf1\x0c\xaag\x9c\x0b\x8ev\x1bbk\xb0\x92O\xdd\xce\xdc\xf3\xe7j\x94\x1e?\xd1\x06\x9dl.\n(-\n^c\xfd5\xf2\x99:xZ\x04v\xec>`@.CS?\x89\xfc6\x98\x9bz\x99\x16r\xaebz\xec4\'\xb1\xad\xec\xacs\x7fXd\x02w^u\xc8\xadj\x12\xb3\x10N7\xe2?\xf4\x8d\xe8X\xdf\x96<\xd3\xae\xa1\xe7\xd7]6\xa9\x1fo\t\xff\xb3\xd0\xf5\x16\x96L!)\xb4\xb3\xae\x00\xe2/\x08\x8e\xe8#\xc0\x860\n\x14\xa1n<\x03\xc97n\xa4(do\xba2X\x10\x9e4\n1=\x9e>F\x92\xb4\x9e\xad\xe6FQ\xe9C\xb8\xbb=\xda+\x17/T\xa2j\x88\xf2\xec`F\x16o\x97\xear\xb6.2\xe6\x93\x9dh\xcc23\x086\xc0\xef\x91\x0b\x16t+\x02J\x8d \xd6\n\xa5\x03\x97\xadx\xcc\x91\x9b\x12v\xf0j\x95\xb5b+k:/\xb8@\xa5\xcf\xd8\x0e\x8ek\xf2\xe6\x94\xe896\xc8-x\xa6=\x0f\x0ch\x9f@\x9b\xb9\x1e\xd00v\xd2sM2\xec&]=\xab\xa4\x02m\x13\xc1\x8a\xc4\xe6X\x1f\xb3+\x8a]n\x88\xb0\xfc\xf7h\xaa\x7f\xfa\x16/\xf8\x86b\'k\x96/AO\x8e,\xc5\xa9=\xd4\xe0B\x94G\x80ko5\xb9\xe0Dk\x85\xd7q\x1f\x84i\xc2\xc9\x0f/PM\xb7\xc1\xe2\'&r\xd5\xe2\xc1!\xfaT\x94\xe2\x99\x04\xb0\xb2\xdd$\t(.8\x82\x06[\x8eY$\x81\xc5\xa4\x98\xfd\x13\xf7\xd6\x01{\x8f\x17^\x00\xf4y\xee\xb2\xf2\xd2\x85\xef\x06\x9a\xec]D\xfa\xd3\x88u\xe2\xeb\x8bT\xa9r{\xed\xcd\xfe<v\xba{.\xdev\x13U@\x04\x82\xf5\x8b\xda\xc9\xaa\xcbevE\xa8\xe5\xa7hn\x1a\xeb\xcb\xf6\xbfS\xf7\x9e_8\xba\xea\x89\xd3;\xa2#p\x8a\x85\x13\xdf\x86Y\xe0\xf15\x92\x9b\xc2\x81\x87\xa4\x0c\xd2\x1f\xb7\x1a9\xe7\x16\x03\x1e\xd7\x0e\xcb\xd1\x8b\x87\xde;\xf3-\xf5y~[\xef\x1f\x90\x9d\xeb\xd4<mJ\x0e\xea\xf9^\xd8\xb3C\xf8/\xce4\x1e.\xb1\x93\x84\xa4\xe1\xf0t\x11\x8e\xc72\xcd\r\xf8\x01\xcc\x08+\x01{2\x1at\xb7\x19\x93\xbf\xc5\xe4\x9e\xd6\xc2\xd8\xdb\x0f\xfd\x17BB\xfb\x83\xee\xc2\xe3z\xde*;\xe5\xab\x88\x12\xbd\xbfY:\xfc\\\xb9f\xdc\x9a\xac:\xa8;\xa6\xf8]\xfb\x07;z\x8e\xf16\x89\n\xbc)\xe8\xe4\xe1\xf6\x11Z\x8d\xa1\xe6\x98\xd1n\x9encu\xd6ES\xc3\xe3\x0f\x1b\x9ddB\x06N\x1f@\xbdR\x0f\x18\'\x87v\xab\x91\x8c&gZ\xc3s\x1a\xdf\xc7t\xce{\x97h\xdc\x0b\\\xed\x8b\x90\xf4\xaa\xc7eg\xa2\x1a\xb5\xe5=]\xeap\xb27\x84\xc6=B\xb2?M\xc6\xed\xddL\xd1\x92\xa3\xb4\xda\xbc\xde\xab\xfftW\x82W_\xc5\xdb\xe44\xda\xd3J\xf6\xf8\xf8\xce\x0fo\xb1VRW>\xb6M\xdd.T5\xfa\xb0\xe2\xdd\xbf\x9eb\xfd\xdf\xcb\x17\xff\xc6c\x1f\x1c\x88\xcc\xa9\x0c?\xe0|\xc54\x8el\x95\xa2\xa7\xc3\r 13|\xec\x86d\x84\xa8\x88\xb66\xa4\xff\x83\xa6\xd19\x04\xf5\xc9n\xc48\xedS\x96$q\xefSV\xbc[\xe1)\x03\xe9cb\x81\xbf\x19\xd7x\xeaFp\xbf;0\x08F\xad\x9e\x0e\x02y\xe9\x18j&\xcf<b\x1e\xa8#h\xb7\n\x86\x8e\xb0z\x12\x1dq\xd2\xcc\xd9\x86\x86iI@\x95\x7f4)\x05\xfd\xc4Q|\xa1\xe3\x8bM\xabL\x1b\x19c\x0f\x1bh\xc8\xc4\x1a\xf8R(\x8f\x8c\x02\t\x07\xa8+\xb1\x94Y|\x0b\xb4\x9e\x8cY\xb1\t\t\x9b\x184\xd3u\x14Z\xb1\x11X\x95\x93.\xbdT\xc2\xbc\x8a\xf4\xc8\x97k,T\xbdf\xd9\x90\xc4O\x14\xd8\xa4\x1aM\x1e\xb3\x88\x92P4\x12\\7S\x9a\xb9\x0e\xbbow\x9bK\xb4\xf4\xe7:5\xec\xccF\xa6N\xf2\xd8x\xb9h(\xc3\xde\x95Q\x90d\xe5G\xd1\xc3T\x96l\xb7\x81m\x99\x02\xb2%\x03\xf5\x98\x1f\x81,\x97\xa5;\xe92-\xbb]\xd3\x9a;\xbb\xdd3\x86e\xf3\x1c\x0e\x9b\xf8\xe5z\x87BS\xc5\x8b9]]\xf4\x8a^a\xf9o\xd1b\xcel\xed\x0f$\x9d\xfb\xe8\xb8\xff\xdd`2\xa2\xac\xde\xc2\xdee\xe7A\x1d\xf5\xe4\xf3\xf7!\x97\x8a6\xf7\xa7\x82\x1f|n6F\x90\x13y\x17|\xc8\x15\xbc\x9b\xca\xb9\x07W\x8c7(i\xe7\xbfX\x06\x11\xfe\xf7[jx\x13\xa7\x02q\x8es\x90\xce\x1eu\xe6\x05\xfe/(\xcc\xdc\n\xb87\x01\x01c\xc7\x05B\x80\xd0\n\x97\xf7\xad`\xcb2o\xadQ\r~\x19"\x1d\xc9"\x8cG}\x81\xa2\x93\x14\xecA\x8b\xdc\xa4n\xed\xd9q\\\xcb;y\xc8K\xde0\xbc\xd1R\x18\xbd\xbdbS<_\x1aC\xb2\xbcm%I\xbf$\x11\x8fL\xbaE\x1eg\x9f\xa9RU\x08\xfbc\xb1\xa7\xda\x87\x86\xdfTw\x0b\xbd\x03@\t\xdf\xfaJrQ\xba\x95$;\xdfN\x93\x18\xafu\x8e.\n&\xe7/:\xbd\x9b$\x95\xc0\xbf^i\x18\xb2f<\xe9\xe15wU\x9a\x14\x87\xe3y\x14\xf3\xc4\xdaNcX\xaat\xc0\xd8\xafq5\xba[\x99\xc1\x85\xc3O\x96\xb76gf`\x05\xf31g=\xe5\xef\x85\x82z\xb8\xb9\xd84\xc7.uk)t\'\x1c\xde\xda\x7f\xf5\x9e\xb3r.\xa6c\x7f\xf0\x1e^G>\xa3\x86\x8dD\x97\xde>\xbeY^\xe6\xbf\xc5[\xcc\xf3(3\x81\xca\x15\xdc\x17\xf0>\xe0\r`\x83\xfb\xbe\xc1\x8f\xc6\x1d\x9ey\xc0U{\x1dU\xe6\x02XY\xa4^\x8cw,\xe8\xfb\x8e\xe3\x86\xca\xe10\x07\x10YKP\x80\x18n\xb2\xf3pq\x1f\'\xc1\xfd*\xf15\xe2\xe0z2cLDhR\x93l\xf9,,\xd0l"\x16*\xcc\xb7`I\xe0\x15QWl\x07\x9aM}\x9eDe\xd5Pe\xacdk\xc7h\xe0\xb3\xf4\xde\x1a3\xdfT\xdaot\xb3\xe1emZMW\x13\xdar\x97tz\xd5(\x95+BWO.P\xcen\x14\x00\xdc\x96\xd7\x912\xb7q/\x91H\xb6\xafX\x90~\xa8\xfa\x18\xe1Mt\xach\xaa5\x17o\xdfJ\x87;`\x97\xbdsyF\xd4S\xcb\xdb{f\xd7+4\xd7\xd9\nR\x03\xd2\xe9\x0f\x0bqE*|<\x01\'\xf4\x87%8k\xbd\xdb"\xb6\xfe\x8c\xbb\xf9ij:|\xdc\xa1\xde`:\xa7khlC\xadf\xd3\xc0\x88(nz\x11\xc8c\x9fD\xd8,\x1c\xbdk\r\xf6\xcb\x15\x00\xdb3r\xd0\xfe\xf6\x0c=\x1ec\x15<\xeb\x93}\xf9H|\x92(\xd0^\x89\x8e\x18\xee\xbc4=\xbbUn\xcei6\xf2\x987\xd8V\xa2\xee\x96\xa6\xbe\x0c^\xbb\xd5D\x16/\x1f\x12\xe0\xf9\xe4\xc26]\x16\x7f\xffHG\x19\xd7t\xf4{\x18\x17\xafO\x0f\xc6a\xdbc\x1f\xe1\x0e\'u\xbe?\xc8\x9cd[\xc3\xc9\xcf)\xc8\x10X\x89iub\\\xd7a\xca\xa9\\a\xfd\xdfD\xdb4\x1b\xf5E\xb0\x9a\xee\xa95c/r\x0f\xbb\x07\xf1\x98F\xd8\xf5$(@)\xb1#\xa3$\xc7\xb7\xa6 1v\xc1[\x00\x06\xc5x\x0c\x8e\x14\xdd\xc4X[\x0f\xab\x93d\xcb$\xc9\x1c\xe8\xef0v">\x19H;\xcf\x99\xf8R}w\xef\xa3\xff\x8d\xaf5\x8c\x04\xd6\xc0>\xbe\xed=\xa1\xd2\xad\xebY\x83\xb4\xa3\xb9\xec\xdd\x1d\xd8o\xd7?\xf6a\x96:\x1d\x01e?\xf7\x0b Hb\x1c\xce\x1a\xf6\xde\x17\xceU\xea\x0f\xc5\x07\xbf\x8b:/\'\x1f\xfe\x91n0\xfaZ\x08\xe3\xfc\xe70\x1d\xd3)\xc1\x99j6_=O;\xba\xe1\xaf\x81\xcc\t\xf4^T\xbb\xfcJb#b_\x17\xd43.\\c\x94\xa1\xf2*\xcf|\xfb\xb5\xa7\xed=\xdd\xe3\xa50\xbfE\xa1\xe4\xf7\xed\xa2\x9c\xd1cvOE\xde\x1ceYF\x1c\x8c\xf6\xa6\xd9\xec\x86\xc6w\xba\xad\t\xa8\xde\xb9\xea\xcc\xa5v\xbc6^\xe5\xf2\xc8\xf8\xe9\teo\xd4\xe5\\\x16t\xaf\x13\xb81\xf9J\xad\xe0\x03J\x7f\xb2\\\xc7\xca\xfaQU\x85\xde\xc9\xfcC\xd6\xb2\x1e\xec\xaf\x06\x87\x9b\x07=\xbaZ\xef\x9a\x85w\x89\xe8E\xf9\x99\xcf\xbe\xd3\x8dF\xd5\xa1\x8f,=*p\x8d\x80_\x9fq\xef\xbcd\xab\xc1\xaf\xfe]\xae|`U\xbb\xe0\x80\x13\x05\xdad\xe3T\xf7\xbd\xb3qJ\x9a\xbf\x908\x94f/\xf5\xc1\x06\xa0A\x0c\'\xb1\xaf\xb9\x82\xd3\x88\xb2\xae\xc0C\xa3\x8a\xbe$_+\xb4]\xcc\x01\xc8h\x8f+\x0eN\xa3\x89\xc9\x02Q[=\t\xbe\x01\xd2\x98\xb9\x8c\x11\xe8\xe1T\x01"\xc4\x08\x15\xb3.d\x04\x16\x90\xcf\xdb\xa8\x8aE\x86\xbaBq\x82\xc2\xa6P@\xbfk#E\x993\x06-\x9e!\xb84\x0e`\x91\x17\xf6\xa3d\x0177\xeap\xf2\x12\xcbB\xe5,qD\\P\xca\x99\x8f\x08\x0b\xaf\xbf|e%\x90<\xdc\xec\x12\xb3\x8e@\x00;\x88\xfa\x1b\x0f\xca\x88K\xdb\xb8\xe80\xe1T\xbc\xc4ih\x93x\xbcp\x0c\xbe\x99\x10\x85\xf6#(\xa3f\xc7$R{(\x98\xfa -\xe6\x8f6\x12\x00\xf0n\xd9{\xf2)jg\xafw\x99\xa8\xb0O[-\n\xd8\xef\xdb\xaco\xd9\xef\xdf}\xb2\xb3\xff\xf4`L\xe1\xfb\xb3\xe3\xf9\x80\xef\xcfO\xd7?\x06\xeb1]\xb5\x01'
SEND_IMG = b'\x1b\x84.\x00\x1e\x85q\xe3\xf3\xe1\x92\xb5\xc9ZDq\xf2\x9ak\x84$\xb3\xfe\x17M\xf5\xe9\xa28\nk\x1a\x05\xedN.\xac\xc8\x81\xab#Cy3\xe36@\xdbZv\x806,\xc38*\xf1\xbf\xa2\x02\xac\xb4\x17\xde\x92\xe7L\x01\x94\x83\x1b`9s%V\x03\x84C\x94g\xb3A\xe3\x8f\xa7\x9a\xc6\x17}P\xa1\xd5W\x94\x12\xaa\xde\'\x12\xb4\x82V\xbc\x91\x96:\xado)\xfd\x90\xea\xa7\xfdq\xf5V\xab\x0f-UN\xfa\xa6G\xf9\xfb\x11\x91j\x95?A\x83\xf8\xb2\x07\xbc\xdb\xfe\x1e\xa0\xa0\x96R\x86\x96\xa6\x98d\x8eJK\xcb\xb2\x12\xb1\xb1\x9c\rQ\x1b\xb6\xb44Q\xbf\x96a\xa4Ak9s\xac\x96\xb6\x14\x07\x92\xf1\xc9T\x9c\xe5Z\x94-,\x8brM\x14\x19\x7f\xdd\x9b\xda*H\x02\x14\xd1\xa8Uj\xbdy@#\x1a:\xdc\xd9K\xdd\x7fusT\xda\xdb+\xad\x01Fc\xc7\xa1\x0f\xc0\x87\x9f2\x07\x88\x01\x8as\xc3\xe6j\x14\x0e\xceAKm\xc5\xd2\x87\x8e\xe3\xfa\xdc\x158\xae&I\xa1T\xd3\xdc]w\xcdo\xa0)\x0f\xa0q?\xa7\xed\xfb\x01\x1an\xc3\x9e\x94\xd3|\xfd\xd4\x97e \xd7k>\xbb\xb6\xc2\xcaf\xed>\x00\xb8\xa7\xd8\xba8\x02\xd6\xc4(\xdc\x0f\x95\x01P?\xe2\xe4}\x0e\xd0d\xf7]8B\xfb\x99\xaf\x8e\x01zh\xee\xd9\xeex0\xc2g\x88\xa7\xac\xf5\xeb\xba=2;\xda\xa7_\xf1\x14_\x0e\x16o\x0f\x15\x9f\xe4\x19\x1cX\xe0;\xec\xfe\xfbdr\xe4N\xdf5uk\xed\xb4\x17\x04\x0f\t\xed\x15\x92\x89|^\xfd\x9f9\xbb\xf9\xcf\xad\xf4\xec;\xffA\x9f\xac}6\x983\x19E\xc7\x0czw\xe1J\xc6\x85T\xbbK\x05\x8d\xfe\x92\xdf\x19\xea_\x90\xa3\xde\xa50/\x95W\x99\x9f\xc9\xfb\xe4gM\xfa+\xfa\xdb\x97\x92\xf7_]k`\xf1U\x9aS6\xbf\xe0\x9b\x95\x99\xab0`j\xd2/i\r\x16\xa8+\x8b\xc6?\xef\xa7\xf3\xc8\x08\x18\xd4\x19\x83e\x93:|\x11{R\x8bAK\xfczq*\xef\xd8\xf0b\xfc\x83\xfaN\x02@xP\x89\xf0\xb0\xf3<\xbd\xce\xd45\xf3o;|\x8d,4hw\xfdu\xd8\xf8\xda`p.\x00-9|\x14\xc2\x15L)\x07\xc97K\x7fBmq\x15+\xbf\xe6\x08\xa0n-\x07x\xbd\x07\x19\xd5\x9aLb\xd8n\xe6\x14\xd6\xea\x8dni\x830\xd7\xb7\x82\xf5\tp\xf2a\xc6\x84\xc8\xa7Z}\\\xf8\x88\x9e\xc8\xa6S\x11 o\xf7N\x88\x104\n\xe3\x12\x96r\xe7\x8f\x8e\x9b\x92\x07\x11\xcf\xc4\x8b%\xfd\xe2\x93s\xc0qv\x88k\xb3\xf2\xe7\xfe\xca~\xb9\xeenn\x90\x9a\x06P\xf5\xbd\x15\x11\x9b\xecz\xd8\x8a\xbf\x91>\x0b9\xe9\xcb\xe5\x82\x12[4\xd0\x8cj\x07\xaf\xf7\xe4\xcb\xbf"\xf4\xbb\x05\xae\xec\x8aT\xfcg\xba\r`\xb5\xfa\xa6\x12).\xe1Ns\x1e\x89l\x7f\x9eH\x87@k\xbfY\xc0\xfa\xf8\xef\x1f\xeb4\xb2\x8c\xcb\xa9\xc9\xa9\xf8\x7f?\xe6\x01UFEB\x9an@\x83C\xd7e\xfe\xc2\xcc%{\xd3(\x11\x01\x90\xdc\x10l\x00\xb9\xad\r\xd3\xb0ej\xca\xd6C{\xc8\x91\x9e\x08\x10\x7f\x1d\x84EvY\xad$\xf7\xe7\xa1(\xfcL\xa1\x8c\xc9\xab\x96\x07\x12.\x97 \x83\xef\xe4\xf9\xce\xce\xdd\xc0\x82\x7f\x88\xe1,\xe5\xdd\xa7"\x90mq\x06P1*\xad\xa2_\x9b\xdc\x9b\xb8[\xf4\x85\xe7G\x00\xb4\x89z\x0e\xbc\x97\x90#K\xbb\xdeV\xed\xaf[-*\xa9\xf9\xb2\x05\x07\xb4y\x88s\x82M\x0b\xebj\x94\x94\x19\xcb\x80\xfe\x7f\xf2P`[\xd8\xeb\xe1\xcb(\x88\x06QC\xe2\x82u\xfe^\xfaX,i"\x03\xec\xe2 ,]`\xec\t\xa3\'\xb7\xdfY\xd6nL\xc6\xa5\x19\xe0\x80\xb3\x02!o\x86\xdc\xc1}e\x17\xc6\xb3\xcd8\xf0\xf7}\xcb\x99\x85\xae[1\x90/\xfc\x0f\xf5"\xa6\xf7\x06\x0f\xf0\x1b\xb9hSw\x15n\xebi\x0f@\xd1\xefo\x88\x9e@\xec\xae\xe4;8\xf6\xd8\xf7\x952\xb9\x14\x12\x1a\\!\x9d$\xa6|\xa8\x85_7\x0b\x15\x9e[\x9f\xbd\xfb\xdf\x7f\xbe\x04@ \xea\xcf\'\xd9\xbb\xf2\x8dG\x92\x1bX\xbf\x8e=>\xd9\xfew\xae&\xa6V}!\xd0\xa1Cv`g\xbcT\r^t\xf5MP_\x8d\x96\x86\xcf}\x95l\x98$\r\xbb\xb8@\x8a\xce9\xd9V\xb6\xfb\x06sM\xb2\x87\xcen\xc3\xb8\x00+\x1bh\x0e\xe0`D*\xa7\xf0F\xbaD\xf5.\x04\x1e\xb8R\x04y\xde\xdd\x9d\xdcY\xd8f\xb5e\xde\xc0\xfb\xa2R2\xc0_\xc6E\xd3n\x87b\xd5\xda\x02\xfe\'\x13\xdc\xfb!\x04@\xff?\x0b\x10\x1b\xf6\x9c\xd6yT\xd0\xc0\xd0\xc1\xdc\xf5\x87 \x17\x05\x13!c\x11oVYj\xfd\xa9\xceh\xb4\xb9y\xf2}9\xb5\xf9S\x1f.\xc7\xca\xc2\xd58\xcaM\xca\xab`\xa3\xa0\x06\x1ep\xa5\xbd\x0b\xd0\xa8:Ua\xeb\xac\xec\\\xbe\xd0y\xa5\xda\x1c\xad\xedA\x1e\x80\x93\xd1\xef\x81\x1c\xa7h\x9d8\xb4\xd3\xf1x\tF\xbb\xad\xa51\x03\x08@\xfc\x8dVp\\\x1b\x17\xdc\xd3\x8c\xe8L\x1c\x8e"b\xbe|~\xbf9\xd4\x0309Z\xd6;\xf9\x19k\xe0-R\x91\x04\xbf\xa4\xe4\x92A\x82\xe6\xcb\x03"\xec\xd2\xc8Q\xf7a\xed\xb1\x8a3\x99c\x17\xf2[\xf6\xf3b\x08\x80\xb2\xd3\xef\xf5Y\x19R\xa6\xd8891\xbe\xd1>\xe0%EV\x94\xe5\xaf\x02A\xa8\xc5\xa0}\xc5\x94\xa5\xd8\x88>\xb0V\x14\x11\x85\x8b\xaf\xca\x1b&^-w_ZD\x02_\xe2\xf4\xab[\xce\x91q\xef\x8fd\t&o\xa27\xe7\xa6\xdc\xd8\xae\x8f\x1c\xde\x82\xca\x002\xea\xbe\xca\xd0\x05F\x1d\xed\xce`\xb8\xcdC[6V\xceoYv\x15@\xec\xa3r\xd1\xfa\x87\xb36\xb6[\xbd}\x87\x83C\xc7\x1f\x9cl\xff\xdb\xe3\xe2SL\x00\xa4\x07\x1e\x85\xa4\xcd\x93\xb9\xd6\x81\x9dD\xccM\xa5O\x04\x9f\xa3?\xecCZ0}W\xa3\x08\xacY\xd1\xb7\xe7\xf3D\xd8\xfaev\x98\xa2\x19`l\xedkK0oJ\x15y1R\xb9&\x1a\x85\xa7~v}0\x0e\x9e\xb2\xc5\x80\xc7\xe4b0\xcf\xa7P5\xe7g2~&\x97\x0c\xb0\x8c \x9a\xf1BX\x19\xdff\xb5\xe5H\xd9x\xa9l\rBgY,\x9a\xfb\xdf\xe1\xd5\x836\xab\xd3\x8e=R\x95\x806\x91E/\x87\xce.\x97\xd0\x02<\xf3\xb3\xa8\xc9\xa5\xfc\xe9\xcf\xf3\xe0\xa8$\x98 \x9fF\xc1\x8a\xaf\xb2\xf97\x1b\xeax\xaa\x11"\x02\x90\xaa\xb5\n\xecH\x1a\xa9\xd3^\\\x18\xeb\xbf\xd0Vc\xfb)\x020\x96\xbb\x0e\xbc\xfa\xbd~A\xff\x87\xd9\xc8\x9b\r\xc2\x00|\xc4\xd7* \xbd\xb4T\x83\xc7Rf\xbf\xa7I\xb2S\x8csyc/\x01(\xed\xd6\x942S\t5r\x1f\xda\xaf\xac\xbf\xd7PQV`\xe2\xb49\xaa\xaaE\x91N9\x00\xb6\xa2\xdd\xe1\x95\xa5)gX0\xb7A\xbaI\x90\x06\xf0\xd0\x044\xba\x18\xd2\xae\x97oT1\xcfd\xdf?<a\xabWL\x00y\xd5@\x0b5\xbd\xce\xac\xf2\xd6\xf0Ld\x85&\xda\xf43G\x99\xd0U\x05\xa4>\x9c\x1bJ>\xc1;\xf5y\x7f4\xfd\x9e\xa8\xca\x9c\xee\xa5\xba\xed\xefc\x14\xfc\r-Bp\xcf\xf3)RM3\xa1\x0f\xa4\xe1\xbfm\x1f\x12\xed\xc1\xab\x8f\xad\'\x80\xac\xfe\xa6\x03\xb9\x1e_\x93\x8c0fI\x1a>\xa2\xe2\x8c \x86\xaa\x82Xk?\x8a\x8d\xdc\xa0aF\x11\xd55S\x17S\xf9u=\xc0\x89\x17\xd3\xf3)\xca\xeew\xd3\xd5\x8c\x8a\xf3W\xfdT\xb7%\xf7\x9f\xef\x8f\xc0d\xb0\x0b\xae\xda\xa7\x8fdC\xb2\x88\xe5V\xcb\xc3\xdf\xd5\x8f\xa6\xfe\xfd\xfaH\xbaB\xef\x9f\xd5\xe7\xbb\xd1&w.\'h\xaeS\x17DX\xa0R\xe5M\xebB\xd55\x8f\xdaxV\xca;t2\xee\xfd)\x98u\xea\xfezh\xb0z\x1a\xcc-a\xf7\xcb\x0e\xbb\xdf\xc6H:\xbb\xf7\xfd\xe9QS\x7f\x04\x89\x96\xf3\xf9\xcd\x81{V\xfc\xfc\xb8V\x10X\xbd\xfc\xaf\xa81\xbfO\x11\x86]G\xd4\x97+\x97O\x93\x8e\x87\xa5\xa6\x9c\x9f\xf1s6\x95\xbf!\x00-I\xfdF\x9e+\x9a\xb6,\xfc\'\x95Kw|\xc2$\x80\xba\xeeb\n\x13/\x11\xd1\xe3\x97\xe19\xfc\xdf\xb7\x9b\xe9c\x9e:\xa8\\\xa2\xec~\xf7\xb8f\xd9q<\xa9<\xc6\x06\x94\xa6sHop\x04i\xe9\x1a\xa7\xd4\x95\x8e\x19\xa5X\xa6\x88\xf1\x08\xa0\xf3\xdeR \xc3\x84\x0e\x82\xa9\xeb\x9f<\xcf\x04\xcf\xcd\xb4\\s\x95\xa2+Q(\x88b j\xbf\xa6\xfb\xddj\xf6\'\x0f\x1b\xde{\xb4\xe9\x17\xf0\x92\xe9E\x00\xa3|\xbc\xb0\x92C\x06\x9f\xbd\x89vW\t\xddZJ\xc9\x97\xe9C\x8e\n\xee\x85\xdcc\xdd\x08\xf5\xbc^a$\x01\x94\xbb3/`\x17\xa3\xcd\x81\xb26\xcc\xdb\x94\xcf\xd5\x1f\x12\x85S\xa0\x17\xdcZ\xf8\xba\xec\xb8\xa0\xb3\x8d:\xfcm\x8e\xd4\xa9\xfc\te\xe5l5\x19\xc1\xe4\xd7\x90\x9e\xa0\x8c\xda\xf2D{+\xfe\xbf".\xdalI\xc5G|\xaf\x02\xe7T\x07LX\xa9\x8f\xbcD\x8f\x0b^\xf8Wm\xc9\xe4B\xa0\x0c\xdaDI!\x99\x19<M9\xa2OS\x8d\x1d`c\xe5\x9d\xe3\xcb\xae\x02zqGr)-\xd1\x93\x86\x89y\x8a\x05\x04S\xab\xbd\xa6\xf6Vy\xc3\xe4\\\x14;\xea\xec\x00\xc7\xe3\xea\x1c(\xb3\xe1qY\x18m\xe5\x9cmO\xb8\xeea\x02\x141\xa5\xae\xc0u\x0fp2\xa7\xf0\x1a\xec\x1d\xb9\xdb\xa7m\xc0\x02\xb8+W\x0e\xff\x9f\xa2\x9a\x1eqy\xfa:\xcc\x9e$\xffX\xad\xa0d\xef\xd4\x90I\xe5li\xef!\xe9CVFt\xfd\xc0i\xef\xddUw\xb1\x8f\xc6k\x80\x9d\xd8\'\x8dyZ\x17,\xdd\x83RS"\xfe/\xfd\xea\xec\xe6\xad\x82\xa2P[DO0\r\xc2\xfcl\'\xd6-\xd6\x1b\xcd$\x83l\xa7s\xd1z\x08\xc9\xa8\xdfD\x989\xd9\xc8H\x87\xd8\x9f\xb6\xb3j\xfa\x94T\x9cFz\x92n\xfd\xa9f3j\x7f5\n\x0b\xadK\x80\x1c\x7f\xce\xcaXn=\xfc\xe1\x8c\x00\x7f\xbal\x8d\x0bU&\xc5?\xbe\xcd\xca<o\xeb\x96\xf5\xa3ud\x90\x9dt\x1eZ\x0f!\xc2\xe2\xdd&\xc9N\xa2+\x97%Q\x8f\x00\x1bo\x1b\xd6d\xc5W\xfbd\xc3\xca\xa7\xe0\x82\xdd\xbc\xa3\x11FTD\x9a\x90\x13\xb8J\x98\xf7\xa8^\xb5\xf5\xc0\xcf\xbd\x8d\x03Q\xa23\x82\xd0\\\x143j4\x83\xe8\x7f\x86`\xc8k\x9dN\x9b\xf9#Y\x82M\xdf\xff\xd4\x7f\xe9\xfa\x90\xb1x\x85\x05\x8e\xd74\xa3\xcd\xa3d\xcc\xa8YXy\x84\x064x\x82\xeb\xcez{p\xe1\x8f*\xdb9DGF\x1b\x97\x12\x9au\x92lG\xf6\xe7\x025\xd0\xc8P\xd3S?\xa6\x05\x93 \xbb\x95\xc7\x08-\n\xfa2~\xa6\xdd\xc5\x87G\x80\xc4\xc7A4\xeai\x90\xf1g\xdew2n+\x05\x0f\x86\'\x17\x83\x1a\xfd\xcf\xb2\xca\xa5LV\xbb?\xe9\x8b\xc7\x8c\xa9%@\xe2C\xa4p\xc4\x0e\x8f\x1b\xf6\x1f\xd5j\xc6\xebrk\xb1\xe4*\x19D\xf4i&V\xf7\xf2~\xab\xca:\xe1\x17\x9ce\xdem\x98)jj\x9a\n\xcbE)\xbfFC\xc8]&j!\xc3\xaaU0\xff\xba$\xa7\xe17\xae,x\xb5\xb4\xda\x81\xb2K\x97Ro\x99\xcf\xbeq\x80\xce\x05\r+\x7fh\x1dmX3f\xcdT#\xe6\x1bj\xd8\xb5%i\xfa\xb6\xf6\xd1\x01~%\x9cK\x0f_6\x7f\xaa\xee\xefEy\xf5AL\',\xf0I\x9c0\xc7\xe3\xacwT\x87\x87\xe9\x92]w!E\x15\xd7?\xda\xd8\xa7\xaf\x8fX/\xda\xac6E\xb6\x97\'\xcc\t\x940\xe1\xee\xe8\xb9g\xbd\x0b:oL|\x87wih\xae\xfe\x08\x1dN\xa3\xc1\x01m\xe2^\xc1\x01\xdf\xfcp\xc7\x9eW\x1e\x90\x8c\x117\xaeh\xc9\xa4\x08V?.7\x8b\x1a\xf9\xcf\x97@\xa3\xda\x045}\xf5\xe9\x11\xae*\xebt\xdd@B\x95\xfb\xff\xf7E\xb7\xc8 : 6\x7f\x8f\x05\x12\xbe\x11\xa8.\tn\xb3z*\xcd\xaa3Yd$\xf8#\x15M\t\xea\xb6(.}\n\xfe\xfb\x91LA\xd7\x12\xe1\xb8@[\x1f\xf1_\xbd\xf6\x03\xb1\xfe0\xa2\x7f\x16\xe1\xcbK\xf86\xf5`\xc7\x9b\x8fT\xe0\x84\xea\r\xec\x85>o\xef\xfe\x1d\x87TX{{\xf9\x82sFxw2\xff\xf1\xb5\x81\xe9\xf8\x0b\x8c\x1d_Z\x1csQ6gs\xfe\x07$\x96\x0f\xc5\\\x86\xbf\xcd\xed\x9c\x99\xda\x89[\x1f\xcf\x0f$P\xe6\xd7\x92\xe0\xf8\xa5\x07\x196\xddg\x8dz\x8e\xf10\xda\xcd(\xfc\xccK2\xf2\xb3\xd3Z\xab\xbfC\x14\xa3\'\x81\x95=\x99\xe7n\x1dk\xe5\x9e"@s\x8a3x6\xe9Vi\xa8\xd2\xd9;\xf3\x0f\x10\x9eR\xef\x90\x022\x84\xfc\xd6\x96\xcc\x92;\xfaq\xac@ \xaf\xb0\xe4\x03\x06\x90C,\xe4\x03\xc21l\xf9\xd6+\xeb\xea\xa6\xe3\xef\xe2\x046\x06\xd7\xf5F\xfd_Oe\t\x02.\xd6hL\x9cF\x89\xcd5S\x88\xc7\\\x05g?\xa6\xb681Cs\x91\xc8\xd0,S\xf7\xb0\x9a}=NV_d\xd9\x11\x0b\xc4\xbe\xfd\x1a\xf1\xb0\ns&\\Tyh\xb8\xa2,\x83o\xda\x1a\x85\x92qK\x8b\xe4)\xde\xc8\x12&\nH4\x8c\xcc\xdf-\xa9\x941\x13\xfc\x11\xaeV3\xdd/}\xf8\x06\x15\xfb\xa3\xf0m\x90\xaa\xa4\xd4\xc4U\xe6N\xe6\xb0@\xd0V\x1cxaW\x1c\x8f\xfbJ\x7f\x009~QV\xc8Yl\xa1\x83y\x18\xa9\x01\xaf\xf9\xd3 \xf2.\xf7J\x86AC;\xb3\xdd\xa5\xd2\x17\xbd\xff1Jx\xdc\xe5Iy\x9fa\xc0\x8a\x87\x8e\xe1\xedW\xc8\x05\xbdT\xc4\xb0\xab\x19D<~\xbb\xf5\x91\xf0n]\xf2\xfc\xbf\x95\x0b\xf5\x1bz\\E\xcf,X8s2\xb0\x89C\x81.mz\x85I\xd2\x14\xb4\xf3y\xf2\xa25G\x0b\xed\xf1_\x92 \x1e\xbc\x08\xb3<\xee\x9f\xb0&\xb4\xb9\x8d\xaab\xe8\xd7\xa0\xa9\xf1\x04\x05G\x87\x1b\xc231Zc$.\xfe\xeb\xbd\xa0];\xac\xe4\x17\x11I\x89\x95v\xef|\xe2T\x90\x93p+\xbc5\xa5\x99\x00\x9d\xbd\xa2\x81\xe3\xe1 \x91{4\xf8.\xa4\xa6o\\\xfbpo\xf3\xef,\x01\xa6\x1a%4\xea\x9fa\xf5\x0f*?\xb4UE\xa2\x8b\xfd\xe4\x88\xa9\x119\xc1\x7f\xfc5\x19\x99\xf9Z\x1b\xd1\x93\x9clQ\xd4\xd5\x82\xd4\x01#d\xae\xb0\xb8\xdb>\x18\x97w\x01?\xa9\x0c\xc8\xb4\x95\x7f\x197\x19\\#O\xe9N\x8f\x8e\xf3\x12\x0b\x03\xed\xc4fw\xaf\xa5\xb5;\xb7|\x0ee>O\xb7\xb9A4\xf2,\x96\x02\xd4TR\x9eqK\x84\x81\xfbB?i\xd9\xcf\x03\x80\x9fn\xc2\xf2\x86\xfd\x91\x8bIVW\xce\x14\x88\x99n\xea\x88\xab\xcdCl\xd6pP\xef\xc7\x81\x8f\xbe\xbbX\x94\xfc\xbd\xef/\x0fK\x8c\xe5\x1e\x7f3U\xa3\x90j\x84\xef\xc5\xe7\xe5\xdaK\x1bX@\xd4\xed\x96\x8c\xcd\x8c\x97\xb8\xd6\xcfm\xd1|}\x18\xf9s\x129\x11$\xd6\xe5\xea\tN/\xf7\x7f\x18\xafB\xdf\x94J\xa4q\xad\xa0\xe1\x86\x8c\xd9\xeb\x8f\x14U\xa7\x0eL/\xc5\xb9\x8b\xe7\x8dO;&\xe5\t?\xcf\xb33\xe3\xbfC\x9e\xcd\x01oU\xc1gx\xcem\xefJ\xb5!Ji\xb5\xf2\xdc\xf8\x8f\x02*\xfe20\xd8\x1b\xff3o\xbf\xe4\xba\x8c\xe9\xe0ExuvN\x06]\x90\xa8-\xe0?\xef\x8d\xff<tMP\xf3\xa6\x97\xc8\x96\x0f\x05\xce\xa2\x98@\x12\xe6\xe9\x845\xe5 y\xcb\xcd2f\x95\xbfJ\xe0\xe1\xbd\xf3\x82\xec\xaf\x8ce\xa1hv[\xe9\x96\t\x1a\xc5\xda\xf7\xe7x\x90\xc7\xcf\xb4[\x16\x87\x1c\xabq\x8e\xb4{\x148m\xb6\xf3\xf7x\xa2\xb6W\x0f\x8e\xbfx\x00\xa4,\xbe~\xf0\xfc\x95\x88[\xb6O\nV\xbfUQ^\x17\xec\xc1\xb0\xe0\xfa\xea\xdf\xa4\x90[\r\xd6\xb8\xfb\xfd\xf1s\x98\'&e\xde\x972!t$\xfb\xe6\x87\x86m\xd6\xff\xa69\xea\\\xf3\x8f\x12.\x0c\xe7\xfc\x8e\xbf\xd5\x0e\xe4\xbb\xb0\xd2m\xb3;e\xcf\xbfT\xe7\xaf\xe2-\x11w\x15\x93\xab\n\xa1\xa0c\xf63\x8b\x90\xdf4\x16\xfc\xec*6\x93v\xd6EU\xe9\x8d\xba\x1d\x97\xfa\x1e4Az\xd2\xe3\x1f\xb28\xab\x8f1y=\xe1D\xcc\x91\xd6\x95\xf9ME\xef+\x8b\xe3\x89o\xdfgR`\xb1\x91pO;\xed\xdb\x84C|\xdfj^\x83\x11}<O\xb4G\x0bai~\x90\xac?\xbb\r\xd4\xe2\xd7\xf0\x93\xa5\xb5iX\x92j\xad3\xab\x97\xf4f\xfe%\xb3n\x1b\xd1!ic\x04\x83\xae70\x0f\xe37\x06\x10\x8e\xf7\xb7\x96\x97u\xf4\xdao)\x8f/\xe6y+x\x15q\xc1\xc5\xaa\x10\xf4\x05d\xc0\xb2\xf6\xadd\x02\xdf\x1fH\x82p][\xe2*\xdc\xfdn\x82\xe0C=\x11\x96\x16b\x80\xd2\xeb\r\x86\xb7\xf2\x9d\xe9\xedG\xa9HA\xf5*\xa4\'}\x83@\x05\xf2SJ\x8f\r\x1bih\xcc \xc2\xe2\xc3\xeb5\xff\x882IEBM\x99^\x08=\x13\x9b\xeb\xe50\xeb|$+\x8f\\\xe2\xf7\xa0\\\xb3\xcf^\x1fA)\xc7y\x15\x7f\xa5Hr&\xca\xfb\xcb\xf8\x89\\\xd4\xa6\x83\x89\x8f&H\xddI\xa0\\v:\xf6\xe0\x02L?\xa5\xe27\xfaz\xf4\xc4\xe4\xa8&F\xc9\x84\xc2LRr"\x19w~n\xd3\xcf\x1c\xad:\xe8j\xf5\xfb\xf5\x13M\xfe\xb7\xa4L\x10\xf1?\xdd\x08\x7f\x95\x0f\x17K\xee\x91[\x8fw\xc9\xe1\x82\xa8\xc6\x93\xabES\x85\xb5=\x9b\xb2\n\xf7\x0c\x93\xb0\xee`\xf8\x05\xe1#\xd9W\x07\xa0=7\x14\xba\x1a\xb6,\xe5Vu\x96&6\xc5y\xacs\x0fGQB&\x0b\xa0\xb8\xa0\xb1qmtB\xa3\x05\x1cg\xf5\xb2-\\\x8b\xa2\x10f\'K\x7f\xda9Z\\\x1bt\xa5:6\x91\xff*3\x15\xcd\xcd\x10mi\xb3g\xd9\x81\xd00\x8d\xa8;\x88\x8fXyt\xda\xf6\xa7\x89\xe3\x93\xc1*\x02\xe4Z\xbf\x11\x02\xf2\xae\x1f\x90o\x90~nChW\xa0e-\xd5\x1a\xc9X\x1c\x95\xd9\xb5\xcb\r\xed5\xb1\xe7\xb0\x9aw\xf42,^\x07\xe7\x1c%\x19\x81\xcfP\xd8\xdb>B>is\xd0\xab\xeb\x06\xec\xb2f}6C!.\xb2\x0c}n\'\xb6_\xa3:\xee\xf0\xb0\x02;\xe3\xb9*H\xb3\xd4\x94\xc63\x82\xab\x1e\xeek\xbb\x14P\xd3kc\x04\xfe\xdc\xb6\x97\xabpi\xf5\xf2\x81\x07w,7w\xa3\x81\x13\xeb\x07N\xf4%=~\x81\xdb\xcbN\xa6\x83\xd6D\x1a\x95\x11V?\xa0\xcd\xa8\xae\xbez\xb5\x8a\x0e\xd1\xc93,\x80I\xbf\xdf\xf9\xa5\xa5\xd4\x9f\x11p\xa9;\xea\xfcl \x9aQ#\x04T\xa4\xa9b\x0eY\xe3&Z\xe3\xb6\xfay<<\xb4\x1e\xcdFd\x01\xae\xd1\xbcx\xa7\xcdj\x08\x9d\x10[\xa8;*\xaa.\xbd\xff}0~\xe5\xa9\xb6\x9b\x1a\xf2\xd5\xebj\x94bk\x82\xd3w\xfb\xdcb\x90\x7f\x04\xe5Y\xf1\xae\x8fQa\x86D\x99\x8d\x01\xe1hR?\xe5\x83f\x05\x7f\xe2J1u|*\x1f\xaf5\xedRBM\xaf\xc8\x08\xd8\xd7T0K\x07\x17l\x7f\xd6hil\x0e\xe14\xbb?\xe6\x9f6\xce\rn\xa8\x8f\xeb\x87\x0e_\x9e\xf7n\n\xfb\x0c\xee\xd5?\x106\xfct.p\x0f\x90\x14\'cV\xa3\xcdR\xff\x8a\xf5\x1et5\xdd\xcb>\x84\x04\x8c7<\x1c\xac\x8a\xd8\x17\xa5\xfd\x90j\xc1f\xa1\xf03\x19\x87\xd5+\xaf\xe7\xec\xcb\xf9\x07\x0e\xf0\x1e\x07a`\x97\x98\x9cw\x9c\xf0^%\x13\xf8l\xf5\xe6;\x9a\xfb\xddQQe\xc2}x\x89~\xa5\xa1\xfb\x90%\x98\xfd\xa3\xb6(\x04\x9d\xc9\x14\xe7\xb3\xb1\xbaa\x8d\xf6+[\x98\xdbq\x81\xa6{\'\xaec\x07\xda,\xa7\xaaL\xa8L\x87\x03<\xc1N\x902\xc9U:\x98\xc1\x81*\xe9\x95\x9f\xfa\xed\xb0\x1a\x04\xb6[\x00\x91<d\x9c\x03c\xf5\x0b\xc3w\x1e\x00\xb4j9\xdc \x88\xe3/H\xa9W\x0c\x90\x0c\xa1\x03\xe0\xfd\x00\xb1E\x95a\xadE_\n\xf5\n\xe5\xf1\xa7\xd1J\x8d\x8e\x9b\xe5\xe5\xf8 \x1dS\x89\xe2\xd8\x1d\x08\x14\xab3\xe9\xb6\x93\xa8\xe02\xbd\x84\xac\x97;\xd8\xd9b\xb5\xdc!\xc1\xc9\xf6\xce\xc4\xd1\xcb\xd3\x19\xe6\xf4\r#\xca\xc00\x95\x88\x0fh\xd3\x80\x1a\x90A7|\xb2g^\xca\xeb\x1a\x04F\xb6??w\xee>\xf1h\xcc\x1f\x15P\xe2/4\x9d\x9d\x8cF\xb4\x99\xe9\x1f0opW\xe3\xbe\x88\xeeC\xd9\x98{\xdd[\xc8\xf8o\xa6\xc13\x97\xa2\x15:\x10\xe3=\xf4}\xb6\\n\x12\xfe\xf8\xb9\xcbP\xf7\xb7ZN\xacv\xec\xa9\xff\xf3T\xaeB\xf7\x14 \xf37{O\xd3\xd2\xf0\xff\xa6\xf5\x08\xfd\xb9`<\xec\xde]i\xa0d^^\x93\x01\'\xc6\x05\x13BwE\xe2?3\x12\xfb7\xc1@\xeew\tv@\xdf5"\x90\x00\xa1\xee\x9d\xb8\xa8\x96\xc6\xebWq\xa1\xde4\xadZ^~\x9dJ\x1c+y\x96\xf7\xcc;\xa3\xb1\x17>\xd3\xbb\tB\xb6\xd9\x14\xd9\xe8B(n\xb2\xb0\xde\xe5\x8f*L\xbf\x10\xc5t\xdcX\x1e\x925\x1cW5F\x04\xf47lw%\xe3\xd2\xe6lCb\xc8\x16\xf7\x00w8\xb1\xc4\xf1\x8f\xb52\x8b\xf3v\'p\x87,\xbdX\xb1\xde\xb3\xef\x84D;\xb0\x17jf\xa1(\xec\xce\xfc\x19\xb6\x8dS\x14>\xa2.\xcbl+\xd0P\'o\xe8\x8d\x9aR\x88\x0f)\x8f0s\x16PQ\xae\xe2f\xf3\xcf\xb28i,L(J\x0b\xe5N}o\xb4xno\xe3o\xfc\xf5\xb1\xee\x9cE\x05\x87\x9aM>\xde\xbf\t\x83\x99\x85l\x80\xb2\x90\xc5\x98\xcd\x87iT\x0b\x0c\xaa\xeeg\xb1\x80\x98\x0e\xb3\x1f\xca\xa2l\xd4([\x87\x83\xd5xS\x82=^\xa8\n3IB_2\xae\xa46\xe0)z,\xfb\xf3\x83\xaf\xb9\xe1=Y\x94\xaf\xf4\x1bz \x16\x1c\xd0\xa9\x8c\x87\x91\x11\x8b\x8a0)\x02\xebi, \xdd@\x11\xda4\xa5\xd9zb\xe0\x1b\xfd\xac\xaf\xd56\x8c\x89Pm\xce\xd4+\x8c\xe6\xd9\x1fk\x89\x83\xbfh\x92\xban\xe2\xb0\x01;\xea?S\xda\xbb\x98\xaa\x12QO\xb0\xd9\x01,12\x9c\x89\xd4\xd3\x82\xec,\xef\xd0\xb3M\x95{\xee\xc0\xbe\xa8\xbc\xe1}\xca\xcfs\x0c\xd2\xaf\x10\x12\xdc\xf8\xf7\xeaJg\xdd)2\xee\xfc\x8bz\xbf\x05\xc0=\x97\xd20\xd2\xf2\xa0\xb52`!\xc8\xedF\x0b\x1e\x1c\x93\xe0\xce\xd9\xac\xd6Ss\xdc\xb6\xb8>\xe6\xa0\x97>\n\xde\xe3\x85\xaa\xac\xaa\x0b\xa2\xaa\x0b\x96\xbf\xb2\x04q\xb9n\xd7\x01\xaa\xb2\x0b\x9a\x04p\xf7;\xeb\xca\rD\xf5\x8bW\x8e\x0co\x94K\xc1O\xcd\xbe\xb96\xda\xb3l\xc9\xa4\xa4\x85\x90{\x10P\x90\x9b\xc5\x02\xb1=l8>}\x03\xedz0\x01\x05c\xfb ~m\x16\x17\x1cW\xf6\xb11\xf20qn\xfe\xbd4\xc4\xb7\r\xf14i\xb6\xae\xad\xc1e\x0e;\xe4\x1a\xd2!4d\x8d\xcb\x0fQh\xf4\x9a~_\x0bu[\x055\xbd\xf2\xedN([M\xc3\x1f\xe9\xbf4\xa5fF\xa6\xb1j\xa2L\xca\x9f\xb3\xcec\xfe\xe4l\x9b\xc6\x82V46\x9c\x98.\xd9t\x97\xa7\x86\xa0\x1c\x15\x0c\xab\xf5\xe2\xb2?I\x0f=`\xc5\x02\x08\xf5\x1d\x1c\xff\xab\xb5\x80\x8d\x1d\x7f\xab\x97A\x13\x08\xd7\xb7\x9e\xacZ\x03\xdb\x08V\x0bg\x8a\xc1\xd9\x0b\xd7X w\xf9\x86I\xb8\xb2\x9b~l\x1b`\xb1\xef\xf9\xc2n3\x07\xf5Sa<\xe6~\x86\xd7\xa7\xb2;K\xa0\xc1\x93\xe9\xd9\xee\x8a^\xbdo\xbbzBHO\x82/[\x9a2\x94\x9f9\xc7\xb6\x02"\tY!\xa3\x17\x90\xeb\xe2r\xf3\xd9u\x87e\x99\xcc\xde\xe5BQ#\xbf\xb6\xfb&\x1eP\xd5\xbcm\xf1u\xa2E\xf0)&\xc2\xe39\x85\xf3P\xd26=M\xcd\x05\xd4\xc97W\xbf?\x191\x8dM1\xa1\x0f8*\x01\x0b5\xe6\x1b8\x95\xde\x95\xecP\x03$<\xfe\x0fz\x12\xff\x18\x93\xc2\x17\xd5\xaa\xcc\xbb\xb8i1\xbcVz\xf5s1\xbd#)^\x05\x90\xc0cS\xa1k\xbf\x86\xb7\x8f\x94;\x9dgs!86\xdf \x18\x96Y\xfa,\xa5\xc7\xa2"</n|xA\x1fD!\x15\x05#!\xab^\x8b<\xecx"\x0f\xb1nc\xef\x8e*A\xb9w\xee\xdb\xa2\xea\xf1\xfb$?u]G\x808\x7f\x92\xa5\xe06W\xf0\xdd\xb2\xd0\x81\x0bY\x19\xe0\xef\x1e\xff\xcc\xf4,\xe6t\xbe\x18\xe7\x88\xd4\x99\x7f\xe7-\x00[\xdb>\xb3*K\xe8O\xbb\xf9\x03\xfa\xf6Vhm"\'\x19r)}\x98d!\x97-B\x9ep\x1c\x06D\xfc9v\xcb\xbfm\xccg\xddR\xad|\xea\x8e\xb5\x06\x85\x9a\xc7\x00\x84\xde>kK\x083d\xed\xda\x11\xb6=)\xb9$\xf6\xc2\x01\x0c$\xedP\x1d2O\x99\x1f*\xdb\xa4u\xc7\x01\xd6\x9ae(\xa8b\xcf\x8c\xf1\x1f\xe0\xc0\xbc\xcb\x9a<\x88\x86\xdc\xa0\x11\xf6\x84\xa5\x9c\x88\xe7\xf5\x89\x93\xb6\x90i\xac\x80\xc3\xbb/\xffT\x9f\xad_\x1d\xcb\r\x97*\x05\x93!\x8fxD"\x1c\xfc\x89=BX\xf9\xcb\x0eg\xe9\x08\xc7\x11\x9f~\xbbq\xd1\x8bS\x9f^5\x91\x8c\x00\x955o\xed\xe0\xd0Va~6?\xad\x93~\x8a\x04H\x8f2)Xr`Z\xfd?\xf4s)tR\xeb\x0bW6\x9c\xf4R\xddF<\xe4\xe7\x81\x03{vy\xb5\xa7\xe2\xdf\xf1\x1d-Mq\xdbi\x93\xeaX\xc3\t.#\xf1"\x1e\xd4\xce\xcaJ\xa8T(}W\xfe\x9e\xb9{X0\xce\x92\x94\x0b[Ui\xbf\xda\x12\x99\xdf\xa5A\xc1\xac\xe4\x04\x90,\x9f\xe5P\xde\x82d\xd7n\xd2b/\x95R\xd9\xcdFN\xdf#\xd8\xbb\t\x18\x84\xf8\x07\xc3(\xbf\x86\x9a\xe7\x8e\xafHta\x8f\xf2\xf4I\x0cd\xe5\x97co\x17\xd9\x1d\x93J@\xa1\xe2ZV\x02\x043\xcf\xe9\xec\x96^b\xca,\x1f\xef\xd6\x8e\x8cx\x96Z\xd6\xec\xc1\xa4\xcf$n\x94\xdb\x01\xfb\xb5w/\xdcBTT<\xde}\x00\x03\xdf\xf9\'4b\xab\xf0w\xd9\x18)\x8a\xdb\xa0\x07\xc2\xfaP\x1d3\xb2H\x1d\x92a\x1aw3\x91\x01\x9e\xf1\xd3+\x1c$\xbb}\xe4.P\xdf\xeb\xb2MV\xeb\xa43\x07\xac\x06D\xe02\xf9y\xa1\x88EZjM]LN\xd9\xb5D\xf3\x08D]\xb9S\xd7\x99\xb2\xa1D\xd1Y\x12\x88\xf0\xa5\x19R(\xc6\x0eD\x89\xc4\xef\xed\x0f\x04\xe0\xc1x\xf7\xd6\x0e\x8c4N\xe1,\x0b\xbe\xd7\xeer\x038\x87\xbeF^\xb7\x9e&\xcb\r\x8aJ\xd7\x99\x9bo\xfa\xeb\x00l\x9b\xde\xa0fs\xe6\xef\xc5\x1e\xfbf2\xb7\xaf\xd6%\xa0M\xf1l\xc6\xb5\x04\x90^\x9c\xe0X\x98\xbf\\\xdc4\xb7ZC\xde\x1b\x03\xb8~\x1fN=\xa16`\xcflK\xdc\xad\xba\xad\xd4\xff\xb5\xa2f\x13\x10\xfa\x9f&b\x9e\xd97W\xed\xa9\xfbk8J\x19\xcd\xa6\xdb|#\x16\x15\xa7:\xc5\xef5\x94\xba\x95~:\x0f\xe8>\xf9O{\x99\\\x87()\xc25\xe2\x82\xc7\x8a\xb8\xe7\xa3z\xe1\x1f\x84DG\xb0\xde\x9a\xfa#\xa4\xeagY\xa8\xd3\xa7h\xf9\xff\xfb\xd0%\x95^D\x0c\xed9\xea\xb0\xd1t\xcbi^\x9fa\xd5\xca\x8f\xcbXd\xee\xa2\xc9:\x88\x8a\xe0iM%\xd6\x83c?{\x96B\xf8\x9cS\xe5\xd1\xc8\x10)\x87\x1dx\xf0\x95)J\xb1F\'-\xdec\xa2\xed!\x127vR\x9f/\xdc\xe9\x1b8M\xf2V\x0e7\x13\x97&\xa4\xd3_\x92\xf5\xb2\x06\xa1)\xa2\x90]2T\xe3&\x9ae\xc1\xb7\xd8\xf4\xd2\xfa\xea&\x9b\xb32\xe1\x12\x07\xb9\x0eT\xae."\x13\no\xb41\x8aq^\xddX\xb37`\x11\x0b\xc1W\xf5\x9c\x9a\x92\xcd#\x98"n)l\x0e\x91y\xfeP,3D\xc4&\xf3\xa1\x95\x1b\x10\xeaN\x0b\xef\xd1b~\xa5\xcf\xe4L\xa0\x89:~\xc7\xfcb\x1b\x1d\xe8E\xbc\x04\x197\xf6f\xd0+I\t3\xae.\x16\x83p\r\xd5\xad\xe1\xe2\xa3\x9e\xd5O\xberKpAT;\x94 \x03t\xfa\xee|\x1eS\x1a\x14{sWW\xa8\x9a\x8eu\x1d\x90"1\xceV\xf1\xb1\xba\xac\xe09\xa6\x04\xf5K0\xca\x83^\xebZ\x85\xa4\xf7I{\xd3\xcd%\x93\x0e\x9e\xf2\xbd\x883y3\xe4jF\xcf\xc9 h\xcb\xc6\xfe\xae\xf8$\x18e!\xd0\x1fOS\xc9k\x9fF\x1f\xb3\xa7\xb7{.?\xa7\xf5\xa7"\xb8\xe3\xd3\xd9\xd1\x1d\x89\xb6#\xfa\xb9!\xea\x15\x060\xa2e_h\xc64\x06\x1b\x16\xf5\xe9\x87Z\x8e\xb1\xe0\x02\xf2\x9a\x1d]\xcaH\x03n\xdc\xd8\x13-;\x9f\xda\xcb?Eh\xb4\tG3\xe3\x8b\xdfirv\x88\r\xb0\xaf\xf6\x8c\x1a\xa2\xe2}\xf3\x18\x89Ih\xf4\n\xdf\x80\xbc\xd8:{\tp\xf4<\x9f\xa9\x9b%\xe8I\x0fSL\x9b\xe0\xcb9)X\x99\x19\x1c?\xc0\xf3kU\x14\xb3kM\x87/\xac\x9a\xfa\'H\xe55\xbf\xef`u\xec\xb0$\xe6\xe5\xe2N\xc0\xd4w\x14M\xb1\xcb\xc6\xb5\x94O\xbc\x91\x17*\xe9\xe8\xd1N\x97\x87\xd9\x8aS{\x11\x84\xce\xb8\xac\xc8i\x9eM*z.\xdf\xc0\xaf\xdd\n\xd6\x90\xcf\x92\x80\xf5=\xfc-IX\xc1d\x8cUg-\xddt\xf4\xd8\x80<G\x17A\x98T\xf6+\xb5\x97$\xd6b\xae\x92\x0b<r\x1fl\xcdi\x90v\\\x92\xde\xe7\'\xb6\x03LR\xd3cf\x0b\x97\xcb\xd9<\x82\xd9\xd3*\x01\x94\x04:\xf0\x97PcV8Hi\xbb\xd7\xc9.\x05T\xff\xfeN><~o\x9b\xd2e\\\x9aH\\\xf4\x0cg\xf1$\xf9\x12\xe4\x00\x0f\x0em\x11ff\x8c\x195\xb1\x199IX\x99\x99n\xc9o\xec\xa5\x03\x19W\'\xd7\x13\xe5\x0c\xb3m*\xf9\xa6\xb0Z\x81\xc1\xde\x8bS/\x98\xb2\xfc\x1f\x8a\xcd\xfd\xf3\x80\x82\x18\xe0y\xd4\x161\x87]C\x7f\x95\x19=\x04E\xa7\x84\xb1\x18X\xb7\xba\xc4\x9e\'Ii\xb0\xdc\x8f\xa1\xddS?d\t\xe2F\x18S\xf9\x01\xcd\x9b\x91\xf7o\xf4j$\x02\xbc \xe1\xcf\xc6\xfa\xce\xfd\x92Z{\xcc&\xb7\xb8\xbc*\x11Kb\x0c\xd6-\xd0+o\x85>\xfa\xc8\xbe3\xc2\x9f\xf7K\x03\xda\xf1\xd0\xea/(,\xc6\x81\xd04.\xdd\xda\xaco\xfdo\xbaX\xbd\xcd\x03\x0bD&H\x9cwK\xdc\xefB\xf85\xacS\x8c\xb9\xc3a\x7f \xf8\xa7\x10\xbeC\xf1U|n\x88\r\xa8\xad\xc6\xa5\xbf\xb4\x94\xa1|\xf1~\x9f\xd2\xa1*\xed\xb9\xe2;c\xfb\xc8\x81\xb2\xce\x00\x95\xc6\x14\x16\xa0T\x97\xc1Q\x01\xeb\x10\xcc\\\xbd\xeer\xe8.\xdf\xd7\xf5\\\x82\xc0k\xfd#TtJ\xc8\xc0\xa0\x95\xe3\xf2\x86\xe6Y\xfc\x8d2\xc1\xba\xc5\x0e\xc1/4\xe9\xf0\xd4\xf8\xe9\xba\x81\x9d\xe9\x10J\x17\xc0U/\x9b\x15\xd6\xa8G|\xbbdQ\xbd\\\xdb\x93\xef\xab\xe1\nI?\x18\xc6\xac\x81\xb7&g\n\xfc\x14\xe3<\xdb\x06\xcb["Q\xb8\xad\xa6\xf4\xd5.\xfe\x0c\x16\xd4\xcc\xe7\xab\x94\xafW\xc8\xc7I\xa0\xb0[{\xf3\xa3z\xf1\x93\xefr\x19\xfe\n\xea\xcb94\x16\xaa\xa4B\xf8\xd8KT_\xcb\xfeN\x10T%\xc2j238n\xa0\x9a\x87\x83 \x85\x9d&\x12\x15=\xc3\x15\x1ax|\x96\x8a\xc1\xa9\xc5\xab\x85\x99!\xb2lY\xc20X\x1d\xab=JCN\xefE\xe8\xe6E "U\x07\x92\xf9\x8b`O\xab\x94\x941"\xdf\xdc\xb2\xbf\xcd7\x8dt\xfa\xf5\xc0l\xb4\xaf\x88oH\tR\xc5\x8d\r\x938\x91\xa8\xfe\x87\xa2\xf5:\x1eK\xd4\xf8\xdcGo\xacU0,7\xb47\xab\xaf\xfb\x9b\x9d\xc7\x88\x1ae#D\xc5\x18\xd9\x8cF\x00\xb8\x91r\x11\xcdJ\x07\xd6\xd5\xf1\xf2\xe4\x04\x17r\x90\x8c\xa9\xef\x8d9\x82\xc3\x89D\xb0G\xd71pC-\x96\x1a\xfc\'&v\x8b\xbd_\xcc\r\x86\x85\x98z\x9a$[\xd2T\xf1\x8b\xc6\x80}\x1do\xd9J>\xef\xf8\x0f_D\xa3\x1e\\\xf6;\'\xab;Z\xb6\n+\x7f\xa4\x7f\xc9=H&6\x19\xb8\xfa\xbc\xc1A\xc85\x9b\xc2\x9eE\xba\x08\x94\xbe\xeb\xe7\xb4X\xe9v}\x84%ngt\xd1\xa8\x06\x0f\xcb\x04\xf7\xd71\x1f\x1e\xb1\x1b\x01\xeb;:\x97\xd3\xe9_\x15q\xe8\x8d\xa2\xf4\x15\x84\xab\x11\x9a v\xac\xd4\x92\x1c\x15U\xb2\x7f\xd1\xde\xc8s\xdc\x9f\x98\xa2!\xa0_)\xca3\x00~\xd0"u\xec\xd9\x13\xcb\xf7\xff\xe1\xa2\xbd\xe3\xc4 \x0cN \t\x84}\xcd6\xc4\xa0\t\xef\xe1Yf\t\xcb&\xd5[\x06\xae\xd9\xa2\xe9\xd7\xc3\x8d"q\xbes\xf9\xca\x0b2\xab\xd5\xf8Xv7\xb359\xf1\xa2\xf8<=ec\xf3,\xb3^\x9ek\xf9}\x8b\xcc\xd2t\xdd\x81\x15\xf5$\xfc\x89N\x19\xba\xber7\xbc@\xd2~\xa4W\xd0\xc1\x809\x0bi\xbf\xe1J:%(1F\xfbx6C\x1fQ\xa95\x16\xb1\xea\xf6\xcf\x97J\x8c\xea\x13\xc9$I\xadR\xaa\xdbl9\xbb\x9dN9\xf5\xd0\x18\xbam\xe5#\x81\xcdij8k(\xc4|\xf0\x1bn\xa4Sz\xaf\xbf\xec\x8b\x07o\xc6\xe9\xdb\xf3yLYP\xacj\xd0\xff\xe24\xd8\xe3\xb2\x10kX>\x9d-\x1asX\xc7<\x9e\xed\x96\x0e\xea\x03eV\xc2\x84\xf1\xde\xb8-ge\xadGk3\xcc[\xd4(+\xbduL9\xed@0N\x96\xea}\xc5\x12c\xd7\xee\x04\xa8(\xa5C\t T_hn\xed\xa5\xd8\xf5<\x9d!v\xaff\x06\xad\xfc\xa0\xc3\xf2\x1f\x8f\xc1\xc3r\x1e\x0e\xaa|\xd8X\x13\xfa\x92oY M\xfa\xb6]p\xba\xf4\xe5\xd6s1\xfd\x8a\xd8\x87\xed\xd3\x0f\xad:\xc6a\xdf\xd2cc\xcb\xda\xde\x0eF\x8d\xa6\xf2uT\x15\xde\x86\xbc\x19\'\xd4\xbe.^\xfd\x82\x08\x024\xdbF\x86n[\x1d$4xK\x1aP\xdb\t\xd4\xa8Js\x91r=c\xe7se\xb1\xdd2>\\\xb4\x8a9\xecCG\xd7\xe2S\n\x7f\t\xe1\xf5\x1e\xf6\x1e\xb1Y\xb7"^\xf4\xb3\xdeg\xdf\x1f\xa7vT\x02\xeb\xd9\xaf_\x93&\xf1\xb6\xca1d\x90\xa8\xc0SU\x94b\xec\x84\x16R\x81\xebS7\x92i\x9cn\xc2\xeeH\xf2ZO\xc3\xd0\xcc\xd2\xde\x8c\x9f"\xa4\xc3b\xffN1\x7f\x9e\x05\x97\x90!a\xcb\xb9\x0b\xf2\x03mQ\xce!N\xb3\xe9\xb5\xe0\x88m\xc4&|J\xed\x03!\x18uc\x80Q\x88c\x95_x)\xbc\xabP7C\xf3\x8c04\xce!6\xb5\x1f,FYl\x86\r\xd4\r\xec\x80n[\xcbgh\xf0\xba4`\x17S\xddf9\xec&:\xf4/~e\x05k\x14\xff\xb1\xc0\xcfd6\xbe^\x02\xa5f\xce\x19\t\x94\x99\xa1\xbdU*7\xd2\x06\xdePC\x1f\x89\xc95\xc7\xc2\x08g\x1dC\xc5s\x1c\xcbb\xb1\x0c\x06\x8f\xa2\xe4\xec\x9a\x95M\x9dFG\x86n|Q\xf7j\xa6\xe6\x9d\xf9{\xab/\xb4b\x9e,GIl4\x16ud\x93\xa2\x04\x0eP\xb1J\xa8\xb0\x96\xdb\xd8AT\xa0\x8fk4U\xabK\xd4t5\x04\x14\xb2P\xdc\xfe\xe9\xec#\xedQ\x16\x9c\x00L\xd5 Pz\xcb\n.\x88r\x86\xe3J\xdbA\xc8\x9e\x8d\x95\x0b\x05 \x9ce\xf6\x04r\x9c\xb4\x93\xee\x85\xc7OL`P\xfd\x9b\x1cZ\xd4I\x87C&\xed\xc6B1\x1cI\x80\xcc]J+\xcc+\x92`bG\xb3)\xf2?o\x1d\xbd\xfb\x07\xf7L\xa0\xcfF)\x08\xe5\x84t\xde\xda\x8b\xa5\xfb\xe8\xa0\xaaF\xc9\x179T\xd4\x81\x8f\x847\x8b@\xb5\xef(\x9a"i\xce\x96\x1aK\xec\x1f\x01\x9b\xbfd\xf6\xeb8\xcc\xfd\xe8\xb9S\x1b>;Pw\xe8\x16\x0bN&C\xf0C\xaa\x04\xe4._f\x01\x9f\xd1:\x85\x13lzm\xd0"\x8d\xd4\xea6\xa1\xa4\xd3\x90>W\x93d\xaa\xa8\xae\x16\x91\xaaD\x85\x8b\x97v@\xeb\x13\x1eI~\x8fj.A,\xdd\xf9S\xf9]\xf4\xe7|^0\x01\x1ag\x0b\xad\x9al%\x82\xd8\xc2\x95\xd2Rg\t\xa4\xbad(f|\xb1\x89v\xad)\xd2\x06\xd6\xe9\x04\x8a\x88\n\xc3XU\x8c\xdd]\xfe\x9audK1\xa3F\xac\x826\xa1&\xb3\x9c\xdfS\x95\xff\x89\x0ee\xab\x85\xbee\xe3L.\x0e\xaa\xfc\x1f\xb9\xbe?8\xc8\xc6K9\xc8\xadv L&\xa2\xfeW\xf9b \x8d]\x91\xd6\x0bW\xd3a\xb5\xc5D\x9f\x94\xd7\x88\xb8_\xf0\xa2:y\xa7\xebyR\x1a\x89\xf5\xf2\x96\'\xf0%K-\xc4:\xc8\x1e\x1d~\xf9\xfd\xc7\x06\xc5v\xc9\xcd\x1c\xc7\xb3HU]j\x12\xf8\xb3e}]xf;\xa8\xda\xa9\x83\x0c\x81\xba\xd34\xaa\x89Z\xbcWi\x97\x98\xac|\xdbX\xe2\xbe\x97\t?\x99\xcdY\x82\xea\xdf\x89\xa1\xe3g\xda\xc1\xdf\x1e\xec\xa1+\xddv\x8f\x90\xc0@\xde\xd4\x08\xe4\xf6\xd7,`\x15\x1cb\xd49\x8e\xd3\x96\x8c%+\x91\x120\x991\x9d\x04\xfe\x1c?\xa3\x88\x1e\x89K\x87nWu\x89y39p\x0c\x19\xc4\x08\x9d\x08-\xae\x0e\xc0\x99\x9d\xf4mO\\\x8cK\'4\x92EQ\xad<\x12\xed4}\x1b,\\c\xb1z\xe5\xff\xabz\xf7\x0b\x0c\t $\xf4F\xb4\xfe\xcd1\x08\xa3\xc3P\x9d{\x1c\xf6\x95\x11\x8c\xf4\xe7\xfe\'\xe58\xb7\xb8\x88\x05\xbc%\xadn\x16\xa9\x95\xbaS\xeeQ\x84\x96\xffq\x95P\xed\xeb\x9d\xf1\xc1\x0c\xbd\xd8\xafS\x0c\x0b\xb5\x94\x98*\x14\xbe_;`\x05i\x94\xbb#\xdeu\xfa\xedI\xd9\xfc\xb4/\x04\xe0\x16\\O\x02IQL E\xb1\xaa?\x17I\x8b\xc4\xde\xbf\xf9\'\x08\xe0\xaf\xeec\xa0f\xbea\x90\x9eH\xc2\xd6J\x14\xdf\x1dR\xfa`/\x13\x16\xae)\xf1\x8e\x88\x84\x16^\xa6-\xfa\xac\x91\xb0y\x98\xd0\xf3\x87"\x02G/ 4\x05\x7f\t`K\xfd\'n\xf8,#\x8b\xe8\xda\xd0\xe2j\xd1\xcaS\x92\xa1\x0bK\xf3\xce|)S\x96\xcf\xbdk\xe1\x18\xdbK0\x9eG\'=\xd1=)\xf7\xf2\x98\xbc>\x82\x91\x96\xa7\x8b\xe5\xe6j\xc3K\x985\x8f\xea8\xc8-2H\x9d\xd3\\i\x05\xb1\xca\xd7\x1bL\x1c\x1a\xe3\xac4\xe8PZ\xbb\x0e,v\xc8!\xf0(f\xf0\xe9L}\xd7*\xf4s\xdf\xa4\xf2\x88\xcc\x8ao\x8c\x08R\r\xd9EQ\x07V\xed\xaeT\xa6\xbd\r\x0e\x94\xd9\xb3\x9c\xa7a\x02\xda\x18\xf3\xc1\x92T\xf8j\xc07k\xe2WO\xee\x85\x95\x8e\xc1\xaeZ\x07\x8by\xdf\t\xe0l\xeb\xc0 \r|j}Ot\xd5<\xb9K\x0c\x05y\'\xd1\xea\xe0\xb8\xc2\xa3\x1b\x8e%r|s\x16\x07\x9f/^\xa4\xca\xa0\r\xe3]\n\x8c_K\xd1BN\xa8\xf4\x91\x89\xe7\xb4\x0e\xf9Htk\x05F\x11\xbf\xcb\x94\x92M\xc7\x82\xb3\xda3~e\xd7\x9a\x86U\x13\x15\xbc\x12\x14\x92\x0e\x1dJDkL=\xc4\xc3\xada\xc6\x99\xcc\xe1\'K\x98\x84\xa6\x81*\x88\xa8w(\xa0\xe1\xc1N\xd9\xf7\xa2\xfb\x06\x82{\xaf\x8f={\xcf)o \x00\x11\x9cG\xa2\xed\xe3W\x18\xd2\tO\x7f\xd9\x15\x89\xc7\xbam\xe1\xeb\x98\xd0\x8a/B\x91\x05\x16\xe3\xd2\x0f\x86\xdd\x99g\xc4\xc8H\xcf\x08 \xdc:\x82P\xe1\n\xcar\xfa\x00C5q\xee\xe6\x91\x15\xd2K\xa2FK6\n\x96`\xaf\x04D\x80\x97\xbeRH\x92r\x90#\x16m$d\x93\xaa\xdf\x9bx\xda\xb0\xd0\xa7h\xe5\xbbRx\x80\xbc\x9d\x99V0\xcf\xf2\xb3\xac\xf5\x88\x9a<|\xc8-@\x01\x8c\xb4\x8e\x06\xb4\xe3\xec\x90\xd8\xc6\x0b\xb49\x1et\xd2\xbe\xef\xae\xe2\xb7\x19\x1a\x897o\x92\xa8\xeat1v\xc0H$\xae\xaf\x90\xe8\r\xfc\xef\x8d\x17\xe7\x98R\x97\xc0@\x17\xb3\xa3cD\x9b\xb4\x90J\xed\x01\x9c]\x1b\xcb_\x01\x0c8P\x0b\x81X\xd83q$D\x16\xb4\x8a\xf1\xe6\xe7\xa3\x18\xf4\xab.,\xed\x95\x15y\x86\x0c*\xed\x12\x07\x83\xbdA\x97\xe0\xc0\x1f\xcdT(\x1b\xeb\\V[\xd2\x9b\x1eWzp\xda"=\xb6b\xef\x7f\x87\r]XO/\xcc?\x18^\xdfe\x9c\x87\x82\xff\xe2K\x1e\x14-f\x90z^\xef\xb6\x9a\x8d\\bJr\x10\xeb\xc5$\x88u\xf4\x0f\xc3\xeb=\xb9\xf1\r)\xb4\x9b\xe5\n\xb3DJ\xab\xa2\xe84\xee\x13\xa8\x81\xea\xe5\xba<\x0e\xa2\x1c\xa2eS"{I\x83Z\xca\xbf\xfe\x10b\xdf\x86\x9b\xd2\xd1\x84\xef#+\xe7/\x98\x84\xd3c\xe4A9\xb7R\xb5X\xa9\xf6\x8f\x9e\x83eN!\x83\xd85\xcf2\x8b\x97\xa4\xd8>\x17C\x08\x9d\xf2v\xea\xa8\xf4U\x18rhc\x8b\x82\x19\x16;\xc6\x03\x98\xcc\xa0fi\xc7%\xff\xe2\xb5D\xdbm\x99g9O\xa5)|\x11\x1cB\x00\xf6\xb1\xdaO\x0b]\x1a\xbe\xde\xdfk\x19\xa7\x9b\x1a\x86\x18 s\x977\x84\xf5\x0bV\x1e!\xd8\x92\x9b\xaf\xbbg\xe2#\xa2>\x10\x15:\xfe\x08~n\xf3\xbd\x04\xed\x19\xdd\xb2o\xa8\xe91\xd9\xc2\xd6\'\xba>\x9dv\x13h\xd2K\x9fRf\x96r\xb7x:\xaf\xdd\x0b\xbb\xc6P\xe2\x8e8\xdf\x85P\x14W\x94\xe6`&\x87\xe7\xd0\\\x97\xb3c\x96\xb3\xc3\xed<\xb9\x8c*\xfa`\x07\xb6\xe1I\xfb>-\x87\x98x\x14\xb3\xcbK\xd7b\x8f\xf9u\x0br\xb6\t}\xc3\x9eU\xeceB\xb8\xce\xd9\x16)\xad\x15V\xc6S\xdd\x0e\xf7\x8e\x8eh\xc1xkN\xcek\xbe\xf7\x91q\xb3&\xb74\xca\x99\xd1\xcd\x0c\xc0\xfdz\xe7i\xe08\xe5dp0\x18\xf6v"\tF\xb4<\xa5]\xaf\xc9\x99?35\x95\x9f\x90N\xd7\xa8\xc5C\xc48W\x01\xf3\xde2\xae\xd7\xc8\xcd:\xf6\'#Dv\xb7\xfeQ\x8e\n\x92\xe5T\x9e\xb4\xe3\xe1\x90<\xc0\x0b\xa8\xdb\xea."\xb9M_\x03\x8f\x82Xc\x1fH-N\xae\xbb\x0cjk-\x06\x1c8\xf9w|\x8c\x81Yc\xe5\xd8ycMDB|\xe5\x88\xd0^\xe3\x96|]\xf3\xed.r\xfe\x9a\xff\x8d\xd7\x8b]\xab\x10\x8a\xf7)t2<\x18\xae\xd6\x12\xa5%\'|\x8cK\'\xd8\x86c,XR\t\xa0\xfa\x1f\x10!\x07\x84\x9b7{O\xc3V\xe5\x7fY\xec\x1a\xb5\xa7\xac\xbf\x04\xbf\x83\x1cLE\x1b\xb4.\x8cha\xca\xbe"\tfU&\xf3R\xd9\xcd\xe3Og\x8a\x9e\xcb\x03\xbd\xf6\xfc0\xa0hb\xb1A\xe2\xe1\x93\xf2,\xc5w\'#\x15\x80..\x11\xaa\xdeR:!:_\xcb\xf9\xfbv\xc2\xa0/\x89\xee\xa5\x02\xe2\xe3\xb2\xb4V$\xab,\x0eR8\xe2\x19p\x1a\xa41\r\x869]\xfe\xc9VD\xee\xad\xb8S\x9d\xfc\x8d\xa80d\xa8\x82\x85\x06\x97\xa3\xf5ol\xae\xea\n\xc2\xc0\xd5\xcc\xef\x04\x1e\xf8\x06\x1e\x9b\xd8\xd5q\x15\x9b}Q\xac\\0\xe0,\x12\xe1\xebq\x80\xefC\xe7\x80\xe3R\xf4,:\xc8f\x91\xd8Be\xb3\t\'\xadA\xbe\xe1\xf4\xa1\xd5:u\xa2&\xf9\x0bQ\xe1\x18\xab\n\x16\x95\xa7\r\x7f\xb6\x94;Y\xda\xa7\x0f\xf9W\xcc\xd0\xd2\x0cO\xa8\x81\xcb\xa5\xf3\xfb=\x83\xbae\xb3\xd5\xf5\x94\x17\xe3~?\x95\x92\xe87#\xbf&\x1e"s\x19\xac\xe3YT\xab\x8f\x1d\xc3\x9b\xf4\x1c@\xe6\xf8k\xa2\xe6p\x08\t\xe3_v\x10\xea\xa8\x96x,0\x11\x8d\xa6\xe7\xa2g)\x9c\xd96\x1cj\xd7\xc6=C\x00\x04\xa6\xbf\xd1a\xfc\xda\r\xd6\x1d\xe3vW\xb2\xb1\xfc.\xfb\x17\xb2nF\x08\xc3\x95\xab\x91gbEw\xcftbE\xdf\xe9{\x8am\xed.\xc6\xe4Y\'\xb8 \xba:,\xb0L\xdf\xb7-\x9bR\xddP\xd5\xdcG\n!\x00\x8a\xc6\xbf!2\xd1\xe4\xde\xb5\x1f\xf4\xa9\r\xe3\xe1"q~\x97\x18\xc2\xa0\xe7>`+U\xd5\x15\x9f)\x16\xa2\xf4\x9f\xb8\xe8\xa5<0\xab\xb0\xc7\x17j\x94\xc9\x93\xb0\x8f_4\x89\xac\xe4\xf1z8\x9b$`\xd5\xd7\xbcj6r::+|\xdb\x1d\x8e\xb4\x8cw\xcd\xfeT*\xe2\x05\x14\xa5\xe2\xa6\xbf\xcd\x7fn\xc0\xa0\xc0b\xfe_\x1b\xf3>\x8e\xb0;$\xc0o\xd5x\xb8^\xc5\xaa\x8a\xf0\xa3\x94\xa4\xf7\x95\x11\xb7\xc8\x08\xc8\xbbo\x83\x12\xee[\x8c\xbe8\xffj\x9f\xa2\xba\x92\x88\xed\xbf\xbe!z\x12:\x95\xbc\x8d\xed\x1a\xf6\xacbqm\x95\x00\x88\x94\x92.\xde0D\x08\x13\x85\t\xd4\x8b\xc90\x1b\xff\xb52R\xb7\x9c\x9f\xa7l/\x0c(\x88\xfa\x03\xe6\xf2\xebc\x0f\x1ar\xd2}\x1f\xc0\xe9d\x80"|\x97\x94\xb2=\x18\xb5h\xf3V,5C\xf8R\x84T\x93\x8e\xf5A0"zu\xa6\x82\x86\x83Y\xcf\x14\x7f\xa0E\xa6p0P\xa2\xc7M\xd2\x97e\x162y\xdd\xab\x1f\x92]/\\\xf8\xe4\\\xfe\x99\xec\x00\xc83\xfb\xa1\xc3*\xbe\xd6l\x98\xba\x82^\xd2\xe4\xe1/\xe3b74\xa4\xe7I\x9c\xb3\x01b\x9dbH\x8f|\xe9hBW\xbe\xa7wh\x0c\x9c&\xae\xd1<|\xf1\x87u\x8ds\x997\xd1\xf3p\x11\x1e4\xea+R\x8ed\t\xd6U\xb2\xddw\xb1{\xb6\xaf\xb9\xc1 @\xaf\xbaep\xf9\xac\x87\xb4\x0e\xe3B\xf4\xc1\xc2\x00\xbf\xf0\xca\x91\xb2\xd1[\x9b<e\x00\t\xdeo$\xa9\xe0!\xa6\x08\x92\xc6\xbfI\xd2\xb9\xc3\xc6\xd73\x9d\xf2/N\xd0\xa2\xfc#D\xb4!R\x88\x07\xc0H2V\xe2}\xfbb3\r\xb7VU\xc2\xbe\xd1\xcf\xdeu{\xfe\xc1\xe3W\x01'
MIC_OPEN_IMG = b'\x1b.K \x1e\x85q\xc3\xdd0\xbe,QDY\\\xc5e\x84$\xb3\x03d\xb7{\xb2\xc6\x1b\xfb\xc9\xca\x1eo\x14;\xa1\xa4a\xbe\x905\xcb\xe3\xf1\xc8xkd?e\x95\xc8L\xc9{/vVY\xe3\x11Y#\xe3\xc9x_\x7f\xb9\x93\x17T\xe5W\x8c\xf9\x82\xba \t\xf1\x95\x15\x869\x84\x82\xf8\xa5\xaa\tr\xca%\xdc\xa9/\x14l\xa1\xb6\xc22@v\xbb\xf72\x92\xd903\x1e\x89\x90\xb5\xfb\xde\x13\xd1\x8b\x06\x12\xdeJd\x96\xfd\xc6\x9bI\xa8\xa7\xac\xf9!-\xb4\xf9\xe7\xad\xb7VYq\xbdU\x08g|\xec\xff\xc1\xb5V7T"\x8dJ\xa3g\xb1%T\xa3z\x89\x94Fh\xc4\xed0\x1ff\xbb\xc3\xf7\xd8\x0e\xd3H\xa4B(\x94NH\xc4z\xd7~$\x93\xa6\xbdS\x1a\xbd\x02\xfd\xb6\xd7\x1a\xae"\x8a`\xe9\xbb\xbf\xa9i\x0e\xfa\xc6\x96Re;M\x7fP%<\xc4\x18\xd2\x1d\xe7\xa2\x06\x00\x80\xce\xd8L\xcf\x02pH\x80[$%\xf9\xf09\t\xfe\xf1\xbf\xc8\xad@\x94\xb1%\xe5\xf6\r\xe3pO\x06\xaaS\xf9\x99Y\x05\x02\x0e}\xf7#\x0b\xf4R\x82\x87;\x9e\xcf\xf9J\xff\xf9\xab\n#\xa0/\x83\xff\xb8\x7f\x00\xb0\x02D\xe3\x95r\xe1\xbe\x86\x08\x00\xdc\x06\x8c\xf5\xeeY\x06\x17\xed.\x86\x84\x15\xbd\xfeN<"\x10\xf2\x85|[u\'l\xea\x85J-\xb98\xbe\x18yY(\xa2\xa89\xf6#\xebZ\xa2(\xe3\xe6G\xc9B\xad\x19\xc4sW\xe3\xe2\xa8\xc5G\x1f5\x93\xddE\x82\x1fe\x00\xa6\xd4\xae\x17\xdeM\xe9Zd\xe6X\xa4P&\xee\x9b\xe6\xad}\x8f\x89\xf9"\x8a*t>\xa7\x10\x88,\xc9\x1f\xddi%\xd5\x06:R\xdc\x03\xa5\xd4\x976\x8a=\xb9\x93\x8d\xb6M\x1d\xdbD\xca/=\x9f\xaf\xbbd\xc8\x9em\xba\xe6T\xe6\xa4\xc9\xfaq\x16\'+\xccA\xf6\x80\x95\xf2QZ%h\x83\x88\x8d\xed8+\xac\xfb\x02Z$\x13\xa7\x98\x02\xfb@\xd8\xa6\xc0-\x82\xc4\xaf\x89B\x8e=g5\x99\x934\xc5\x92L>\x0b\xbdD\xb10\x8ad#\xf1\x82\xfd\x99\xc2\x17]F\x19]\x1d\xf4\xed\x9d/(\xf7(1j\xd9^@\x96jE\xcb\xe6\x92\xa6\x1cY\xeaB\xd3\xba\xfdE\xcbi\x9d\x9e_,\x9d\x1c\xc8ps,,\xdb\x8a\x9c\xc8\xd34\x1e#\xd1b\x0f\xae\x85\xffd\x14\xe7\x8f\xa9(w\xd7\x8f\xa1_&|+|\xf9\xe8+\xc3Q]\x82\xd1ww\x80\x12\x06jL\xb8\x89E\xa8X\xe6Xv`\xb5-\xd3\xe0>3\xff\x02\xfdR]WE\x93\xcb\x1e\xcd\xd3\x08\x8a\'\xfd\xf4"\x80\x9e\xad\x95\x8en\x1f\x89\x80\xfd\x1b\x7f\x01\xd9ALUw\x8e\xdb\x94\x9e\x19\xf2\xfetg\x0fc/\xd4\xac\xdc\xda\x0b\xa0\xa3_\x13Z\xec\xbb\x96\x8aEt\x1a\xc1\x1b\xe75J\x94\xd1\xfa\x80\xb3\x8b\xc3\x10\x11r\xbdn\x138\xde\xe8\xfb\x83&\xa7\x18\x8f,\x15\xb7"\xdd\x9f>t\xf8\x1b\xe69\x9c\xf9\xc1M\xee\x93w\xc8\x9dT\xf0kr\x11@\xef\xfeO&\x11\xa8=5\x89U\x87\xec\xa3?O\x8a\x9d\xc4\xa1IM\xf5\xa6\xc7\x9eT\xcc\x04\xd4\xac\xdc\xc2\x0b \xb1\xd8\xcaB\x03\x97Usv#\xca\x155PMx2vbz\xb3\xaa)\xb1\xf9\xf8Kh\x07\xea\xa6\x08\x1d \xd03\xf1\xaa\x03\x9f~7\xc1\x1fV\xf3\r\x8e\x89=gg\xab}\xe7r\xf0\xb7u \xd2l\xc3\r \xb1\xb8\xaa$\x82;\xbd\x03Z{(\xfe\x13y\xa3x\xdb\xc1\x87\x9f\nV)\x12Y\xac\xc4U|\xd8\x0f\xeeR\xe7\x06\x04\x04\xe5>x\x8b\xcd{(\x0b\xc50\xb0d\xb5\x05Vw\xbb\xa0Z\x8anVK<n\xed\x84B\x1c\x84\x9a1 l\x81b\xff2yx}\xf5\x82"Lq\xfe[\xe0\xfd_\xf5\x87V\xf3\xc4\xcd\x85\xef\x9f\x9b\x97\xa0\xa6B\x9e\x8a\x00j\xadz&U\x90?S\x06\x1e\x1fZI\xc9\xd7R\x92M\x18^\x0c\xc8\x84\xa7\x18e\xb9\x01\xc4Y\xcb\x19:r[\xb8%\xb9C\x0c\x14\xab3\xd1vh\xcb\xda\xcf\xf9\x89\xe7GX\xbd\x03!\xdd\x8d\xd8\xdc\xbc\x90\x121D\x92^\xc4X\xff\xbb/\x8e\xdbb\xad|{2\xaa\xde\x1dPS!\x17.@\x8f|dB\x8b}u\xbe#\x0cb\xe9\x1aD\xb3\x82\xf7=\x07\xe5!F\xc2sY<\x08\xe1\xdf\x18\xd3\x9b\xca\x8b=\xa4\xf2>l\xda\xe4H\xadP\xfc\x82c\xb0\xfcW\xd4)}\x9f\x01\xdf\xaf\xd0\xe7\xf6+\xed\xee*\x11\x10\t\xfe`d\xbdp\xbf*D\x1a}<\x16\xfc\x18\xd5\xad\x97\xd9\xd0?\xae\x14\xdc\x96S0\xf7\xf2\xfe*\xcc<\xb5\xeb?T\x118TM\xd2E;\x96j\x02\x02\xf5\xab\xad\x0c\xcd\xd7\xc4\xa8\xd9\x1e\xbc\x98\xcd\xfd\x95\xfb\xe7RZQ\x15\xc7\xfbm&\xe86w\x80\xdc[\x9d\xfc%/\xc0~E\xf0\x94\xec\x1e\x01\xb6\xfff#N\x8f+\xe6\xdc\x01\xdd\x9ej\t\x83\x11\xa7A\xec\xc1\x95F\xf6\x9a\x0f\x96\x9b\x83\xbe,\xfc\x85 \xfe\xe8\xff\x05\xf8\xd4c9X\xa9\x1cg(J\xf4P$[U\x16\x99\x1b=\xe4\x01\x1f\x95\x82\x90\xd5\x8f[KC]\xce\x9c\xb0_\xe0)-\x9c&\xcb\x1eyl\x8e\x7f8\xab\xe2\xdec\xa0\xbcu78yt:r\x8b\xfcXF\x80?,>\xa1ldz \xca\xe6\x9a"`t\xeaV\xef~J\xf9\xc8\x10[w\x82!P&\xfaI_\xcf\x9b{<\xf1L\x83\xa7\x18\xe9\xba\x01\xba\xedG\xc9TM\xdd\xfa.>\xd7\x83\x17\x13h\x9e\xe7\x98\x86\x1f\xef\xb1\xd6F\xc4\xa3\xb2\x0b\xc8\x81\xaa\xb0Gs\xbd\xbf\x1f\x1f\xd0\xbc\x9b\x84\x9a\xc8\xbfG?\xdc\x92W\xdf\xf0\xa5\xd3\x83\xc5\x84\xe9\x00\x8b\xd9\x82\xb5\x02\xfc\xe9o\x12\xb1\xbfh\x840\xd3\xaeOUxm\x1cP\xe5\\O\x8dT\x98\x06YP\xd3\xb7\x99L\xdeW\xc20\xb6\xe2\xb4\xd3\xa3\x025\xdf\xd5\xb6\x1b\xe8\xfb\xfa\xa4x\xcb\n\xb5\x9e\xed\x8f\xd0\x05g\x94\x13\xf9\xb1Lu\'I\x847r$Y\xcbQ\\\x9c\xd5X@(\xfan\xe2={6o\x8eg\xb6\x07\xdc\xe3T\x11\xdbKA\xfb\x99\xa7s\x10\x84\x85\x17\x17P\xfe\xcfg\xf1B!\xea1I\x81\xe8H\x8a\x9el\xfe}\x92\xce(\xafL\x07XXqA\xb5\xa2\xfdc\xe1I\x969\x1dj\x1a\x92cY\x88W\xa5\x9b\xe2@\x15\xcf\xb5\xbd\x0f.\x87\x94\xe1\xef+\x14O\xacz\xd5\xdb\xbc?\xe2\x01\x8b\x91Ke[\x08\x07iL\x1e<\xc5f\xc3S,?\xf1\xb2|\x0eMyg\xc9\xc2\rd\x86\xab\x1f\xcc\xe5\x12\x91\xf2\xb2=P\x93O\x9d\x82?d\x9f\xfd\x95z\x80\xd5E\x1b\xe8l\x00\xfc\x15[\xff9\xee\x17Ri\xee\xdcbo\xd7\xbc\xc9\xaecA\xf83\x9e\x1f!\xf8\x1e\x84\xac\xdb{\x9f\'\xb3l\x1d#\x86\xab\x8f\x14\xf9\x1a>\x8aA\xb9\x0b\xbd\xa2D\xd6UW\xad6\xe7\xd8\xfdE\xf3\xe7S\xcd\x05\x8aM<\x1c\xf8"\x1f\xccS\x8f<K\xb1\xfb\xac\xc3>\xd33G\xd1\xa8\xaf;A3\x95\xf7\xe5C\xdbB\xd9\x88\x93\xd4:\xa4UZ\x03V\xe6\xd5\x07\x15\x8f\xae\xb8\xe8Q_\x91e\xbc\xb6?\xf6\xaf\x8d-q5\xf5\x93v!\xf9\xcc\xed\x9a\xaeH\xc3H\xa2\xb3\xdc}\x98\xfet\xc3\x18\xc2\x16\xc5\x82"\xc5;\xdf\x18\xb7\xbb\xf1\x9e\xa8\x95\xacI~L\x1a.\xd2J)K\xe5\x18xt%\xf9o\xfa\xc4\xe9\n\xc6j\x1a\xe54\xb0\xfc\xe7\xfb\x88H\xe4\x8d\x153-\xee\xccKf\xe5\x82\xf8%s\xc6_\xa8\xc9\x90n\xf0\xf2\xc5Y%\x9e\xcac\x98P\x92"`Dn\x8fr\xea\x93\xba\xb95~}\xce\xb4f%\x96\xeb\x9c\xdfD\xc6\x9c\xea\xf2a\xed\xae\xd2\xf7\x8f\xf1\xa5\xdaak\'\x9c%\xdc\xa3\xda\xba\xd7\xa9\xd7]\xc2\x1d\x19\t\xab\xb282\x95\xefy\xfc\xc2\x014\x8e}2\x89\xe9\xa1\x8fQk\xbap\xbc\xb3UW\xe9S\xaa\xd2O\xa9\xb8\xa9\xc9;b\x9a\xbe<"8g\x01\x19\xafb#_S\xaa\xc6\xd6(\x82\xb8\x9awg\xee\xf1\x83\xdc\xba\xe1\xdf\xf51\x17\xf8CH\xc7=c\xff\x97}\xd5\x1f\xc0\x1b\x8eu\xcaD<K\xe7\xc1\xc7\xc2\xa9\x8f\x1fk\x12\x95\xb1\xb71\x82\x9a\xa0\xf8y\\\x9du6/\xfc.+OU\xea\xd9\xcfo\xfb\x83\x19#"\xa7\\?\x16\xb4\x06[\x190\x90\xe8-\xfaA\xfa\x8d\xa2\x1f8\x9b\xec3\x16\xc0\x06~C\xc4\x90x\x14m690\xc0h\xe1\xe6\x05\xbb\xe5\x12\x0b7\xaf\x82D\xf7?\x07O\xf6\xb1V:H\x92\xd2\xee\xa51\x87\xc8e\x94\xf0\xc9\xf6\x87\x19\xec\xfen\xbe\xfc3\xc2|\xf6\x96\x99\xd3i=vAJ*;\x0f\xf1\xce\x89\xe4\xc0@j\x92>$\x90P\x17\xec\x99=\xf6X\xf4\xc6\xe9Y\xfe\xc3\n\xf8\x89l\x88n\xf8\x15\xe6>C\x99nOJf\xc5\xb1\xd7L\xf9\x02\x11N\x1d"\x85\xa6\xf9p\xd8\xcf(LO\x07d\xd2\xa9\xef\x17]\xf6[\x96\xa1\xa8B\xd969\n\r\xc5IKr\x89\xbaE\n\x15E\xbe\xb8\xc7\x1b_6.jK\xc5D5b\x9dn\xf4\xc9\xe5\x84s\xe7\xd8|!(\xd6\xa5\xc4\x14\xa8\x05\x8d\xc0\xe6 \x08y\x96EJ\xb3:~\xe1\x96d\xea\xa9s+\xa1\x92U]\xa8\xa0\x05\xde\x14q=_\x85\xb1b^\xbe\x8d\xc0\xc8\xec\xf4\xf2\x954]`\xea\xa7x\xaf\xd5\'E\x9ezD\x1d\xfc\xcb\x01\xaeY\xb1\xb9\xf7\x15\xe2\xcf\x00\xa3+\xae\xfd`~\xfe\xef=\xd0\xf2<\x1d|V\xea\xd2\x9b\x9d\xbb5\xda8\xb3Ob[\x98y\xdd\x84\x82\x8b+\x18\xee\x1d\xc4\xea\xff\x15m\xcb\xca:\xa2\x82\x83o\xc5\xd8T\xe9\x8b\xdc\xfa\xc6\xbfp\x90\x13\xf1\xa6\xaaF\xa6\xd0\xb2H\xa3\x1b\x12\x96\xc2\x03e\xbbN\xb8~\xb06\xba^!\xd5\xdd\xf6\xcb\x86\x88`\r&5B\xff\x97W\xf0\xfa\xb7\x9b\xe8\x93\xb7\x1d\x90\x1e *Y\xae-k\xe9M\x8f\xc4\x8e\xfc\xc4<\xd6\x97aP\xbfu\xdb\x1f\xf1q\x9fD\xc1m\x95x%\xd8\xe7\xdf\xa7\x92\xdf\xa6\xcc\x88\x0c\x97\xfc\x94\xa2\x8d$4\xe0D\x88\xa3\xa4~\xdbf\xf2\\\xab!\x1a\xbc~\xb5\xf0\xa4~\x87O\x14\xc8\xd9\xc9zw\xc4\xfb\x0fI\xd4\xdf\xbal\x95\xd9[\x96\x87/7\xd7\xa7\x0f\x1eo\x0e\xfeg\xf3o\x05\x8f\xf4\xe2\x14\x12\x1c\xfc\xc8\xe2\x9d\xb2\x87\x8f\x05s\xeb<\xc1\x9f`\x11\x96\xcc%b\x85o\xec\x82\xa2\x9d\x9f\xa5"\xado}p\x0c\xa7\xeb\x8f~#\x1eJ=\x0b\xaf\x8a\xfaV\xb4\xd2\xba\xe1<\x92;W\x14\xa6}\x03\xf0WT_\xd8d\x1c"\x96\x0f\xf0J&\xf5*G+h\x10\x8c\xc0\x94i\x02L\x1f8}\xb3\xfa\'kY\xcf\x85|H\xee\xce>\xfa\xd72{\xcc\xcd\xa3\xdasJ\x8d=\x82\xd9\x87u\x9fpB\x8a\xc1\xe1\xb3\xfe\x13\x1b\xbex+PL\xfaK\xb1\xd6\x03\x87\xd3N\x11\xb2.\xba\xd8\x18\x07\xc4\xcd\x94\x9a\xd93\x8f\xd2\x88\x81.\x93\xc7\xd3\x83\x85$\x15\x06\xe3\xb9G\x852\x03\xa8N\xb52\xb1\x0e\x94\x8c\xd1\x0e\xff\x90\xfcKh\xb9\x13C\x16D\x07\xe9#\x80\xb8\x96)|\xd74\xafFHe\n\xfa\xea\xe1\x95Q\xc8\x002\xcaC\xddig\xd1u\x85\xe2\xcaO\x82\x98\xbckI\xb8\x16"\x9ee~\xf9l\xe3d~T!Zb%\xe5\xc7\x94r\x00\xf1\xf7N\x9b1\xbax$<\x98)\xe4\xebZ\xa9\xa2\xffU\x9a\x8dNF]\xc4\xb9\xc4\x14ms\xa3\xd1\xc1\xdd^>l\xc8\xe0\x9d\x96\xcal\xd0%\x82\x99p\x14\x15\xdd\xbb\xa9\x03\x8aZ\xcbo\x1e~\xf2\xc1\xfe\x9aec\x93\x1d\xf6\xa0X\xa2\xea\xf2a`\xe4^\xa0\xfa\xc7\xea\xd3\xdf\xe7\xec-\xff\x93\xb7\x98\xfb\xcf\xd6DS\xd4z\xb6g\xce\xe6e8\xdb\xba\xa1\xaf\xee2\xdf\xa9\xe4\xfe(8\xf6+\xd7\x1e\xfd\xc1]}\xa2\xe1\x88\xc6&$\xfb\x1c\x96 \x024a\xad\x8a\xe9\xfe>\xa7fd\xbb\x93x\x9c*\x9a\xf7\xf2\xd1\xd7\xc7=\x9e\xb1-\xfb/T\xc2.e\x7f\x8e\xfcKg\x0co\x15\xbd-\x9e\x01QL\x7f~N\xa6P=\xe0>\x04v=4$\x1arI\xcaq\xc6g\xb8\xaf\xcd\x90;H-\xb3\x06\x1b\x9f\xa4\x17S*\x12\xcc\xe4\x93\xb1\xec\x8a\xa9\x0c\xc9\x94"\x80\xd0\x9d\x14\x88\x9c\xc3\xd0Y\x7f\xff4>\xeb\xc1^/\xbbH~\x9b\xa1\x06\xa16$\xc0I}\xa5\x10\x04\xcb\xfe\x0eYq\x9a\xdf\x15\xaa\x0b)\x8e|\xe3^\x7f\xdc\x8e\x07#\xcc\x7f\x03a0\xd5F\x88\xe0\x9aD6M\xe4\xda\xea\xb8*\x16g\reW6\xa4}\x1b\xa15\xc4\xb3\xca69\xba\xa8\x18\xabB\xfa\xf1\xe1\xdb\xe3\xa0i^\xbb\xd2\xf7 \xe4\xacl\xb9\xf7\xa5\xfa\xdc\x10\xcf\xb5\x9d=_0\xb7\x95!m#\xfaX<.\x08S\xe8\x97\x06\xbf2\xa09\x18\xc6\xben\x0c%\x93b\x0fS \xc5\xaf\xf9\x91\\\x80\x10\xbdR\xb3/\xccu\x9fS\xb3\x9cl\x80o\x80\xdb\xf9[\x1a\x9c\xaa\x10u\xfe\x85\xb1\x8e\xd0\xd3\xc2\xe78\x9c\xebz8\x05\x956o^\xf3\xb8\xb0\xfa\x93\xb6K\x83\x1b`\x02\xd1pl\x04\xdb\xae9\x15c=\xf6N(\x18\x84\x12\xb6\xb8\xdd\xaf.\xfa\xdd\xe7|\xe9#\xa2\xc5\xe9\x8e\x9a\xbe@\xf0Hz \x8b\x07nt\xca\xd1\xba\xbd\xdcZ\xf35\x0f\x9db\xb0+\xad-\xc7\xfa\x16\x83D?of\xa9\xda\x12\x03>\xfdp\xa1Eb\xfb1\xcb\x85\r\xed\x94\nW\xb8\xfd~\xe0@iix\x11<\x01E\x0e$\xfc\xd8\xc2\x83\xf6T\xffV\xe0\x02&VV\xdb\xd4\x8b\xb6\xf8\xfeQP\x89\xfd\xd0\x16\xfd\x9d\x06\\_\xffT\x08\xaf\x94MI\xc8\xeb\x07"@w\xbe\xac\xd0\x87P[\xda\xb1\x98\r]|\x08x\x03r\x0e\xb8\xcc\xec\xb0F\xad\x13\x1f\xd6\xac\x87SB\xa1d\x83\x02\xfa\nhm\xa2\x047\xf0\xc7\xf3\x9e\xa1\x82l\x0f\xd4\xadEZ\xcfU\xfb,\xd9kL\xbbF\xea]\x93o\x98a\x8b\xb5.\xf1\xd1\xb2\x13\xc8\x19\xae\x9a^\xd9sL\x16$\xb6\xba\x03\x04S\xb3\xdfC\xab\xdc\rt\x99>^\xce\x92\xc3\xb9j$\xfdH\xfb\x0bQY\xf1\x87\xe8C\x1d=q\x19U}\x14\xa2uG\x98\xe7\xdb\x950d$\xa7H\x88\x08\xedt\xcfA\x9e\xc0\x98\x15\xd3\xbc\xe10\n\x8a\xd1)P\x06V  k\xab\xab\\(\xbb\xd1\xeb$\x7f\xdd,\x8f\xc0\xc3=\x85X+\x90\xb3\xd5\xbf\xf7\xd1\x9c\xea\xbc\x9a[\x9bB\xc8\xdf\x15\xc1\xca4\xcc0\x14\xc1eGs\xe6\xcd5\x08u\xcb+\x1e\x1cJ]\xc2\x83m\xb0\x8a\x00\xaa$JH\x1dw3\xa0\xf9\x08v\x10\xe3X\xd7\xc1`\xcc\xf1\x1a~\xc5\xb6\xb3\x02$k\xcd\x19\xa7\x02\xa9\xc2\xbd\x12\xe0\xe3\xca\x9f!\x8b\x18\x0f\xec\xf0k{\xb1\xb1\xb0OX\xca\x8c\x15r\xc8\xc5\xbd\xd5\xb55\xe1\xfe\xb5\x8fV\xb5\xcc?\xe71\xf2\x18\x03\xc2f\xb5\xc3\xa0\x8eP[\xda\x8ey<\xc7\xea\xe7_\xc4\xa0\xee!\xff\x9d\xd0+z\x03\xe7VP\x8c\x8b\xf7\xe2\x85#\x9f\x18\x94\x0e\xf8S\xe6\xb5\xfc\x82\x12\x0c%\x97\x0eiU\x15;\xa5\'\xeeW^\xb2\xfa\xfe\x03*i\xbd8\x8c\xa3\xf6w\xfaiD\xe5_\xf6\x1d\xa5\xa7o\x97\xc3\x90\x91y\xcd\xc1r\xb4}\xd5\x98\xc9q\xa8\xcb7\x1d\x91\xc63\xc9"\xf9\xe3\x064\x1cY"Ix\xbe\x80\xccLT\xf7\x02H\x84\xed\xba\xf4\x99\x03s\xb0\xf1\x8e\x10\x94<=+\xff\x1e9\x85\x06\xc1\xd6;\xa6\xd1@\x8f0\xc2a\xc3D\x84\xdf\x13\xcf"\x07\x8e\x02R\xe1\x94\x87\xe9v*Q\t\xcce\x9a\x06\x88\x9d{\xec\x89\xf6\x10\xaa\xea\xb3\xd5\xfa\xad\x98\xc26\x85$\xe7\xfb\x00\xb1\x93-\x8eO\x98}\xe6\xf9?_l\xe5\xfd\x99\xe3\x11\x95\x16\xf7\x0c_\xd8\xb6\xc3\x92Kj3c\x16\xb3]b\xac\x8d\xee\xc7\x9b5\xbf\'\xd2\xb6L\xef\xb6R\xc9r\x15!\x9e\xb4\x0bk\xb9++h\x15\x8eK4\xfc\xf2\x1d\x8eg\xcc\xc1\x15p*\xe3=\xd9j\xef\x8bO\xbfl\xfb\xa4[\x8c\xeey:1\x94\xd7O{\x1b\xa6\x17\x9c\xa0h\x92\x9b8\xe4\x01\x17\xc9\xb3\xcc;\xd9\xf1\x9e\xd4\x9a\xae\xe3\xdfo\xaf\x0e\xd7/\x06\xa3P\xa1p-\x7f\x9d\xd4\xa5\x9b\xf9\xef?\xa6\xba/H9\x8a\x0bj[.\x98\x96%\x8ctD`\xce\xe4\xef\xe3yk\xc9v\x84\x0e\x11\xb3\x1a\xe4\xd4.z\xeb\xa7\xd3\x81z\x8d.\xf0[7\xc5\xcd[\xe5\xb7\xeb_\x9b\xa3\xba{\xf7.O\x87e*\x83\xc0\x98\xb4~\xe0\xb8\xca\xca\xa9(A|Y\x89\xc8$\xb3\xf2\x10\x8a)\xfd\xa2l\x95\x1c4\xc7\xf0\xb6\x04\xeav\x15\x00\xa1,\xed\x94]\xa1~ep\xea\xaf?D3#\xf7`\x1fX<\x0f\xb0;4\xec:\xc8\xb7\x16\x1f \xfe\xf0\xd9\xdd\x19\x85\x9f\xe0\x96\x8b\xf9\xcc\x83\xd5]\xd3\x0f\x12-;\xc6\xa3\x1c\x8fC\xe4h\xff~\x94.\xc7\x9e\xf0\x92\x10\xe2\x18{\xa1\xd2\xd0\xdd\xa7Pti>9^|\x1e\x1b5\xbd\x07\x946\xac\xde\xa1\x9b\xb7\xc4Y\xa6\x1d^\xfc\xb1\xae\x1ax\xbe\xfb>\xb2\x88\x85!E\x939\xb4SY\xfbG2A\xfc\x1d\x8f\x1e\xf7\x85\xfc\xc5\x15\xe6\x84\xb2\xbb_\xfd\x98\x82\x04\\\xb6\xeb\x87\x8a=\xcc=g\xc1\xd9\xa4x\xb4\xab\xdbL\xeb\x029\xc7F\x8e\xe4\ng\xcb|7\x92P\xfd\xd1\xd2\xc8\xe1\xc4\x17z\x99p\x8a\xc3=\x1e\xd5D\xec\x9d\x0ehf\xdc\xc4\xfe\x91_gv\xff\xc5\x03<+\xc8\x19Oc\x1d#R\x1e\xec:\xd7n\xf4\x00\xd8\x1c\xbf\xcd\xf9l\x13\xad\x13r\xf0(\x8a\xc9\xe6\xeb\x82C\xa5\xb5jP\x94Qo\xa52\xc8\x9c\xb3\x89V\xcd)KE]\xb2\xc5\x8a\x99\x07\x15\x87H\xa4\xb5\x10X8\x10c\xf52\xcb\x07\xb1\xa9\xb6>\xf3\xd3\xae\x10h\xbcu\xef\xb8\x06\xefC\xb0jq\xeb0L\xe9\xf2\xf2~x\xca~\xc9\x0cZ\xe5\x05k0\xa1;\xc4\xaf\xb5[\xab\x02L%\xee\xf7\xe9Q\xc7@\x00V\x81\xccL\xec\x16\xf8\xd5\xce\xf8\x05\x94\\\xbd\xb5\x9a4\x1a\x84C\x04c\x8eW\x87L+1X\\\xb6}^R\x04\x01:\xaff\xcd\x97b\x1dlM\t\xc7\x83s\x15\x9e/\xec\xa1U\x88\xaf\xb0q\xf0\xb8l\xb3\xd4\xf9i$\x0fp\x16\x97\x92\x15U\x97\xad\xb9\x9c\x9f\xe1\x97(\xcd_\xe3 \x85^A\xab\xe4P\xcd\x05\xae`BI}D\xfe\x9a3\xe5\xfe\xf2\x974\xb7\xe1\xa2m\nl\xac\x99\x9b\xf1n\xf2\x0fj\xda]\xdf*\xc8\xac\xd5\x15\xf8\xd3\xd55\x88|_\x10!+\x10-[\xdaA\xb2x\xb5\xaa\xf7x\xa8\x0b\xe5v:\xfc\xb22\x19\xe9\xcd\x1f;\xd5\x96\x16\x1c\xb7\x1aI\x86\x8f33\x00\r\xdc\xb1\xe4\xf0\x7f\x98\x14z\x06:\x8d\xafW\xda\xb7i\xbf\x7f\xf9\xec\x8c\x9ec\xe8\xe4\xb5\x7fq<\x17Gk\x92Ki\xb4&\r\xadR5q\xa5\xcdh\xf1J\xce\x17\x06\xdf\x05ql\xe9\x9f\xda\xb8\xc3\xdac\xf1\x98\xee.\r"%\xec\xe0\xbf\x94\x19\xcc\xbcv\xdc\xe7\xda\xd5\xa9\xa1 3\xab\rv\xde\x87b.\'2\xfe\x87\x1bS\x9f::Sj0Q\x04\x8d\xbc\xe2\x89\xd0Z\xf5\xd2\x9f,\x8d:U\xc8r\xfe\xf9D\xd2\x14\x88\xc0\x00\xb8$\x9c\x01,\xe2zZ\xc0;M\xe0\xed\x9d\xed=O\x14\xe1kYT\x15^\xb3A6q\xce\xfb\x11V\x908\xf3\xe7\xe6e\xd3\xf4Z\xb4\xf8s+\xa3\xf7H2\x1c\xe5RA\xfa,X\x8eVz\x7f\xe5\xf9q\xbe\x8b3%\xfe\xe6\xa7P\xe64\xf5\x92?He\x13\x04^r\x968\xcbc\xdc\x01\xd2\x9f\xfb\x15\xc2\x8d]\xfe\x06\xfck;\xc9\xc6^\xda\x0eJd\x91\xfc\xb7\xe7\xc9\xb2\xa4\x01\xa5NS_\xc6\x01i\xf3\xa1\xe9\x199\x17\x9d\x05\xc3\xc2h:\x9f\xff>\x9d5\x9f\xb47A\x91\x8f@\x90\x8d\x8f\xbf/\x8cYr\xe8\xdf\xda\x8c\xa6\xfe\x0c\x06\x99"\xbd\xac\xef\xf7 |\x81\x14\x991\xe5\x06\xc0\x12\xd68\x0bu\xa1\x0c,\x8e\x14\xd8K\n;(H\xaf\xc7\xc1\xa9\xb7]}\xb2:\xf5\xc8\xfd\x93\xbd\xe1\xacx)8V\x9d\xf5a\xd5\xcd\xbe=\x14#\x85\xd6\xe41\x01!\x96\xda\xcf\xd9M\xf49\xcfE($\xb1 \xfe\x81n\x07\x8b\xd0z8\x8c\x17O\x92^\xafj^\xe4\x02\xca\xdb\x021k\xc3J\xfe\xa3\xb1\x0e/\xc5\xf7\x15\xcf\xff\xe1\x05\xacu7\t~\x9d\xb5#\x8e1q:?\x96\xe8\xe4\x8d&\xe6\xa7]/\xd1=D\x1f\x9cx19\x00\x06g\x88\x13A\xc8;\xa9\x9c\xda\x0b 0\xb8JG\x04\xc8^\xe3O\xe9\xb7\xc3\xf03\x98\xfd&\\\x7f2\xe0\x87/N\xab\xaa\xd9\xb1Wx\xdc\x0b\x8btX\x18A\xba+\xf4Zs\xf4P)\xf6t~\x16\xbb\x89\x84\xb7\x08\x11Sg\x05\x10\x82\x95\xa7\x17\xed\xb9\x80\xfb\xfd\xf6_O\x91\xdec4.=V\xc4\x070\xc9\xdd\x7f\x12\x8bo(\xbc\xd8\xc0\xc8g\'i\xd5\xbf\xd544\xa98\x9b\x16\xd8\x8a\xd7r~\xacL\x8eY;B\xfd\xd6C\x16\xddv~\'\xf4\xb5\xaf.\xf2\x13\x8f.\xa3\xe6^z\xfa\xfc\x8f\xc3F\xcc\xd9\x9b\x8c\xb0\xf0\x8b\xa9\x7fFN\xbc\x87\x95\xf4\xeb.|Ln\x8d`\xc2q\x97\xf0\xce\xfcl\xa1S b\x9aY\t\xa9@\xe9\x82\x19\xadh\xbcinRv\xd4_\xe6J\xd5\xb48d\xcbj84\xd6\xf7\x1cWY\xd5x#\xd5\xbc\x93\x94\xcc\x82\xde\x81i\xb9\x03 \x81\x8e\xf6\xd6\x07\xf7\xd0\xf1\x8dH\x1dab\xbf5l\xdciHQ\x8a\xd8\x11\xe2\t\x8a\x16\xa3\x02!N\x86\x7f\xce<&Z\x17D(\t\x1e\x91\xf3Y\xe3\x8d\x0b\xe4\xfa\x93\x89\xb5I\xa6\xe8\xf2\xdbw\x88\x8d\xa6p\x8a\x91\xefb\xd8\xb1\x85\xeb\xf5\x03FE\x92\x91\x88\xd20\xe1a\x05\'\x10\xd4\xf38\xff\xef\xec^\xb3\xa8T\x91\xaf\xa7\x8f\xfa\xe2\xde\xb5\t\xd1\xc3\xebzP\x8b\x1b kT\xf1)\xa2\x8dl\xc7\xc4\x0b\xdd}o\xe2\xaeW^\xf4\xe5\xe6\x16\x1b7\x10{_\xd0\xdd\x19\x8a\xd7\x1a\xba<\xd1\xed\xa8\x9aR\x04\xa0v\xf0\xf4AS\xcf\x98\x82\x10\xa6\xe3\xc6\x1c\xf7\x17\xd3\xadZF\xc2\xcf\x0f\xff?\x04\xdc\x07\xa0g$S\xaa\xaa\xfd]4K\xddg\x99\x04\xa2\xe4\xaf"\xb9\xc3\x14\x8f#\xc7kL\x08g\x01\xae\xa1p\x8d$\xff/h\x0f\xdd\x03\xda$\xb4\x05I\x0b\x1a\x16\xec\x0b\xe5\xca\xdbF\xd7\xd2\xdc\xa8ZT\x1e\x83\xa2\xf4\xc4\xf3\xa6p)\xa5 IXUs\xa8\xdc\xeeS\xb3\xb4c\x0c_\x06u\xc5\xe9\x87R7\xc0\xda\xe8\x8db\xb0_u\x06o)\n\x08\x97Ga\xe6\xb8s\x13\xad@\xaa\x06Wv\x9c \xca\xe8\xd8\xc8\x7f[kE`M\xc2\x05y\x10s\xb9m\xe1\x0e\xc2\xeaC\xdc\xcb\xe8\\\xd5~\xa8\x0b\xe3*\x16\x8e&F\xbb\x1fU\x8b\x8a\x00\xff\xd8\xc7O?\x8c*vC\x91z\xe2\x05S\xb8\xe3eP\xbe\xfa\x7fx\xfc\x95\xef\x0e=\x87^\x1d\x1c\x8f\xb2\xd4\x98\xa78\xadG\x8al$\xc9\xc72\xb35\x0c@\x91=\x84\xc4\xf4c\x11\x81ue\xfe\x01u\x1d\xd4\xaf+\xfa\xf3!f\x1c[\xb3\x80y\xf3\xf2\x1d`\x82\xa2\xa7\x9b\x92\xe7\xf5d.\xbf\xdc\xdc\x12\xa0\x03.\x1a\xfd\xde\xc0[|\xda\x17\xee f\xd9\xb7\xb8\x98\x03m\xca\x15\x81\xb5\x9dw\xfb\rT\x06k\xe8Z\x9a7j\xf7\x87,\xd0\x03\x1d`"\xb3D\x13\x14\xf5\xdd\xb9\xc5#\xc5^%\xfdy=\xf4}\x9d\x1d\x98\xc7o@P\x8a\xdf\x8bZj\xe3\xf7\x84\xb3m\xd7 R\x02O\xeef\x9c\xda\x7f\x9da\xa4__\x9efNx\x07f\x0e\xd6\xf2d\x06\xe1\xc6{\x86\xd06&\xce\xe8\x82\x1d\xabxN\x8a:\x1b\xb9\xd6VD\xa0\x07M\xc4{\xe77\xdd-\xc2qF\x7f@\x1fg\xc7\x17\xa1\xca\x1f\'S\x86\xb2\xe4|\x87|y\x0fN\xa1L8Hc\x82g\xbeM\x91(\xda\xf2\xb6k3\xd4\xbf\x11\x043>U\x9c^\xbcT\x04\x92-\xa1\x16\xae\xe6\xda\xd0\xb0\r\xd8\xc6a\x1e\\\xbf\xad\x0e\xd5O\x7f\x87)o\xea\xc3J\xdc\xe9\x04\xaa\xbdh\xce)\xcbF\x95\x05\x03j\xb2\xa1\xd2\x02\xdb\xfe\xe0Y\x91\x00b\xf4\x1d\x0f\xe6\x97\x9f\xe5^\x8b\xbc\xcf\xcb\xa1\x99g\xaeg\xc3\x99M\xf9\xb1\x83!\xf7w\xab[\xde\xba<\x18X2A;S\xdea6\x9a\xc0\x91\x84\x18\tcX\x8b\xcb!Y\x1e6u\xac\xe8\xec\x01\xc7\x0f3\xae\xb1d\xb2Qf\x1d\xaa[\x81po\xf4\xeb;\x97\xc8*o\xe2\xbf\x0b\xa2\xb3\xad\x08\xe3\xf8\xc3\xd0\xf8\xa8\t\xf5\x19}\xb4c\xe5\xe9E\x1bE \xfb\xee.>&xf\xbbA0C(\xed\x96\x91\xcd/\xecGR\xde\x17\x87"\xc6c\x1c\xefy\x0fR\xab\xff+\xf1\xd5tq\x84\x85\xa55\xb1\xb1\xac\x17Z\x92\xb9\xd7\xa6\xff3~\x85\xe9\x80R\xe2\xeb\xb0 \xb1\x0f\xdcb[\xf3\x86\xca\xb2\x99\xe3\xeb*\x9f\xbbB/\x17\x87DG\x0ev\xe6i^\xaf\xe4O\xec;}\x99\xea/7\xed\xe6p\xa4\xf0\xee\x95\xe4\x12v+\x06!\xf0Dw\x07Fz\xc5\x01\xe5\xdc\x87,>;\xa9\x9fvPF\xb1\xa5\xf8\xf6s\xac\xca\x88g\xb4\xae\x99n\xe8\xb2%\xacB\xd4\x98\xb5SE\xe5\xcd\x13-\x05\xc9\xfc\xdb\xf3D\xd5\xb3\x82\xac\r\xecY\x08AQ\x12\x8aE\xc6\x90gv1A\xc9\x7fp@\xa8\xfe\x93\x9f$\x9c)\xfd\xe8\xfc\x0cr6\xb0>*D\xa1\xfa\x1d\\\xf1q\xf6\xdf\x94f\xd0\xeb\xb9\xd8\xc8\x08\x9c\x11\xad\xd7\x18~\xadSX\x8a\xac\xf6\xe8}\xc8\x99\xd5\x82Bo\x84\x80@>\xf3\xc1\xd9\xeb\x8e\x14\xfc\xd8Z\xc0l\xabSm_\x91\x87\xdf\xe1\t(T?\nM\n\xbf\x06\xf8JnS\x0e\xdb\x90\xa5\xcaJ\x1a\xdb\xc4\x83\x94\xf0q\x0c\n\xad\xe7,\xe4\x88og\xfc{J\x99\x1fO\x03\xd2\x10\xb2\x9a\xc3\xdf\xe1\tX\xb0d\xf88\x13\xd5\x80\x98\x9d;F\xf7\xea\xe1\xbb\x8a\x9a\xa6\xf54-\x0cr\xdd\x87\x82\xc2\x02oy\xc7\x86\xd5\xde{\x81\\\xb9\x9cC\xb2n\x7f\xfeg\xbb\xea<\xf3o\xfd\xfah\xfa;\x19\x87B\x19q\xb6\xb5DE\x9d\x8d\x03\x83>;\x8e\x90\xa8\xd9R\xc6\xc23\x03\x8d\xf5EzH\x02!`\x11\x9a\xe1\xed\\\xa2\x04\xc4`\x98c\x96$\xbe#%\x95\x13g\xdd"E\xcf\xdd\xd34\xd1\xd3\xfb)\xfaeo\xa7i\x07\x00V~\xd6\xbf\x94s\x83%\xcc\xaaX\xf0\xba\xae\x04\x88s]~\xf2\xf3\x98\xb1\xde$0\x81\xc1\xfe,\xe3\xa3\xec\x95\x01\xee\xb6\xc8\xd3c=\xa90\xfc\xec\x8eh\xdfl\xd23\xf0\xca\x97\x80\xbe\x99$z\x0f\x0c\xad\xf7I_q~z\x91\x1e0\xa7\x1aKf\xca\x19\xabsw\xb2"}\xc1\x9d\xa18\x0e7W\xf5\xe0-a[i\xed\xb8\xfb,\xe9\xf3\xe3\x9a\x13\xc4\xf2\x83T\xd2;\x1d\xb5\x81\xde\xcf\xc9\xb5\xcc\x9e\xd7\x99%\xe2\xa33> U\xfc\xc5\xc8\xe7\x19\xc3\x85\xdc\xee\xdfb\xde\xfc?\xf2S\x01}sQV\xad\xcf\x0c\xaf\xce\xee;\xfb\xfc\x8e!\xdf\xce\x95\n\xd1\x92r|K\xdb\xa9&\xaa\x9e\xc4\x87\xf3\x8c\xcf\xdfw\xaa\x16\xaf}\x91\t\xe1\xb0Q@V\x04\x98W\xee\x80\x06\xf8\xc1<\xa99\x17.LC\x0f\xae\x8ai\x97\xe6x\xae=.f\x18MT\x15\xcc\xa3[a\xd0\'\xbe\xe9t\xc1J\xd5\x17uX\xd0\x9e\xea\x15\x1e\x90s?@d\xbe\xbeC\xfc\xf7\xa8\x7f\xaf\xbab\xd8\xc2\xbb\xed\x1a\x89\x1a\x8e\xcdA\x93Yv\x1d\xc0\xbe(%\xf8iN\xd8b6\xae4\x85\xb7\x8e\xf9.dd\xf7@U~\x04$C\xdc\x83\x01?\x85[|\xd2\x1f\xaft\xce\x14\xbe\x9b\xb2p\x03\xdf5E.R:\xfbB\x0f!\x01\xe1|N\xfa\x9eg\xbe\x04\x9e=\x92\x1aPI\xa7>\xe3\xa2\x1a\x05B\xfe\x83\xdd\xa3\r?\x1d\xb9VUz}\xc2h\x8dB?-\x03\xb9;{!\xb2\xa1p\x1d\xa1\x9d\x02\x99>\xfd=&$g\xc7M\xe1,\x87\x00\x91\x0c\xcc\x9d\x18\x9b\x898\x1d\xe5\xa9r&\xf9\x03jI~\xc0\x9f\xb2\xb7\xe4\xbc\x969\xc9DjG\x19\xb9|\xb9\xf1\xc8 \xc7;\xea8\x0cp\x8c\x12\xa6\x80\x99M\x12\x1c\xc7\xbd\x83x\xbf\x11)\xeb\xf6\xf3\xd0\t!\xf0f\xfc\x7f\xb6\x95\x08`\xe0\xb1\x9fyg\x19\x11MR\xf0\x9c\n7L\xf8_\xc4\x9d\xd3T\xc3\xd10\xa3\x87\xa6.?\xbd8\xae\x08$O\xfc/\x928\x7f\x10\xcf\x14\xeb\x1b?\x9e\x7fv\x16\xff\x0c\xedL\xf1\x0e\x99[\t\xc2\xcap\xcd\x8d\x96\x1b4`\x83\xfe\x86\x89\xcc\x9b\x87\x86!\xc1UO\xef\x10\xe5\xcdI\x91\xa5.\xcc\x17\xf2Qu\xc1\x9e\x8c-\xd1V\xbe\x88\x10W\x94\xd1\xe9\xdf\xffm\xf9\x15\x01\x96OuD\x85H"\xc5\xe8L\x16\xa3\xde<\xc2\x8fY\xe9V\xedk\xa8\x7f\x008\xde\xe1\xef\xd8/\xad>\xa8\xb1\xde\xa7\xc8)\\\xca{P\xc9m8\xfb\xa3\xa2B\xdbS&\x10*\xf6`C\xc8I\xf3\x17\x90\xa7\\\x1bfR\xd4\x1c\xc7\xccZ\xa56\xad\xcc\x15\x85&\xa1,\xd5>#_Z\xb6q\x16\xb0I\xd0\xbd\xa8\x86S\xa5-_\xacO|\x07\xc1\x08\x8b\x1f_\x18\xb7N\xd1\x01!MO\xa1\xe8\xe1~*\xc2b\xc0x5(\xbf\x1e"\xb7[\xec\xc5r&c\xec\xf7P\xe3\x84\xbeYp\x8aO\xa2_\r<\xceZ\xd6t\x800\x8d\x8b\x9e\xec\x0fR\xc5s@\x10I\x01\xd6\x07;0\x93\xdf\x80\xe2\xb8\xa0\xc8\xcb\xa9?;*T\xe0xP\xbc1{/\xd4\xe5\xa1\xb7\x8b\x1c\xf2F\xe0\xc3Ao\xbfm\xbe\xe0\xfb\x1db\x89\xf1\xef\x14\x03/\xc0.\x05\xc9uu\r\xcd\xb5\xc5\xce"@\xbc\xdc\xd9I\xc3\x01\xeb\x830\xd4\xe8\xbd\x8b\x13 \xee\xb26\xe6\xa4_;\x10\x15\xd1\xeb\xeb\'bt\xc0ER(\xdc\xd4\x11M\x8e\x07/\xee\x10\x949\x16f\x16>F@q\xbd\x9f&*\xb9\xc7\x8d\xda\x88\x04\xf6\xd39&\xe9\x90\x0b\x7fi|&\xd4\x89\x98i@\xee\xf7\x9ef\xdb\xb1\x1fW\\\x9a\xe6\xc5\xeb\xfc\xacT\x95\xc0\xc5\xcdL\xe7\x10\xb5\xb7\x9b\x85\xd7pM\x94^\x80\x85M\xf1\xd5\xa5\'\x85\xf3"\x8b\xe1\x14\x07-/\x14B02\xb6\x88|\xf2O\xb4f~\x98\xa6S\xde^\xc9#*o6\xf7\xfc\xb1\xcf\x17$\x82$\x91\x19\xc8Nr\xd7\xe21\x15\x1c\xc5\t\x97\xa3\xde~\x02\x10\x03:K"j\xa9.;\x0bu\xf1\xfb\xda\x83\xc1\x064\xd4II\xfdkV3\x1a\x85iF\x88\x97\x94\xc90_\xd2X\x83\xa8\xe4\xf5\x95$#x\x81\xa7\n\x03P\xa9\xa6L\xe7K\x071\xcd\xb1\xc1 Y<\xb5\xa6?\x03\x10\xc7\x0e\xd5s/\xacC\r\xbc\x85\xb1\xcc~~\xea\xc6p\x9f\xd8\xc66LJ\xe6V\x93h&\xb7\xc6\xa5\x0c\xd6!*\x1f\x15\xdb\xc2w\x07\x04\x9cK\xa4\x1d_\xa5\xc9,~\x98\x135\x81\x00\x0eZ\x02\x04\xae\xcc\xe79\xeb\x8b\xe9\xf6\xb1\xf9x\xaa\xf8\xa6\x8f8n\x19\xf7\x05O\x8b]\xcfG1PQg\n!H+n\xba\xaa54 \xb9\xac\t0\xd4& \xb8k\x1d&I\xaf\x7f{\xd3F\xca\xc6\x9a)Bbfs\xc5\xc9\x8a\xfc\x0c\x1e\x86JyB[GjS\xc6\x9d\x92`\xbetV\x05ov\xd0{v\x16,Gk\x86\x03\x02\xce0\x9dn\x8ck\x80?R\xa5\x14\xe6\x10\xdd\x83\xd5\xbabD\x8a\x04\xff\xdc\x1c3\xa9i\xc1\x95\xe7\xd4\xfc\xc3\x08\r\xf5\x9a\xc2\x0f\xaf\xf9\xe4`U\x1f\xef\x9b\xc6\xcb\x1e\x07\xe8\xbf&@\xa6v\x9e\xcaI\xd1\x83\x92/\xdb\xb7\x8eA]\x1e\xb2]\xcf\x95\xc2$\xcd\xeb\xefO\x92\xdb_\x82\xc4\x88mV\xa4\xc8&<\xee\'\xd4Ev\xbcN\xf3\xe9u\xd1\xd9\x06g?d\x01\xadBTD\xdf,\xa2"}\xa9\x08D\xd5\xa4tr|\x9b~c\xa1\xd8\xb6&\xa0\xa9T\xdd\xc6\x9c\xd4\xb8V\\%\xd3Q[\xdc\x1c\xba\xe5\x05\xa1z\xe5\xd2\x8f1B\x16\x1fa(\xf7\xaa\x19\x02p\x0bM\xfa\\\x86\x1b\xb8HDj\x8f\xb7\x83\xa0x\xeb\x8f\xcbT\xd8x8\xd5\x81\x11<p\x07\x8a\xb9\xfc\xaa\xdc0B\xc5\xd9\x1c\x85\x00\\\x8d{\x84\xb6\x8f8v\xbe\xb3#i\x8el\xfdF\xb8V\xf7(\xbc\xd5c\xf0+T"\xe4h\xbbp\xadG\xab\xef\xad\xb9}S=\x08\xf1\xbb\xf5~\tp\xe3JE0B\xf2\xf9\xc23`\xee\x1f#\x12y~\xb1l\xc2\x18\x1f2\x02h\x9d\xe2\xe6\xea\x83X\xd2p\x17\x9b\x85\xd1\x1e\xfa\x99Q<\x95\xf1\x9eS[<L\xf1\x1e)\xd2)\xc0\x9f\xf8\x9f\x82\x92\x8d\x00w\xdd\xcf\xbcC\x03Z%Fz\x1f\x0b\x9c\\\x98\x87\xd2\x1c:t\xcf\x84\x02K\xc4\x8a\xe6`$\xe6\xa4\x7f\x1d\x08D\x84s\x94?1\x9f\x0cJ>\xf1\x04\t\x84/\xaa\xe1\xcd\xef\xb4\xe8f\xf0Y\xad\xbd\x89\xff\xb3\xed\x99\x8e\xfd\xac\xb9\xc4*\x8c;\x07N}\xc7\x96\xd1\xc2\x00w\xc62P\xbc\xcfr\xcf\xe0s#<wGb.\x19~d\x86\xc5\xbf\xeco\xd4\xa3\xbd\x049\x8d\xa9\xe1\x84\x109L\xec,\xfc5\xafA\x9e\xd6<\x84\xa0$\x02\xfck\xfe\xd4\x1c\xbfy0\x8bn\xbb\xf6\xe8\xf3~\x16\x01\x9c\xea\x03\xf1\xa9\xdam\x085\x07\xca\xa5$2\xb7\xda{\xf8\xd1`\xd4\xb7Q{\xf6*\xce\xd3\x04\xdeH\xc6\xbd\x02\x92g\xfb\xb6\xf9\xc2\xbc\\\x00u\xd3\x1c\x14\xfb0a\xf8\x10#4\x918\xda\x97p\x041\xeeN\x1e\xfc\xc1\xfe\x0b\x94t\x03\x0c}SS\x1bs\xd2\x0b\xce\xe0\xf9 \x84#\xcf\x8f-\x14\xc0\xea=(Fq\x18\x10\x14\xe3^\xfc\xb0\xce\x94\xab\x01)\xa3z\x1bMR\xe3\xe6H\x8a\xcf\xb8*\r]k\xc2\xf6\x8e\xc1\xc0\xc1_\xbbxr~W\xdb\x92\x1cC\x1f\xe1\xc8\xf8\xbd\x8fV!2\xe6\xb51\xb3\xb1\xea\x9ch\x8b:\x96\x83J\x18\xbdvqN\xab\x0f\xa1h\xa9D\xc5}\xd0\xbb\xba\xa5s_\x87/\x08\x18\xd5\xe7\xfdlX*\x1c=\xf1\x7f\xdf\x9e\xf7G\x88\'\xad1}\x89\xac\xa6\xab\x8d\x8b\xcd5\x90(\x9a\x94M\x8e\xef\xd43\x02d\x0b+\x0b\x05\x98\xaf\xf3lV\xecTx\xb4qb\xa0\xc9S\xa9\xda\xdcP\xed\xeeA\x12\xaa\x1a\xc8\xda\x9a\xd5\xa6\t<\xb0\xb3eh\xc3\xb2\x03{\xa0\xf31\xbe\x9b\xbbo\\\xde\xf0[\x86\xa5\xc2\xdb\xde\xe9\x8d]\t\xa3\x08\x8a\x18\xf4>\x12\xcb\x9dt\x90\xaa\xb5\xc5\x8a\x07\ry,\xaa\x12:V\xf0\x9c\xad\xf5E\xfbNY!Wh\xab\xa5\x0buWr\x81\xb8\xcd\xe95Q/\x00z\x99\xb5\xff0B\x16\x05\x06\x8d\x83\xfb_`\xa8o\x8b\x18W\x9d\xda+\xa7O\xe6^\xe1#\xd87\xc5\x13\xa6\xb1A\xb2\x87/\xa0\x18\x17\xef7\x8c\xab\xa7\x15@\x0c\xe3\x9e\xd3\x8b\x04b[\x8d\x11o\xd9\xee)\xb9\x1dR\xff\x18w\xaa\x8d\x12\n\xe4\xbe\'\x14=s\xbe\xb5\xf4\xb5\xee\xa4Q\xd5\x9f\xf6\xc5\x9d\xef\nd\xee\xb2\xf1\x19\x7f\xb1_\xbbhU\x83\xa0&xsz\x9c\xe6\x00\xd4\x85R~\xbe3\x00B\xb58\xa3\xe6\xe3/\x061\xb3\t\xfc{\xbc\xc0\xed\xdc\x14\x10\xb0\x8c\xfb\x90p\xc2\x96\xde\xbbs\x1aFs\xadK\x0b\x16\xa4\xb5\xc9\xbb\xa2b\xc6f\xc4vm\xdc\xbeXc_3\x0cE$)\x02,\xe2T\xfe\x12\xdfh\xc4\xa82\x96\xa4C.h\x9e\xb2\xe4\xe6-\x1cX\xd7\xe5k3\xbd\xab\xe1\xd4Z\xb1\xc1/\x11\x16\xd5p\xb4"\xd7\x9cMg\xf7\xe7\x18\x98\x1d\xf5\xe7zK\x8c\x99\x03\x08\xb5\xb2aq8\x0c\x95\xacV\x04X~\x8e\xcdh\x07!\xe4\x9a\x9c\xb2\xe0m\xe9\xa9\x85m\xccI;\x81\xd9\x9a\x96\xea\x8c\xabv%\xe3\x92S\xbb\x95\'\xde\x0f\x83\xbf\ra\x10\xbcG\x07\xa0\x07wNx\x1cqY\xa5\xe0\x9d\xb4\x06\x94;\x00\xdb+\xbeV\x87\r>\n\xba-s2\xabK\xe2S\xafU\x11m\x83\x90\xae\xafc\xd7\xaf\x10[\xedx\xf0\x1a\xd76\x8eR\xed\xa4\xbc\xbb;b\x16\xad"C#\x85\xa72\xbe\xaa\xb3\xabM-}\x05*y\x98\x15\xc5\xe0\x98\xd1\xad\r\xbc\x92\xb2\xa5%\x94\x98o(\xc20\xdb\x07\x1a\x8d\xb5\xa3\xd0\xb9|\xd3\xff\x1b\xbba\x10\xa5\xed\xae\xbc\xd5\xc1\xa7|4\xd2\xdf\xe5!\xee\xf6}\x1e\xea\xea\xc6\x7f\xa3\x14\xd3\xcf\xd0a`I\x8a,\r5%\xa6\xcc\xd4\xb1\xd6\xd0\xae\x80$9\\\xf2gij^>\xf8\xf9\xd2\xf6z\x11:gu\x02\x87\x9b\xbf/\xba\xb7\xb8rg\x8c(\xec\x90\t\xa7\x1eN\xa4I\xb6\x05\x1bl\xe5\xbb:\xebZ|\x9dz9\xabQ\xc6\xe1\x05`b.\xc4!\xea\t\xc8i\x9c\xd7S\xf3\x05\xdb&\x98\x94\xbdj\r\xc5D\x1en\xc3\xad\x02\x08%\xa5\x18\xb5A\xad\x93]\x95\xea$\xc1\xbbC^1r\xbd;X\xf5M\x16\xa2k\x84\xc1|\x04\xb2\x0cNe\xbc\xbdo\xfb\xb4\x02\xe0\x02\x0c\x84$O\xa59tn\x7f\xb6\xa3AT\xcb!\r:\xfaX\x85\xa4AZ\xa3\xff%\x9ea\x8e\xe18x7\x8e\x8b4/\xb9)\xa1\x9d\xe8\xbd\xc4\x97\tc\xe8\x1c+\xc1\xe9\xda\xd1\xb89CoW%]\x8fi#\xaf\x90\xcf\xc0#\x80\'\xc0F\x94\xd3\xa0\xe1l\x11R\xe0\x88:\x08\xb6][=\n\x8e\n\xdb|\xfc\xc6\xa9A\x9c\xf6\x0b!1w\xf2\x10Bm\xd6\xc6\x14\xcc\x1d\x80\x0eB\xb2\xd7\xb6\xe6\xf1\xa0\xd6\xcc\xf1$\x12s\x12\xcb\xb7A\xa8\xd4\xa0"\x90\xac\xd7\xcd\x17\xe1\xec\xb2\xa1M\xcf\xea\xf0n\x1d\x8a|\xe5:M\xf7\'m\xc7\xef\x0f2\xfa<\x0fN\xc5\x99\xa7\x8d6\xe7N\x06\x87f\xeb\xdf\xb8\xec\x93s\xdaE\x13>\xec16n@T%\r\xae\x18\n\x1b\x85\xe0\x9e\x01m)\xdd\x05B\x9b\x15H\xf7\xcb\xa8\x92\x97gL!\r|\x1do^\x1eK\x90\xf9\xd0G\xfa\xa7U\x18\x84\x83\xab\x8d\xe2`?f\x9e\xe5\xe5\x04^\xbf\x887\xf0+\x03J\xd3G,\x92a\x13Pi\xe4\ny}\x81 \xf9\xf3\xda\xf8\xd0s\x03n\xb7\xc3\x11\x0e\x14\x1fva\x15Bx)\x02\x188\xf6I\xc5\x12\xb7\xd1\xaa\x9fNX\x0f\xa2g\x1a.\x90i6\xdfV\x1e\xce\x98H\xfcY1\xfc\x82\xa8\xbc\xb2\xa81Q\xf8\x9f\x18\xd9\xdbcj\x17 \xd5\xa0]\xeac\xab\xf34\x88\xe8\xea8\xdcb\xf5\x15\xe0\xe5\xa4\x03\x04Y\x1b\xfd\x84n\x0ft\xe6\n\xd7[G\x93n#A\xce=\xeb\x1d=\t\xf66\\\xe1k\xab\xee\x00Vi\x1eU1\xaf\xd6~L\x99P\xde\xfe\x0c\xf70\x0cv\x10\\\xc9\x82UC\xd3\xf8m\xa4rT\x9c\xf3B\xac\xd9\xa6\xf0-^\x80\x11\xa39Br\xdcx\xf0\xd2\xc0\x86<\x9a\x9f\xfc\xcd\xe1-(\x11\xf5\xd6\xaa\x01\xfd\rFJ4\xcd\xa7 =\x066\x1d\xf1k;\x0b\xd9\xed)\xf3\xfbJ\xd3J\xb0\xc1E\xda6\xe4\xd3\x1d;\xd5\xcb0z\xda\xcd\xb1\xbc\xd6\x96\xe2\x0e\x1d(YJ\x96\x8d8\xc7\xadK\x07\x08\xbe\xa5m#\xf2\xd3&W\xb8\xfc\xa0!)$\t\xfb\\\xc1$\xdb\xa1\xab\xb4\xad\xa4\x8e\xbf\x82\xa1>^w\x04\x8c\xc5\xf3\xaa\x98T3\xac\x07Z\xe6\xf6G\xf2\xcd\x9b\x9b\xe2H\xc8\x12\xda\xa6\xc4\xd0\xfc\x12I\x83\xa8J\xbe\x0e\xe2yx\x80V%F12\x9f<\xcf\x18\x07<\x0b4\r\x93\x01\xb5c\xb9nW{\xf2\x19O\xd5:\x16b#\xc3\xd6\xbe\x85\xb6\xae\x12\xde\xf1\xfe\xa3[\x1cq>\x95_rf\'\xd7\xe8\xdb\xd1\xa9\x83d\xfe\x07\xad\xee\xa74w\x90\x05?\x14\x18Da?\xcejk\\Q"\xc7\xab\xe0j\x87\xe7%\n\x9f\x85\x19:\x8f\xd84\xe6"_\xd8\xb6S\xa5\xad\x9b=\xba N\xea\xf1\x05\xc6\xd3\x16\xe8\x1d^<7\xa7\xb2\x9e\xca\xf0\xde\xb1\xe7)\x93\xffv\xcc\xe1\xff\x97\xcc\xf3>U(5\xae\xf6\x1f\xd8\x15\x1e>\xa8y\x16\xf1!\xb9\x83\xfc\xcb\xbc\nI0\xe9e\x07\x17?\x11+\xc4\xf2\xcdy\xfei\xf7\xa3\x11@XV\x08 Yk=\xbb\xa1y/\xd2\x8d\x01\xcf\xfa.M\xb7\x82\xf7\xdf\x7fEd\x9b\xab\xbao\x84\xabHZ\xc8%\xd5~\xaf;\x07S\xbfK\xe8i\xa2\x83C\x98\xedv\xf2\xc9\xc8\xdbP6\x7f\xed\xa1\xc7m\x99\xb01\xa8\xdb\xf3\xd0\x12\r\xd8L\x17\xd4\xcd\xc8\xfd\xce\xd4\xc2\xa6;\x80\xb8\xa858H\xd5\xfa\xaa\x1eN\xa9\xe7\xa6\x87\xc3:{K\xbfs\x17.j\x92\xfeB\x1ck\xecGv\xb8\x05\x82\xa73\xd9\xb5{\x89\xcf\xa7?\xe8\xef\x9e\xe5\x0b\xc1\x93\xe4#\x87\x88b;\xc6_]\x97\xba\xa7\xbc\xde\x82\xbd\xc6\xd6\xd1\xd795\x00\x96\xaeOn\xb7A\xd3x\xce\xd6\xc3j\xaf\xbbt@\x8d\x87c\xdaK\xa6\xd0\xd7xb;:\x10\\\x1c\x1e\xbb\xbc\xfb\xccm\x9eiw%\xf33\xf7\x1cR\x85\xe5\xae\x13B\xe2\xfa;\xa6\x83~\xd3L\xb8\xa1c\xc3\xeag+\x08u{\xee\xf2%\xa5Wu\x02\xea\xc6\xf1t\xd7\xf6\xd1\xcb\x18E\x80\xc5\xb4\xbf\xf3\x94\xcc\\U50\x92p\xd3|\xf8\x19\xbe\x0f\xabn\xea\xb1\xc8\x1c\xd5\xb6\x17~\xe1\xe2l2-\xe3\x7f!\x9b\x8a\xd2\xd6*4P[rs\x8e\x87\x1bR\x02D\x18*\xd7\x1d\xc7T\x18\nO\x124\x0fP.\x16\x1e\xe6$\xe7\x82]i\xbb\xe4k\xa7\\\xe2\xc8\xf1\x8e\x9cY)N69E{h\x15\x1f\xf4\xb16\xd3.3\xc8\xd9\x9e\xce#\xf4,l\xe3\x91r0L%\xed\xb2\x90=\xe0g\x89\xf8\xe4\xb9\xdf\x07\x15\t\xcbq\x08n\xbc\x85YG\x19\xc2iO\xeaZ\xaae5\xfa\xd98\xba[\xd4\xcb\xa53\x08u\xc9k\xf4\x1b~}\xce\r@N\xc1\xdc\x12)\xe3C8o\x97\xfde\'\xc3\xa0\x08;\xd3=\x9c@\x9d_\xc3\xdf\x95\x8b9l\xbe\xda\xdc\x15\x86Q\xff*s\xf0\x92\x9d\xa6\x04\xeb\xfa?\xae\xcc\x16\x0c\x0bu\xf9\x8a\xe3\xb0\xb8\xa1\xe5\xbf\x89\x1f\xa5\xfd\xad\x19T{-q\x80r\xc9\xff\xfdU\xc2\xdd\x91@\x04\xe6\xdf\xa4\x13\xd9\x13\xc8\xf1\x8e\xdf\x89\x9b\xaf\x91l>\x0f\x1eQd\xa1\xe3{\x16\xa6\xe6\x18f\xec@\xce\xf6\x93\xddV-\xe5`\xe2}\xfc)\xe1\x89\xc1\xff\xe7\x13\x04\xb6\x89\xfc\xc4\x92\xa5\xcb\xc1)\xb1\x85\x889\xd7\xdc\xdf_%\xd2 \xbf\x05gT\xdc\x0f2\x1a\xdf\xd0,!h_t\xfchty\x94\x9a}\xd9\xbc\xc9\nI+f\xa3\x92a\x9d\xd02\x8b\xfb\x00\xee4\xed`O&m}\xe6\xdbjXv]\xf4hd\xfd\xf6\x03Z>\xc36\xfd\x9d0>b\xd5\x9c\xf6\x01vE\xfd\xe1\x94I\xde\x07Z\xe2\xb5\xb6\xccV\xa8\xab\xa3\xda\xd2\x89\xf3\xfb\xe1\xdf3G\x98\x87\xcd\x84x4\x9d\xfb\xdf&\x1d\xc5\x15u\xbd4\xec"\xc6uW\xd2ae\x18\xcf\xda\x9a\x95\xab\xa4\xc5\xac\x08\xb0<\xf9\xafp\x10\xed\x92\xa7?R\xeaF\x16\xdct$1\xaf\xcf\xfa:\xe9\x14*\xf3\x1e~\x1f\xe4\xfdS\xf3\x15\xfep\xa9\xf1\xddK\xdc\x120\x14\xfa\xact\xc9K\xa1Z\xecW!\x8b\xc6\x97o\xbf\xfc(L5u$\x18\xb8\x99\xb9\xf7mv\xfc*\x84\x90\xdb\xdb\xf39\xf7\xfb\x9f\xce1X\x98\x88%\x13\x1d\xd03q\x1dGQw\xac\x81Y\xfb\x0c\x92\x85/\xf9\xd8\xd3\xd9G\xde\\\x1e.\x10;\x94\xc1\xabt3\xf0_\xbf\xf4Z\xcb#\xb7\x10\xfc\x84j`\xe7\x1b\xd1\x9e\xc0\xb4Pc\x04\xcd\xb5\xb38\xa1\x1aT\xc7\xca\xcbps\x06*\x85}\xed\xf2\x0b(\xf9\x90heO\xc3hsJ{\xeb\xf8\xba\xde\xce\x1f\xec\xe6\x85c\xd9\xad\x87Se\xe9\x8cc\xeeA\xbc\xdc\xc4@Z\xc6\x00\x93\x08t\x1f\x98bM\xae\xee\x85<\xea=\xfc\xa3\xb0\xfdb\xe6\x8a3\x86)\xc6\x844r\x17\xb5\xc5\xcch\x12\xba\x88\xaf_\x0cF\x9d\xb3\xf8=0\xb6\xd7\x96\x86\x8fM.d>\x11ahV48I\xd4Ov\x88B\xd9.\xbb\x8avR|\x84\xd4\x8fB\x93\xa4\xd7}\xd8\x1a\x03R=4\xdc\xf7\xf7\xf0\xe0=*1~M\x86\x99};\x1b\x0f\x82\xd4\xfcO\xcc\xa5\xbaD\x85~\x04\x9e\xcf\x19\x97J\'j\x02\xd7\xca\xff\xe1\x9aU\x8b?!\x94b\x97k\xbe`\xdd|p\xa8\xb83\x1c\xc7\x0c\xfcf_/.;jM*w\xee\x1c\xee \x98\x91\x92\xa2-\xc3/\x11\xff\\]\x17\x01LFH\xd2 \xbc$\x14\xa1\xd9\xb4\xadN\xf4;\xe3V\x1f\x1d\xf2\xe1f\xf6\\\xf3K\x0c\x91 \xb4\xbc(\xd3\x96\xf6\xb1\xb5\xef\xa8\x8e\xdd\xea\xcf\xb9\x9b\x9c\\\xe8\xab#\\+\xb9\xe0(\xda\xa8\xb4\x1e7]\x99o\xd0|\x9e\xbd\xdb2\x10C&\xe9\xec}S\x99(\xbcN\xdc\xf4\xdak\x84\x9b\xda\xd3\xdb\xa9\xc5\xfd/\xa2\x88\x95\x9c\xe2\xdf\xbcW_\xe0\xba\x0cB\xb6W\xc0JXD\xe6p\x18\x9a\x0e\x94\xec\xa2WR\x9b\xe3\x1bn\xb8\xd6\xc7$2\x8f\xe4\x92\xe2fP\x11oL`~\xc8\x83\x18\xba\x95\xae\xee\xcac\x08\x91K\r\xdf\x91\xc6O\xdaH\x1df\x08V\x98\xee\x0e\xd53f*\x1b*\x1d\xa3\xfa\xf6\xae \xbf\xe3\xf6a\xa8\x07\xf2\x1c\xb8\n\xccE\xc2\x90w\x01\x97\x9e\xf4\xed\x19V\x90\xb3\x95\xb9\xf1\xbem`\x91J\xedOYn\xa0\xe2\xd7/\xbc\x0e6\x03N\x95}\xf7\xae\xfaB7\x7f\xfe\xb5\xae\xe7\x11\x0b\xf9\xd8%~\x00/\x06VJ\xe8xl\xc8\xaa\xe4\xa8\xb1\xa7\xfd\x8d<2\xd5b\xdc\r\xe2\xc8\xf1\xffK\xeb\xcdV\x94\xe6/\x16\xb3*\xffh=\xd8K\xd3\x00\xf9_\x83W\xe3\x0c|\x90~h\x87r\xea\x0b(\x19\xc0\xb8\xdb1\x15\x8e\x92r\x11\x97\xd1\xd6^\x8a@\xf6}\xb7\xcb\x00l\x0e\x9cZ\x9fpxU\xaf\xb0\t^\x18n|YMu8\x01\x95V^\xed\xbd\xa3\xa14\xa1\xe0\xeb\x01y|V\xbd\x1ay\xb4<\x83xH\x97ygT6P\x87\xee\x7f\x19\xf3C\xa5\xa8\x86S}3\xd0d\xa3\x92\xc7\xbb\xa5\x99\xaf\xbe\xf8\xd3|\xf2\xf1\xfa\xd2\x92\xcb,o?\xcc6\xe2\xd9\x12\xbe\xa4b\xbcA\x85K5\xe6g\x9b\x8f\xbfPr\x87\xc4\x92W\x17\xbe\xc2\x8b\xfbl\x1d\xff\xb89I!I\xc4\xe0\xeett\xbc\xc2\xd7xaxa\xd8\x19\xf7\x89\x84\xe0\xa75\xb8\xe6\xb6<\xec7!\xd6\xe9qg\x17\xc1\xfdS\xaf\xc7,\xa4v\x8f\x83\x94\xdaf0e\xb7\xd3\xf6\xe0,[\xd8\xe76\xb2O\xcbt\xba\x93xX\xfbQ\xaf\x9e\xba\xc4rx\r\x83\xbc}g\x8aMd\xbf\x7f\xfd\x88\xee\x1e\xc5\x07\xf8\x1c\x8f\xa4W\x8f\xf7F\x1d\xb5c\x1e\x96\x15q\t\xa2\xef\xdeS\xbe\xe1P\xdaR\x02\xc1/\xef\xc3\x91\xafw\x83\x9d^\xc7\xc3\xa9\xf5\x89k\xe3x\xaac\xb3Go#\xc7\x7fL\x05W\x1a\xfd\x0cNN/n_m\xca\xbewF\xfa\xc8L\xa8\xdd\x8f\xbd\x07V3\x86)\xb3\xf0\x02 v\xd9\x0e\xbf\xcc\x9b\xfa\xbe\xe1\x1a\r\xa1\xe2^i\x12\xdf0b\xc8"H\x8f\x89\x7f\xbc\xa5M\xed\x0b?s\xdf\xd74}|9H%\xb6\x87V\xf5\xe1\x7f\xec\xe9\xb6\xee\x06@\xb8\x9a(\x97^\xe1\xb9\xa2]X\x15\x7f\xcb\xd0\xceu\xd0\x8e\x15\x07\xcf\r\x96ir~\xf1\xa2`\xf0\'\x99}\xd8\xf6\x86\xb4\xdd\xed\xbfY k\xf8\xe6\xfb&s\xb9\x8b\x9ctr\xbc\xc5r\xf1WP\xe7\x18gK\xa0\x97\xed\t\xf5\x01*\xee\xb5r\x1b\xbdta\xdfKY\x1a\xad\xbb\xf0A\x06\x92\xe0\xf1\xa9/\xbb\x9a\xb3\xa1<\xf1v\x03\x9fFOA\xd6\x97\x0f\xe0\xc8\xd7\xb1\'\xa2x\xaa=c#\xb2\x9c\xc5Q\xfd\xd0A\xd7\xda\xf4\x8c\xc2B\xa3\x90\x99\'A\xcdW\xd9p\x93\x95\xda\xbe\x17Y\x150f\xba\x90\xb0\r\xb4I\xa4\x81&\xea\xf6n\xb0\xf29\x8c\xa4\xb0\xe9w\xde\x14\xe2{\x94\xcaAp\xff\xb5D\xe6\x0e\xb5\xb3\tT\x97\xfc>\xed$\x03\xc1\xd2c\xb2\x0b\x1a\xb4\xef g\xf8\xf3^\xd2>x\x98\xa1\xa5:\x1d\xf0\xd7A\xca&\xab\xc6_\x9e\xce\xa4\x0e1\x92\xfb\xcb\xfa\x80\x13\xdb\xe7N1\x05\xc52\xfcc\x97\xc0Z\xc5\xa0\xca\xb7\xfb\xee\x96\x15\xca\xbe\xbfyY/\xb3\xe1\xa6\x11\xbb\xf2P\xb4w\t\xa8\x84g\xf9[\x8c\xc4\xcc2\x9a\x10\x1f\xcea\xc8w\x9a\xcaAx\xf9\xe8\xebx!\x89\xadeo\xfc\x84\xf8\xe4K\x9e\x9c\x83\xbd\xfe\x861\x19/,mQ\x18\x16\xe7ep\xb8!\xf6\x8f\xb3\xe1\xc9\xd8Mv\x149>\xc0n\xaaUx\xb7\x18nZ\x8c7n-\xf5\x99\xfa\x19\x1c:%9n\xd0\x89-p\x10\xd6\xf4\xb4Y\xe0\x88\xb9=Q\xdcY\xe2\\\xdf\x03\xf5\xd0s\x91,\xa6\xcb\xfa\xdc\x17!J\xcc\xbah"\xa4\xfe\x02DZ\xf9P\xa91\xd0\xf3n\xa4:\xea<\x1a\xde\x86\n\xee_\xea\xff\xc8\x10\x04}\x0b\xad4\xba\')P\x15\xc2Yx\xac\x1d\x1a\x9f\xfc\\\xf9\x9a\xe9a[\x9f~VqT\xf8\x08\xb4\xcc\xfa>\x80\xdc}v\x03 \xa79\xe5\xd7\xa0\xfb\x9d+\x0b\x08\xc5\xef0\xd5\x9a\xeb]n\x0e;H\x81\xa7\xe8AOM\thK~nb\\j.H\x18\xf3=\xf7:k?\xf6\x02I\xa2:\x96\x1c\x1fP\xb76\x88\xa7\n\xb7\x18\xf7\r\x98\xf1\xa5\x86z&\xcf\xcc\x858pb7\x06\xa3\x8aC*\x8d\x88\xc90\xb5_\x84:t\xfcn\xa3/f^5\xcen\rM\xf8\x96>\x88\xe7\xca}!\x02\xfc\xac\xc25\x9bR4A\xcep\xaa^\xe7\x9e\x16\x1fG\xed6h\xcf\xbaW\xa5\xe7\xaa{\xbd9~\xb7\xf3[\xee\x14\xc1\xfbv\xf3S\xea^9\xce[\x9a\xac\x12\xe1\xb9\xd6\xd3\x92=\xe2\x14\xbd\x83\xb6\xbe\xa6\x08d?Q\x19\x92\x0f\xb3]\xc4\xeb\xde\xe8\x93\x03Y\xdb\xfd\'\x81\xfb0\xbb\xeb\x99O\xd0\xbc\x03LzFd\xc9#\xdc\xd3\x85o\xff\xd8R\x9d]\x9b\xaf3\x16\xe4\x0c7\xe9\xac\xe0\xab{Ud\xf9\xc7\x1d\xc0\xb7}\xc3\xf7\xb1\x87x\xb8i1So{\xfb\x82\xb0\xbdz\xbe[\xc0"MSb\xecx\xffT\x93\x08\xb1%T\xaa\xe8\xde\xdfN\x13\x92n\xcaz\xac\xaff\xcc\x89\x03r\x04*kn\xf7J\xeb*\x10By\x97\x83Jv\xcdD\x81\xcbR\xb8\t\x88\xe7\xa5\xf1\xe8%Y0\xe5\x13\xe6\xa2\xf2V\xfaxYB\xf5\x98.q\xa0!H\x93\xd8\x0f%~|:\x16\xa1cC\xb8\\\x1a\xd8U\xc8m\x9f\xb50}y<\xe0k?\xfdjD\xd4GG\xc5/\x12~\xb58T\x92G\xff\xd91\x8c\xac\x9b\xe2q{\xde\xfe\xc4\x8f\x1b>U<\xd4\xe4gG\x0b\xfc\x8dZ\xda\xdbc\x89S3\xf9O\xf9p1\x83\xcc\x05\xba\xd4\x7f\x98\xae\xb4w/\xe8\xc5)\x92\xf9M\x8b\x18\xe2\x9c\x1b/>\x1e\x12\xca6\xf8g\xb6\xb6\xfcGD\xdbD\xcf)\xc8o\xd2\\z\x1aX?U\x8c\xe4(\x16t x<\xbf\x12\x9ay\xb9"\xb7\x7f\x9e8\x7f>\xe0&j\x9a\x19V<\xe4}\x08\xa2\x81\xfd\xe8]\x8ag\x03d\xca.\x1b\xa9\x0c\xf6\xd1\xd6x\xb5\xd4F\xe2I\xaah\xe38\xf9\xa2\x17\xe3\xf6\x8c\'\xfe5\xa8d\xf3*\r\x1c&lG\xf3\xbbg,$\n/g\x92[}\xcd\xe2\x97\x037\x051~\xb4(\xd9\x86\x18ZJ\xd0\x01\xf69\xcd>\xe7b\x92}\xcc\xf6\xd0\xfa\xfe\xf2\x16!\xadl\x8c\xa2/.<\x11\xcf\x1f\xca~\x8f\xe5\xe2\xf9\xd0\xf4\x97\x1d\xe4\x97\xfd\xdd\xb2xK\x12\xe1zM\xca(=\xe9\x1ds\xbd\xc9\x03\x98+\xcc\x19dV\xdb\xf1Xn\x99\xc9wh\x9by\xd2\xbfi\xb1{Mt\x8e\xea=cR\xacX\xd4\xb5\xd8\xdc\x02\xfaT\x91\xc9#\xebu7W\xfe\xbeL\x83\x1cD.R\xacl\xa0m\xf0\x14\x9c\xdc\x0c#W\xad9j\x96\x08 \xf7\xd9c\xf5\x87\xe4\x1b\x95\x89\xd9\xf8A\xe4\xe9\xe7\xb1\xf4\x84\x1f\x9b\xd6\xbb\xfaf\xf4\xb0\xb9\xb6\x072\xbe\x90\x98\x133=\x9bv\xdbZ\xee\x18\xc9\xc8\xeb\x8b\xb3\x0b\xe7\xf00\x147\x12\xc6\x05\xb4\xbd\xbe\xf4\xcf\x8e\xe6\x0br\x1e\xa3*\xd21\xee\xeb\xc1s\xcaN6\x97d\xd5\xae\xb3\xc7b\xe9:o\x8eV$~\x1b\xf4\xe2Mm\x8f\x1b^\x89\x17\x0e\x1fL\xfai\x06\x85e\x0f-\xee\x10Kn\xae\x8e\xcdU\x93\x05\xab\xed\x12o"z\xf2\x92\xcelO\x9eW\xc1M\xa3,jr\x7f7\xaf\xdf\x83\xd23<\xeb=\x15N\x90\xc7\xe6\x94@\xb1:\x89\x19\xf5\x87+\x9ao\x9f\xaf\xd7\xc3\xcd\x07\x86\xbdb\xe4\xa8pwp*W\xb3\xfc\xeb\x89\x89\x9ar\x82\xba\x8a@wi\xed5\x06\xdb\x0e7\xbdGb\xf5\x9c;\xa7\xef\x9f`\xcd\tF>\xa9R\xff\xa2\x10\x1d\xac\x7f\x8d\xceVa\\SfeQc0\xec1\xdc\xccjh7\x0f\xe3j\x12\x89m{|\\`\xd7G\xcff\xfd\xd9\xda\xfb\xdc\xdd_\xfcx\xb7\x84\xb4`A\x96\xa1\x99,\xc6\xd4\xeb^7\xd1=\xb4\xcd\x194\x8d\x7f9bU\x83\x16F\x93\x83\x8a\x14\xb6Ec\x8e\x17=\x8a\x9eir\x13\xab\x92v\x8cW6\x9c\x83W\x19\xf0\xe1Hn\xa2\xaa\x1b0\xd2\xb7=\xfe|7\xeb \xd60\xdbv\xfa-\x08^\x08\x9c\x04\xf2RK\x8e+9\xb9y\xe1|\xc1c\x98*\x0f\xd6\xa2\xdb\xe3"\x9cJM\x9b\x1e\x8d\xd4\xa8\xff\x1a\x13\xee\xf4\x8e\xbf\x1d`\x903\x91f\xecw\xc8\xca\x1e\x9e\xb5\xee\r=\xac\xbb\xbc4\\$\x8aH\xda\x1b\\\xc9\xa2xH\x0c*\nq|I\xef\'a^\x82E3\x1a\xddz@\x1f\xa9\xba\x9eO5\x13\xb0\xff\r\x99\xf5\xe4\xdd\x0e\xd6\xad\xbb\xb6\xf6\xfa\xa8c\x03\xabn\xea\xc0M\xfa}\xa3q9\xef\x16\xc8_\xf7\x86\x1c?\xa3\xa8\xd4z\x8b\xab\xe4\xb0\x9f#\x96e\xce\xb2\xde&z\x1d2\xeb\xb8\xcdwg\xfc\xdb\x11\x0b%;\xe82\xf4\xafe2\x8ey\x97k~\x8f\xfb\xad\xbd\x1d\x1aq\xa7@\xdd)i6\xad\xeb\xc4\xc9\xe1\x92\xc3\x8e\x86\xd9\x85A1\xf4\xe1H\x9fJ\xe9\xf7\x1f\xa4\x1d\r\x1c*\xe1\xdd\x94>\xd21\xecC\xb3a\x95\xf0\xe4B\xb5\x9e\xed\xcd\x90\xd9\xd7|\xd2\xe4\xc5;\xe8\xccG\x85y\xe1\x85{\xdf/\xd87\xbd\x0b\x95\x98_\xf8\xe5\x7f\xea\x87\x8f\xf4 \x82\xad\xb40\xaa]\xed\xad\xc7\xea\x11O\x06r\x08\xa02/g\xb6\xf3\xec>~\xdd\xb8Z\xb2B<\x7f\xa3d\xe9\xd6\x08\xbb\xf1\xff\xa7\xa9\xb9\xa4\x9f\xf1\xfa\x84\xf9\xd4\t\x19\xb3\xcc\xeaM\xdbu\xcc\'m\xfb\xdd\xe5y\xd7\xe1\x92\x06\x9a\xf1>\xa8\x87\x9eN\xb00zX%\xcc\xb5\x1f7\x02Pu\xef\x993\\.\xd85\xd9\x88\x16\xf1e>\xbaz\xd1\xfb\xe0\x81\xfa\xc1\\\xae;-\x05\xfb\x17\xd8\xb7\x05"\x9axv}9~W\xbc\xb9\x90\xc0\xcbY\xe7\xb5\x06[\x19T$E\xbd\xc1>6\xddd\xab\xb7v\xda\x85H\x8dV\xc2$\x9fRL_\x88\x8dE\xe1b\xd5\xa1l\xfee\x87\x95\x9c\xec\xed(\x89\x01:U\xbf\xa84B6T\xc3)W6\x9e\x7fK\xdd_O\xad&6\x13_qU\xda\x846\x86\xfa\xa7#\x97\x84\x17B\xdez\xd9\xefC\x10\xc9-\xb0\x0b\xdd*\x9f\\\xfa\xa4\xeb1\x83\x94\xeb\xa2\xa8\x9b\xcc\xd7\x87\xbe\xb6\x92\xbf\xbe\x841R14\x93\t7\x19\x17$\x83\x91\xce\'\xcf\xc5\xd0\xc3\xc8A\x83\x18\xf6\xa0"\xedM\x1aJ\x99S3\xe1\xef\x87\xd6\xf5\x05\xdf\xa5k\xd3\xedF\x00j:\r\xaf\xe9\xa2\xf3~\xeb\xd2\x87q_\x8e|\xfb\xd2x\xe4\t\x97\x0e;\xd0\x0c\xdb\xa7\t\xc2\xcc\xced\xc4l\x19>E-&\'\x16n\xf9\xd8\xefAN5sY\xa8~]\xaa\x0f\x99m\x9b\xc9Gk\xab\xbb\x9fh\xe4\x8c\xec\x1c\xf3d\xa48|\xcc\x1bu\x1e\x91fLUrV_\x045*\xaa2\xd0\xc1\x13\x077S~\xde9\xa4\xff8\x9dF\x89\x91\xad\xca(0\x8e}\x13WO]\x0eiq\xe4X}%\xd1T\xf3\xc9\xe7\x87\x02bz\xddm\x8a\xe8A\xf9\xe1XY,:\xa2\xe6"H\xc9v\x1b\x82\xc0|\x00I\xd2p\xb1\x87\xd3\xb7P\x90\x14R\x04\xc6\x89\xbff\x03\xd2\x83\x8e\xd8\xdc\xfa\x12\\\x06\xde\x04\x9c\x9fyO9\x1e\xf7\xe7i\xe6\xf5\xd8\xa34\x00M%\x04J\x08!A\x07\x12\xd8\x81\xf0\xb7V\xebz\xf6P\xf18a\x8d\xa00\x8a\xb0r\xb8\xf9\xa3[F&\xae\x83\xf1$\x05w?.\xa0\xf1\xddV\xa5\xf5\xf89NR\xa3\x0f\xfaJ\x94eZ\xf6\xf3\x81\xe9$\xf3u=:\x8bs\x99;hs=YR\x93{\x8c^H\x9dF\xf6{YQ\x03\x0e\x99\xfc\xa9\x8e\x1d\xfc\x891\x10\\v\xef\xde\xd5W\x15x8\x92\xda\x07x\xc4\xd6\xd0\xdb=>\xd21\x0e.\x9a\xb8\xc1\x98=\xcb\x88{\x1b\xf3\xffV\xd0\xe8\xfc\xf2QG\x8d\xe5\xd8\xba[^\x80\xac\x8b\xef\x91\xb4X\xe6_Z:\xa460\xfa\xcf\x07\x98\xa4D\x81z\xfa\x8f\x9a\xc2\x07\xbf\xa9V\x96l{\xca\x87\\\x97\xceK,?\x83\xdb\x14\xacb\x94f\xaa@1\x93LGR\xe4~N\x08\xc4(l]\xe1e)\x0es=F;8\x13FD\xcb\xc6\x83\xeb6>\xdc\xda\xbau\x8f\xe0\x9a\xd7\xdaR\\,\x12\xf3\xf4\x1e7R\xb6\xfdS\n2\xc4\r\xb0\x995[\xa4\xac\xfb\xc7\xfd\xa2y\x1db\xf3\xdb>\x7f\x96\xcf6\xf0b\x88\x97\xafg|\xa9\xf2\n\xd7d\x87\xf2\x07\xd9\x88}\x89\xf9\xac\x15\xad\xd1\xb6\xe3K\x8c\xc8)\xc5\x10\x1e\x923\xc3\x92\xcc\x08]\xf8/\xd7\xca\xcd\xd4X\x8b\xd3\xdb\x88\xf2\x12\x1e\xae\x92y\x9d\x7fe\xb0\xa8\x8cRO\x1bqb\xaeC\x10]\x1f\x0c\x01\xab\xf1\xc9+[\xda5\xc8i2\xf5\xc0\xb7\xa50n\x9ea\x93\x1e,Ve\xf5\x94k\xf1\xc0\xb3\xb2Q\x99\xe1p\xa8\xed}\xd5d\x88\x032\x03$i\x901\xd2\x8b\x04i\xb1\xc6\xd7Bu\x13r\xe8*#v%\xf5\x02\xc5\xc3\xe8\x1a\xed\xf1\x8dY\x9f\xb2\xea\x0bw\xc7\xb9B\xc3I\xd2\xe7\xc6\xcd\x94K\xdf)\x82\xa0\xb0\x89r~\xc7\x81\x9b\x8f\xf6"\x14]\xfe\x91k\x12v\x8dk\xee#)\x85h\x1d\x10\xee;\xd1\xab\x9d\xaf\x088?\xd9hx\x06n)\x1c\xf7_\r\x92\xe5\xa4\xbb\x8a\xac<\xdb\t~\x8cb1q\xba\xbc\xa4\xb4e\xff\x81\xa8d\xb1O\xac\xf0\xc5\xea\xef\xac\xe2\xf9m8 $\xfd\xad\xd43+\x98\xc4\xf1\x88(\xe7\xaaG\x84\x01.\x859x\xb3\xafD\xady\x9b\xce\xbbe\xcc\xd5\x9d\xd4\xe9\x83\xbe\x12R\xb4\xd5\x81\x07\x92\x19\xd4\xd4\x84z\x01V\xc3\xc2m\xf7\\\xd6/\x13n\x9e\xb0\xa0\xdb\xd7\xe1iw\x13\xfd\x16\xcf\x8f\xe8\x9a\n>\x88J\xbf\x94\xf7\xcb\x86_5\x8e\xf1\x93F\xd38\x95nh\xb8\x17\xd2\xc3\x9c\x9d\x8c\xb6\x9a>FJC\x99\x02\xba\xd17S|^\xdb\xc1O\xe0\xc9\xfd\xf5\x1a\xca\xeaQ\xe9\x98\xdc\xfb\xd3\xe7\xad\xe2\xde\x1e\xf8\xf24\xe4\xb6;\xb0\xbe\xf5\x86\xdd\xc8\xb8\xa0\x9d\xabj\xc2n!K\xb5!\xbf2u4zI\xe1BF\xe3\xdd\xd6\xd2\xa7\xfcS\xa8\xda\x0f\xf0k\t^\xd2Bu\xeb7\xe5\xd3!\x8f\xfb\xfb\xb7\x18\x91\xc2\xee\xdb\xaa\\M\x07\x08\xcflK\x0em\xc7"]\xdbc\xed\xb6\xc7\xe8\x1b\xf7?v\x07\x99\'L\x06\xbf2\xf8UcN\xd7\xb1\xc5\x7f\xf0\x03Zy\xfa\xeb\x82OB\x85\xc3\xcf\xe0\xce[#\xa2\xf2MY?nP\xad\xa5\x99\xd8\xc7h\xa0\xb5\x1d\xcci\xce\xd4\xb4\xbc\xe9%\x0e\xce\x9d\xdb\x9e\xd9\x03U)>\xca\x9dhl\xdcPAV\xc3\xaf&p\x8eOs,\xe2\xec\x9eAN\xb3?f\x9fVP\xb8\xd6\xf0\xe3g\xc5\xe5\xcc\x1d\xe4\xdf\x8c)-\xc6[\xd9\x8b_\xe9:T0\xe3\x04\x0e\x05\x86\xc1\x95\xd9?\x96\x8cZ\xf2\r\x06\xc3>\xc0\x93-\t\x95g\xba\x1c\xda\x00\xfd\xb1\x99\xbc\xe6\xa5\xf6\x7f\xb7\xd1&=\x854r\xfc}M\xcfG\xa4\xf0\x153\x85\x83\x11\xa7\x861\x9am\xbe\x07\x9f\x88E\x11\xa5F\xe6\xc3V\xb7\rG\xb3\x04\xe1| \x83\xf0\x8d\xec\xe6\xb2\x1f\xb4be\x83~\x17\xb2\xa86G\x7fi=\xeb\xd8\xeb\xe0\x80\xb2\xd5\xf6$\x12\xd0\x83\x93B"\x04\xc1\xfa\xd1}\x03\x9c\x17.\xbak\x94\x1a\xfd\x84\x01\xc7\xc5\xd2\xa6\x0b\x0c\xc4(OG\x07\xbc\xad}\xbf\xaa\xc4\x8a\xc9\xd9V\x9bQH<\xf45\xf5E\xca\x10\xfd\x92\xfa\x8c\x8e\xed\xc4\x0b@=\x89\x16k"\xc0\xd4\x0e\x8a\xd4T\x87F\xcaq3\x0cd]\xe2+\r\xc0\xf2M\xef\xd9\x0ei\t\xa1_\xf4\xe3\x13\xca\xfc\x96\xc7^3<\xd9\xd9N\xb7o\x902DWv\x11\xfajH\x0b\xf9l\x90\x9d$H\xfc"W7).u\x90j;\x08J\xae\xa3\x991\x18>!\xbf\xbah\xbb\x82F\x08\xcb;\x1dy=\xdcb\x7f\xbd`\xe3sP\x9c(\xb1\xe8\xd3\xf8\x0bj|\x7f\xddC\xfc\xacG\x8e\xfc\xf1u;c;`b\x0f\xc7.9\x94\x10\x99k<\x1c\x0f \xd2\xe0\xc2\xdf\xcaO\nZ\x19\\\xb7}\xaaW\x85\x9a\x90\x9e\xb6\xa6\xf0c\xee\xd7\x85K\xdb\x0f\x95\xfab\x13\x1d\x82\xb4\xc2xcv\xda,\xc4&t\xc2D\x94\x9a\xed4$C\xd9mm\xa4\xfa\xfc=f$K\xfd\x87\xb8;\'\xa5;v\x1d\xab\xfd\xe7\x18\xb4e?\x1f\x0c\xcf\x9d\xdb\xf2\xae\x82\xaa\x94\xaf\xa9\xa4t\xde\x99\xa2\x14;@\xcfn\xd6\t\x15\xbf\xc3\\\xfce\xec\x85\x9ajX\xbds\xdf\xf0T\xb9\x14:\xb4\x85\xb8\xb4\xa3\x96~\xf4>^\xd4x=\r5\xf9i\x08Gj\xaa;\x0cp,#\xfc\xc8\xcf\x84~P=\x90\xf8\xa1e\xe2:h\xaeAiY\x1a\xa7\xdf\xc1\xdc\xe2\x1a\xfb\x1d/\xd6\xbf\xef\x18\xb4\x94\x14\xfc\xf3\xc1\xff\xdf\x80|\xe6\xcaz s\x82\xb76\x99V\x84\x8a7\xd8\x990\xd9#\xb1M\'\x18\x82\xfcx\xc3\x0c\x91\xf6\xed\xe57\xfc\n\xcdT_\xd0\x83I;\xc6\xa7,r\xbc\xc7\xe8L\x03\xef\xb8\x14\xe5=(\x16X\xdf\xd3\x81\x1c\x9a\x0c\x88O}\xf3T\xc4\xc4m3X6\x8a\x00?\xc6z\x961~c\x18f\x1f\tYq\x02\xc5fu\xe1\xc8\xcf\x85_\xddx\x97[\x84\xb9F\t\x98\'F\xda.\xb9\xbf\x1f\xc7\xb0znx\xffO\xcd\x00\x93=U\xbey\x85:g\xec\xf5\x82\x8a\xc2\x12\xb4\xadm\x8e\x99\xf6\xb5#\xd0\xf0\'\xe7C@\x18\xca@q\xb2\x90\x1c-\xac9\xbe\x1a\xb3\xfe{mW>\xeb[\rI\xa5\xa1\xb1\xd8\xa0\x9d@S\xeb\'U\x9f\x0b\xc78\xe7\xfc*$e\x13\x7f\xf5\xca\x03\x86q\x01\xce\xf1]\x11\xea9RnH\xe3\xbf\xda\xa6-\x8cd\xc6\xe8\xa8\x8ag\xc3\x8b\xffp\x85\xb2B\r\xbd\xfa\x8f\xf8\xd5\x18v%\xab78\x85.\xdc\xe4&\xdaRG.D\xb1\xbam%l\xc0E.\xc4\x96b\xean0L@5\xdb,\xce.\xbe\x82h:M#\xfe/\x15\x8c\xdd\xfb\xa0Q\xf2\x15\x8a\t\x8c\xbd\x03\x15\x85%\xces\x92\xaf\xdd\x0b\xf7d\xc8;\x16!\xfal\xff\t5\xa5;\xe4\xe94!?FL\x1b\xd2\xd8\xedB\x95HIU\x9a>5\xf7A\xab>\r\xb9\x89\x9a\xd6\xae\xebqx\xc2\xe5H\x9b\xf1\xc6\x04L>~mr3L\xdf\xe8?\xefa\xc8"\xef\xfeF\xbd\x88\x92+\x9e\xde|PL\xb8\x81\xb5\xa5\x8ec\x89 \xdc\xbc\xe1k\xa7\xec\x8a\x81_\xd7\xf7hu?\x95\x8c\xe4\xcc*\xa2\xde\xa6v\x88\x83\xdb\xdc\xe1x\xf6\x18\xd7\xa7\xb6o\xdb\xad\xe0\x05\xe8b=\xd2\xed\xd2U*\xac\x03#\xe3V,4~J\\\x11\xf11\x9f;y\xea\x99\xb0\x9e\x84\xf9\x8d}w\x0b\xa7tx\x1f\x9b\x89\xa2J\x1b\x89;\x8e\x7f\r&\xae$\xb2\x01\x9c\xb6\xe4b\xe8S\x9eU\x15o\xbc\x13\xbc\xc10\x98:!\xc5\xeaS\xea9c\x01\xbd\xb3\xcci\xfe\x18\x05J\x8f_\x0b\xaea\x8e\xf5\x07\x8d\x85\x15\xef\xd6\xc3\x87\xbe\xaf?\x84\x18\x9f\xe46d\xbdZc&w\xe1\xa9g\x98\xae\x16\xe5\xd4B\xaam\xc4\xf0\\OM\x01\xf1#\xfc:\x8b\xcb\x97=C\x1bLd\xcc\xaa\xb1nT\xc7\x03\xa8<u\x9e|\x893\x08\x82\xc0\xc2\x93\xbbM\xe1xZ\xab\x1b\x97a\xa9\xb02\xcf\xea\xa4-0\xc7\xde\xf3\xc9{%\xe8\xda\x1cD\xf5\x1f\xfa\x04h\xf4\xca7\xe40\xed(\x89\x01\xc5g\xfdvpX4\xc8\xa9\xebg\x8e\t(&\xa0\x1d\xbe\xe5\xbc\xeb\xa2Xl\xaa\x8c\x05\xe5\xfcE\xdb\x94N\x81v\x1c\xb6]Q\xf4s\x95\xcf\x01\x80:\xfb8\x00\xb7\x7f\xec\x9d\x1d%K|\xbb6\xf7\xead\xc7\xfd+n\xc4$\xd5hw\x1f\xb2<f\xd2ar2?\xf8\x92\xc2\xf2\xadd\xc2\xfe2\xa1\x93\x15\x14\xcb\xa0\x13\x01\x84\xb4\x15\xe6\xee\x10\xaa\xafa*\xf6\x16\xf5\xed&\x05\x0e\xf0ax3\x96\x0b\xc6\xde\xac\xc6\x8d\x99\teO?\xber*\xf1\x9c^\x10\xfe\\\xb3\xa4u\x96;\xef\x9e\x99\x8b\xa3r\xd6]\xe9\xa8.Y\x1e\x9d\xbf\xa9/\x06\xebj~\xbb\x0ek\xfa\xbf\x81\';?&\x07\xc4:\x9au\xf3*mSf)\x06];\xc7\x81\xaf\xec\xe1\xed\x18\x1c\xf3\x8a\xbfbM\x97\xd7\xd9\x84\xcf]\x9d\xab\xe5]\xea\x02\xf3\xf7\x95\x17/,\xe3o\xd2N~\xd0\xaa\xb4\xe3\x0eJ\xb4\x13\xf2\xc7\x95\xd3M5\x9b\x93\xf7G\xef\xf5\xa5Z\xfc#\xcf\x90\x93\xd9z\xce\xd6\xe2,P\xf8@\xe4\x0es\xa7s\x9c)\xb5\xd3\x1e{\t\x1a\x8f\x92\xbf/x0@\x19\x99>\xb2\x9ev\xb3}EP^\\\no\xf1\xad\xf7l$\nz\xe7\xf0>1x\x11\x84\x13\xb5\xa3i\xda\x80 f\xcbaH\xd3\xf5w\xe9]\xc6\xab\x1b\x1d\xb4\x10\x0ba\xfb\xc5\x83\xfa\xb5\xc9W\xda\xc4\xdf\x18t\x9d\xc4\x06}z2\xa2\xe4\xc2\x89\xe3\n\xfckp%\xca\xf2\xd8\xdc\xb7\xe7C\x93\xbd0\xd3\xfb\x08`n\xa4\xf8\xeb\xd7\r\x06uN\xd2*\xd3`$\x7f\xc2\xbck\xa1g\xa3U\xb1zmsB\x04(oqQ\x8e\xd0\xe2\xbf\xce\xf0\xf9#`c\xc9\xe0Rp/\xd4\x04\x03O\xb6\xe49K\x92\xfe\xc7\xfa\xfb\xb2\x8fP\xf8\xad\x84\x9d\xb6\x1bh\xf1n\x99ES\x9e\xb1^X\x8a)\x0e\x98\xeb1B\xcc\x96\x03)\xa2\x10\x17\x81v\xb9g\xd7\xb1\xdeFy\xbc+\x8c\xc8\xa2\x01\x18\xb9\xef\xb5\\\xa5a(/@1D>\xf8[\x1a\x08\'-\xc1\x8e\xdf@#^\x9a<\x06\xca\xbf\xf0\xdeo\xcf5.\xdfx\xb1}\x0f9*(\xc8i\xab\xcd\x1f\x96\xfa\x08\xa7\x01\xe3F\x8a)\xed\x81\x9e\xff\xcb\r\xe9x\x91\xb0\x86a\xe5!\x98\xf1\'\xfc\x92OU\x19Zll\x83\xa2?\xbd9\x03\x8c.j4\xb6Gw\xe5\xf6/n]\nA}\x9c$\x04\xd2\xa3\xedLgTmq "\x08\x1f\x9f)\xa4\xcfa\xdb\x9b\xf6\x1d\x14C\xa4\xe6\x80urGr\x1a\xdat\x89\xff\xef\xf3\xe2\xcf\x17\xbd\x1a\xb3\x8c\xcb\x19:v\x17;\xee@<\x04\xf9_\xf7k\xcc\xd5B\xd3\x04?\x1f\t\xca\xcc\x91J\xde\xb8(\x15wF\x1e\xc9\xcd\xcc\x9a\xb20{g\xca\x89\x00~\x89B>\xba\x19\x81\x17\x86\x9f\xfd]\xbf\xe8\xcc\x91\xbd%\x1dgQ\xda\xfa\xca\n\xa6\xbe\x10\xb9\x00A\x90p\x01B\xca\x14\x92\x9c\xba\xe1\xa3\x86xB\x197\x87\xb1\xc7f\xd4\xba3=n\xb4\xfe^\xb32\xc4A\xf8\xe0\x06\xa8\xaa&>Br"\xec\xd4\xaemPm\xa2s\xe6\xbd]\xaa\xef\'\xf15\xcf\xc7\xf7 \xd2\xff\x1e\x88\x00B>t\xab\xc7\x1ca\xe2n\xa7f\xfc\x03]\xe8\xe7mi\xb5dO\xb1\xba\xe8 CR\xbc\xb3qW\xe9\x1c\xd5L\xd2bN\x0b\xd3\xc7\x8ek\xac\xc4\x87\xc0R\xde$\xe1\xa1\xf1\xda[]qk\xb1_\xfd\xb0K\xb6\xb40\xecgxz\xbf\xc2[2\x9c\xe8\xe3K\xfa\xc9^X\x9d\x0e\x0e\x88#\xd6%\xdf\x94m$h_>\x17\xf5{\x07O\xb7\xfc\x1c/{ 0\x1fh\xbb}\xeb\xd2\x00\x177\x90i\xa7O\x1e5}o\x97\xe3\xd7\x1aZ\xfa\xd6K%\x17\x98\xc0\x1e\x91mo.\xc9\tMM\x1f\xdf\t\xbek\x99wF}q\x9aB|d\xd0~\xe8\x15\xf19\xf1\xdevT\xddVaP\xd1\xc4\x0eDZ\x9e\x89\x0b(\x0f \xd5\x7f\x8e\x8b\xf7\xe8\x8f\\\xf7\xa3QB<\xaf\x85f\xccY\x1b\x87&\xf6\xb4g\xbf\x8eF@\\\x04\xc7A \xfc\xb6\xca\x7f\xc8\xd6\x0cO\xb6\x1dZ\xd2\x0b\xbd"/&\x1cSh4R7\x8c]?s\xc0\xa1\x81#\x9c\xf7\x96\xe7]\xd5\x1e\x1e+\x0f\x8d\x90n\x1f\x8edX\x8e\xdf\x9a\x89\'\x9e\xc9>\xfd*\xb9\x93\n\x96g\xa5\x03, \x05\xfb\x05\xc8I\xc2=\x94*\x83f\xf4\xf3\x10o\xce\x18_k\'\xe2\xe0\xbf3\x9a\xef-\xd8\x19c\xa8\xd2JKZ\'\xf1\x97\x8ci\x92\xdd>\x19\x01\xdbr\xf3/D\xbeZ*k\xf8K\xb8\xea\x05\xb2\xbd\xe8@F\xc1o\xe5\xbc3\xaa\xc75~\xe2\x87\x02\'\xe1Uw,~\xd4\xba\x07\x11\x19\x9e\x8f\xb6N@M\xbb\xdf\x9c1\x00\xef\xee\xfeoW\xac\xef-\xccXE\x02\xeb\x03\xb2u\'\xd4\xb94z\xd8\x0e\x94C\xe0\x15\x01\x94\xc6\x8d\xc7\x97<\xf5\x8f\xa5\x8aR\xe5~A\xaf\x18t<7\xaf\x87\xb9\xae\xa83\x908\x02\xf3\x1c<\xaa\xcf\xff\xf0\xe2b\xdd\xfc\xc6\xd6\xe1\x00OUB\x8fr\xee\xb0\xe8\xf8=\x9bi\xa5\x8d\x87\xf2\xb4\x90\xce\xa0\x9c\xd4\'\xcd]\xd2\xc3\xd4\ri\x90\x84\x86\xcb\xc1~gZU\x1c2d\xc6A4\xf5\xedO\xdb\xc9\xe1\xfc\xb8\x1c*\xad5\xf6\xab\xec\xab?\x90#o\x95\xbb\xea\x8e\xa2B(\x8f1t\xbd\xfd|\xd1\xa8\xbd\xb4q\xf1m\xed\x7f\xfd\xd5f\xc8\x9f\xe3\x9e\x83K\x87\x82\xe2\x94b\xc1\x97\xdd\x80\xb6\xf7\xff\xe5\xe8\xd48\xb1\xe59\x14\x18DfpR!\xe1\n\xf03\x0f\xaf \x95|\n\xbc/l\x07d\x13\xc7\xee\xb5(\xbe\xee\xdaY\x971V\xadh\x89c64\x9a\xa3=\x01l\x11\xe5\x02\x02$\xde\xe4V\xba\xe5\xbdY\xbb\xe2\x8b\xf8R\xef\xfd4=5#\xb4\xc3\x81\xc6\xa0\xb8{\xa9\x18\x9a\xfee\x96\x03\x18kV\x89\x08H^\x80\x9au)\xe6\x8a\xd1j\x17\x8d\xc7\xf2?:\xdf\x8bb\xd6\xd8Jc\x9c,y\xf5\x9f\x16p\x17\\8\x9d\xf4\xa6\x13\x0eb\xef\xa5\x14}\x88\xc2v8\xd0kLg\x99\x02\xc8\x87%\xe9f\x01U\xc4\xd7#\x11[^t\xd1\xadP7\x80\xbdg\xae\'\x95o\x93og\x9e\xeb\xe5kR4)>\xa9\xd1Jf\xc8\xf8\xb0\xbcnw5_\xb9\x89\xf0\x91\xd1u\x13\xd1Q@K\x1f\xf4\xd2\xad\x0f\xcc\xa9^\xc3\xeb\xf6\x13\x9e\xcf\xea\xba\xd2\x8e\x8f\x9c\xee\x90\x19\x08F\x05\xba\xb3\x19\xb5\x99\xfe\xf1\xbeo\x16x\xbc\x8c)(\xd85x\x96\xe5\xe1\x0epE~\x1e7m|r\xafC\x94\xdc\x96\xd5-Zs\xf3\xe8\xe8\xec\x9d\xed\xbfx\x1c\xbb\x9d\xcc\xf8{\xf3\xa7w\x1fs\x7f-:.\xc9\xfd\xe9\x08p\xe1\xc0\xa6\xd7\xc4\xe8\'\xe8\xc1\x01T\x7fN(o\x13\x94!\xf4:\x9c\r/d\xce*\x0f\x08\x19\x7fJ\x07I\x1a[\xc4\xd2\x02\xc6\x99\xe2\xee\x00gZJ\x91\xde\xcd(\xa7\x16\x062\x85n\xf5\x03*\xf4Z\'\xb4\t\x89\xea3<\xbf\xf9\x9a{)\xc4\xdd\xce\xbe\t\x92g\xeeP\r\x80\xd6\xd3\t\xa1\x16+\xbb_\xc7\x1eS\xe4\x03\xe2\xba\xc5h\xaa\\\x8fc\xdeL$\x15\xde\x89\x92#\xbd\xbb\xc0u4\x8e&\xde\xb4\xae]\x9d\x97\xe5\xd14l\r\x08O\xc8N\xd5a\xd2\xd2\\\xe6\x94N\x1b1S@%\xffR\xb17\xa7\x03\x96\xcc\xa5\xb4\xe9i\r\x062\xdewr\xadk\x84/\x96\xa8\xc4,wm\xca\rop\x02\xe2\x83#\xb3|\x83\x87\x1a\xf96e\x1f\x8c\xc6~\x19>O\xfd\x95\x1f\xa1\x1a\x8az\x95\x0b*\x91\xef,\t\x1f}\xeb\x19\xcbgj\x9e\xa1<\x188\xa5H\x17\xfap\xa7\xe1\xb7\xae\x0c\xe9\xdd\x8d\xfd\xbc\x86\xa8\xcf\x12M$\xe2\xa8b\x81\xcf\xcb\x84C\xc4"B\xd1\xdc\x1e\xc5[\xd6\xca\t$6\xdfd\x13}\x0f\x0f\x9f9\xa6\xca\x05\x1d\x7f\x0b\xf1$X\xd3\x19\'\x077\x00L\xfd\xff\x8c\x8b\xc7y<J\x7fk\x1e\xcd\xab\xa9\xf3\xfa\x98\xfcn`\xd0\x08/\xc2_14\x8ee\xf12\xa8\x02\x96\xc2[\xaa.\x0c$\xca1zs\x97\x82~\x93\xf9\xa5\x15\x0b$\x1aG>\x18_\xfck\xc8z\xfa\xc77\x80\xa5\x0c\xb1\xe1\x1av^\x1d\x94k\xf3Mu\xd7\x92N;9\xc0\r4\xfb\xae\xd4I\xcf\'\x9d\x8d\xecOc\xad1\xf8S\xad\x88)I\xe2-k\r\x86\x97\x00\xb9\xa9\xcb+2\x8e\xcaF]\xccC\x827\xf9H\xef*\r\xd2}\x87\x9f\x0f\x8d\xb5|1\xe4\xb4\x1e\xe0|B;\xd9\x03\x08\xa6\xd7,\x9at\xd8\x88N[%\xdb\xba\xcb\x91\x8b\xe2-m\xe5\x00<\xac\xb4\x18\xb1w\x15,\xb6\x17\xf9\x0c\xef\xbd\x96\x03&j{\x9d\xe9\xb7\xaa\x1eLp\x03\xcd?\x01\x99\xdfO\x15\x97d\x15\xab\xb0\x1bb\xbe\xc9Nzw\xf5\xfe\x14\xaf\xe1=\xf1\xec::\xff\xc61\xf2\xbfJ\xe5\xccb\xff\xdb\xd0\x81\xc9\x1e\x14d\xce\xbd\xd5\x91\x10\x15\x9b\xc0\x95QTI\xbb\xf4<\xfcRh\xb4\xe5y\x18\xb7\xc7[P\xc9\xd7aC\xde\xe7\x89\xd9\xc7\xb9\x9bT\xd5I\x96\x14$\xbb\x9eD\x1b\xff>\xbf\x7f*\x0cx\xcc\x1f-\x82lr\xb9\x02\xefD\x18\xfb\xdb\x9c\xbfqC\xcc\x9eQ\xd0\xf2\\\xa3c\xba\x86\xae\x1e\x14D{:\xe3d\x177\xd0,\xf9\xdf\x88\xc4H\xd6Q\xb8\xbfN\xc6\x8b\xfc<\x0cH\xe4\x8d\xb0\x83Th\xace\xf2\x93\xfd\xc2\xfcMpu\x1a\xa8\xe4Li\xd7\x86\xa5(\xad\x98\xff\xf4\x9f\xdc\xde\x03\xe4\xc5\xd0\x98m\'\x00\xbd\x1e[N\xb4\xaeMN\x9b\xfa\xb4\xcd\x1d\xad\xd3\x9a:\xaf\xe5\x01\x16\'wb_zQ\xb2c\x12\xef\xefQ\xad3\x08uR\xbb\x14?f\xae\xdb\xfa\xb4\xef\x04\xd4\x10-\x17\x01\xcbd\xa8{Z\x16\xa4\xba)Lh\xac\xae\xdc\xd5L\xea\x122\x8f\xb9\x94\xc2[\xdaz!\x06\xf4`\xdc\xd6\xc8\xbf\xd4\xb6\x91\x18ph\xea\xcf\xf9\xc9_\xe7\xd08\x88\xbf\x08\xf9\xa7Cg\x99\x1c\xe6V\x10l\x8a\xda:L\x8d\x97@\xd1\xfc\xd6\xf2\xc3\\N\xd3\xa9\xf6\x7f+u\x02a\xa4%\x8d\xc9#Z`\x02\xe9\x02WSh\x8d\xd3\x92\xfc\xdb\xd5\xfe\xb7.\xc3k\xd7\xbd\xaa\x80\xb9:8\x14\x15\x15\x93\xdd.\xdf0\xb2ug\r\x8e\x9bt\x99\xea\x82\xbd:b\xbb\xbb\xd0z0/K\xc6\x83\xd5\xe2\x0f\x1bH?}\xbf\x8a\x1fz\xb4_\xc8)\xf1\xaf\xccB\x18\x98\xbb\xf5\xb05\xb5\xe9AF\xe8\x8en\xd1\xedWv2q\x03^p\xb6\xb2\xe9*\xef\x07B#Y\xf6\x88\x8d\x10,}\xde\xaa\xe4\x9a\xf6B\xd3\xd1\xadz"@\xff\xd0k\xc1\x95\x0b\xc3\x03\x9cj\xc6\xfafz\xb5:\xd8h'
MIC_IMG = b'\x1b\xe8E \x8e\xd4V3\x8d\xf0D\xc9\xe8i\xba_$\xd5\x00\x99\x99\xf4\xf7\xa8\xe8\x97L\x8a\x1c\xe2\xa1\xbd\xb6\xfc\x80\'\xc1\xf4\xa8`\x12,\xf5\x87\x05;<\x88\xb5\xc1\x83\xfbk\x83\x84\xe0-&\xc1\xfc*\xca5\x19 \xbb\xdd\xbf\x99\x8c\x86\x90Y\xec\xf0\xb2\xcb\xe8e\x8d\xac\xd8O\x19Ioef\xacDY;##\xb3\xac\xac\xf4\xe4_\xec\x8c\xe7\xad\xf1\xc6zs\xbd\xff\xff\xf9\xcb\xe9\x9d\x1dgY \x9e\x8dia\x1d7\x17\xa7\xfe\xa2\xbe\xb5\x07\xfd\xa3\xc6D\x88$\x96[t\x9f\xfe\xb7\xbe\x1e\xe5\x1c\x08\xe5D\x9c\xbbkRS\xe8j\x89\xc1\x0b\r:\xbf \x1a\x00\r\xb44U\x8d\x00\xd4\x05\x96\xb0\x0f\xe5\xc9Y\xf6a\xecj\x82:^F\x1a\xca\xc0\xe1!v\x1c\x00\xd4wz\xae\xf7\x1c\xc0\xb1\xc4\x9b\xd2k\x8a\x9f\\\xbe\x1e\x9a\x16^\x91\x86\x1dk:\x04\xba\xe1^\xee\x00\xe0\xff\x10-\xd5\xe7/?\xd8\xec\xceS\x11\x0e\x13D\xdb\xe1\xfe@\xeb\xac\x91L|^R]\xcb\xa7\xb7\x0f\xc0\xbe\x8a\xba\x9c\xc5G\x05\x0f\xa6@\xb2N2\x8c\xcf\xf3\x9f\xd56\x95=\xeb\xaf/\x9c\xfa\xa5\x10\\N\xddV\x84zi%oK\xe1W\xcd\xe4\x0b\xcd\xa9\xf9O\xb7>\x8e\xbdLq\xf5\x1b\xc2\xbf\xd98 /v\x98m\xdd\x18\xb8\x0eE\xca\x9f\xe3\x87\xd6\x9d=\xcf\x87\xb2\xdc\x87\x06r\xed\xc9\xb9\x8b7\x95\xb9\x8f\x1a\xc9N\xf0A\x06\x925\xdfD7\xe2ckG;\xb3\x9d\xb9}\xc5\x92Wa\xefN\xa4\x9d\x0f\xd0V?\x98xV`\xd7\xbf\xba\x83#j{e\x82O\xb7\xb6AY\x8a\xe5$\x0e\x86o\xa1\x9f\x919\x81\xbc\xbf\xd9xcd5\xf3-\xc4\xd82\xdd\xb4\x88\x8f\xc3<\x0c\x01D:["\x9b:\xeb\x94\xbe\xbf\r\xe7D0<\x8a\xa8G\xf6?\xbf\xfa\xc9u\xed\x7f\xc9\x1b\xa9\\\xc6Dy\xe6\xed\xeb\x03\xd9\xe4\x0bw#\x91y\xeem\xcb\xd4v\x10\x07\xa8\x00L\x85Y&\x95\x92}\xc2M\x07\xd5k\x8e}\xa7\x92"g.\x06N\x9c\x16\x9a5b?\x8e\xdf\xe9\xd9\x9di\xf5\xd6\x9cOcs\x1c\xbc\xd6Pg\x06L\x9f\xc0\x10\xfb\xe6\xee\xd1\xa5G\x85~\xcf\x9b\xce/\x9f\xae\xbd\xca~<\xc5Y\xcday\xcbZ\xf8\x0e\xc9\x86\xa6\xc62p\'`\x92\xde\xda.\x08\x90\x98\xbad)o\x91dM\x1b~\xd3\x17\x98(\x84s\xe0\x9b\xaa\xf1\xd0\x8d{v\xcb\xf9:\x93\x98\xf4\x19\x8a!\xa2\xe2\xc0\xa1h\xbf}\x97_C\xe51>\xd5%\x8dgK\x17\xc7\xfb\xdb\xcb\xe2\xd6\x99\xaf\xee[\xf3\xcf\x0fr0\x92q\xfe\x86\x00>J\xc0/\x89F\xf7Zm\xd0ah\x8cH\x19U\xad\xc0\xf8\x8f\xfc~?\xbe=\x92\xfb\xf4\xf0\x15\xc3$%O\xbb\xb7\xea\xc9\xff\xd51S\x87\nt\xaf\x8bk\x8cOLt-\x0f\x8b\xafNO\xd9\x08s\x90\x94\xea\x0c\xe8[\xe6{e\x83\x80\x96\x8d\x02,Svu\xf9m\xf9C\xef\xf8\x85\xb2\x96iI\x8c:\xad!\xd3\x1co\x82\xfb\xd1\xa2)#6\xb36\x03\x08wh\xc0K\xf1\xa1q:\xde\t\xe6O\xad$\xe3\xc5i~\xdd\x85#!]\xc8\x9b\x9b\x9c\x00F\x91\x11\xa0oYr\xa3k\xbc\xab9\xcb\x17J,\x10\x02k}\x9f\x1d\xba\xdb{\x83\xf4\x02\x066\x1cFS>[\x0b\x87\xbd\xfe\x0e@k\x172K\xfe\x0c\x16\xd4\xc2r\xfcl\x90\xbf,\x9e\xc5^\xfe\xf4\x18i@Y\xf3\x8c\x87\xcd\xb2\xa9Y\x06HT\x05A\xdeS?\x1b\xe3i6n%}\xf5\x15\x99\xe2\x7ff\x18\xc2\xb0\xb8\x96+\xfd>\xd9\x9b\x0ch\x13\xfdY\x19 \xe3\x0b\x18\xcc\xcf\xa85\xf4\xbd\xbb\xc1ZE*\xa3\x94\xfd\xd3\x92g\xf92\xfct\xfc\xfa\xefUSP\xce\x02\x00\x15c;\xdbot^6+\x9dg\xaf\xbe\x7fv\xb1\xe1Y\xebY\xcd\x04\x0e\x86\xd1\xbb\x84\x0c\x00\xe8\xfaY\x9d]BS\xf7 \xa4\x92\xbe\xce\x06\xba\xdc\x19\xbe\x89\x10\xe5\xe6\xfd\x11\xec\xb83\xdf$\xa5\xeb\xc6\xf1\xfb\x11|Yu\x93\xff\xfd\xa4,se\x1e\xdc\x9at\xde?\xe3\xc7\xb9X\xacx\x02+\xef"\xfc\x80\x95\xe2O"\xb0\x81\xa7\x8b$3\xbd\'\x17\x9f7X\x08\xf3U\x19\xddg\xe7\xb4D\x08H\xba\xa9\x0e\x90\x9e\x9c\xf9\xdf\xf9\x8c?\x915#\xc7\xa3\x94\xf5\x7f\xb1\x8awMjo,;\x1c>\x04\x1a\xa6\x8b\x1f\xbc\xd5\xe3\x10\xcb\xb43\x91p\x19\xf8\x07\x95\xcf\xe3\xf1]|\xe3l}x\'\x93L\x1f\x07`\xc9*\x82\xa87\x9e\xcf\x08G\xfb\x89\xf6\xf2\x1e\xbbfY{%T\xda\xa4\x89\xc8\x91\x7f`\xa5\xc0\xaa\x01\xac{\x91\x8eT\xc0\x8b\x99\xb08\xab\x87%\xc4Qs_\x16\x7f\r\x10\t\x82[#Ty\x91\xbaEd\x85\x94\x1f:\xe7g\xf0\xad\xd6rV\xd5~O\x93\xe4\xe7\xc8\xc8\xb5v\xf5\xb9\xce\xb5@\xfc\x93\x8b\r\xb4w\xed\x91\x93\xf3[h\xc7\x9a\xd2\x9e\x01\x10\x91\xcfj\x9a+0A|Y4\xd3\x00\xea\xf0\x92G\x1d\x92Qz\xaf/\x80\x9e\xdb\xf3\xb8\x81\xea\x14\xc8\xf2\xb1I|JdPX\x9a86UK\xda}m]i\xf5\x86\x0c%E\xb8\x18\xd6\xdaT\xc8\xedZ1_\xd16\xe8\xfdc\xab\xfb\x9b\xf2&2\rg\x7f\x98\x1e\x8c\n\x02\xab\x18\xbc\x0f\xb2\n\xac\x04\x84\xf0\x99&\xf8\x89\xb6\xdd\xbd\xac\x1f;\xcb\xe7\x86[\xfa5\xb3\xf7\x8a\xd0 \x05{\xfd\xfbF\xa1\xf1)<\xder\x94\xd2%\xd4\x18+\x84T\x92cv\xf7{\x9a\xa4\xc5\x088~\x97now\xd1\x0f\xaf\x1aIv&;J%\xb4\x1a\x16o}\x88\x01R\xee\xeb\x83"ZR^\x93>,\xca\xb2\xbe?\xe8\x196\xf7J\x9b"b\x19Vp\x82\x1a\xab\x81\x88K6\xaa\xd4r+ \x84_=\x03\xc1\xf4\xea\xcb\xc0\x1d\xdc\x8f\xab\x92\x01\xb7\x15CC\x87;\x148\xee\xb4\xf4\xf3\xd1t\xeb\x9a\x13\xeb\xb7\xaf2\x80\xdd7\x97\xf1\'\xe4~P\x10c/\x0b\rR\xd0\xbf\xf3j6\xb3HB\x102\xed\x96Z]\xedV\x0e\x84\xb2e\x04\x18\xcf0S\x87\xcfk=\x7f\xf7\x87\x8d\xbc^\x15q6\xff\xa7\x9d\xdc\xcb\x98\x07\xe6|\xa5\x1a\xf3K\xa9<\x0e&P\xe4$\xcb\xcd\x81\xa4\xe3w8\xb7\xcb\xe4\xfe\xf0\x82\x11Cn6\x8c\t\xa1z\xa4\x9c\xdf\x15\xb8\xae\x9ax\x96]U\xc9\xfdE\xa4\x00\xe0.\xd6\xadQ5\xaad\x07\xa4\xb3\xf3d\x80\xe4-N\xa1\xff\xdc\x16\xb3u\xd3kJI\x7f\xa80ZgoH\x86l\xc3\xbb\xce\x7f\\ku(\xda\xa7\xfd\x94y2\xa0\xbaZ\x10\xf95or\xfd\xf1\xa0\x12\xfa\x7fH$Y\xb4\x05\xbar\xe7\x81\xa65\x98\xfb\x93-g\x031Ew\x1e\xb0\x9c\xde\xbdi4P\xf96\x90k#J\xf5\xa3\xa6\x86\xf0\xd3\xb1\xc6Y-\xabr7\x95\xff^\xc9o\xfe\x94\xad\x9f\x9a\xef\xe0\xa3\xf3\xa8\xb2\x1em\xdbP\x11\xc5\xd6Z\x97Y\x99\x07V~i\xab\xebV~0BU\xec\xbe\x15\'\xc3U\xc9\xc6\x9c\'\x9a\x9d\x90a\xa8\x9c\xe3\x01\t\x94x\x07\xa5\xda\x9cA\xf8\xcf\xa7d \x08(JK\xb7\x9d\xbe\xd0\xbe\xe46-m\xce\x98\xcb\x96\xacWOP\x08\xfa\x8e\xec\xee\x7fx\xbc\xe5\x80\r\xfe9\xaf\x1f\xd5\x13\x93\x8b\xf20%lX_\xe9\xd3\xfd\x94\xe4\x93\xd0\xd0\x12\xa9\xba3\xbd\xb1\xc9\x95\xbb\x11\x92\xe2\xc4\xd0\xc3\x90\xc9\x03\n$\xa8\x82\x08\xf0L\x93U>\x85"\xdb\x13\xd1\x8cuP\x8c\r=K\txz\xf4\xe5\x86q\xf5\xf5\xca\xe9N\xc8K15\xd4\xfe\x17\x8b\xd3|\x9fC\xe3\x9c\xc6\xa0P!U\xf4\xc8w\xa5X\xd0\x1fn\xd7\xac\x0c\xe2\x03\xbf\xea\x8c\xea\xf5\rg?\xd6\x16v\xea\xba2\x14\xa4\xea\xf6\xda\xe9VW\xa3\xf8U\xce4\xc4\xb2\x1f\x08\xe4?\xb6\xc8\x9bW\xd0\xfa\x19c\xffk\x9b\xd5\xff\xfc\xb6\xe46j\xb3\xeeas\xc3\x03\xba?M1\xd16E\x14\xcf\xfb\x1b\x0b!\xae\xe8\x9b\x7f8q\x96W\x14\x99@|\x01\xc0\x99\xb3\xca\xd3?\x18\x92\xf1_uwX\x99\x0b\xff\xeag\xf0\xed\xefj\xf1\x0fO\xe5m\x87\xac\x97\xb6\x1eU\xf6\xcb\x84\x80u\xa8\x9c\xdax\\\xbaq\xc9\xef\x13\x9a\xda\x11\x8b\xab\x16\xb9\xf6\xc67\xb0\x1a\xd5\xc8\x8e\xb5\x04{\xe2\xe4Z\xd8\xb9 \xa0Hr\xd8D\x05G\x86\xb8f\xfe\x89\x1a\x90\xdbI:<j6\xdb\x13\xd5a\x9e\x8c\xbd\xbf\xd2:f\xee\xbf\xbfT\xbf\r\xdd\xc7\x8c\x8c\x0f/|\'\x91q\x8d\x92\xd27\x9a3DZl\x9a\xb3sN\xb1\xffK\x80\xfa\xe1`\xbc}k\xfe>\x8f\x93\xee\xcaN\x9dn\xc0j\x1bj\xe7k\xc0\xa4\xc4\xc4\x00E\xd7\x81\xec\x0fy:\xdd/\x8c\xa8\xbb\xac\x07\xd5\x9e9L\xa6\xe8u#ar\x99!\xf3\x8ea\x93\x82\x80"jzr0C\x19\xe7\xce\xaa\xa7\xc9V\xe7H\xfc+\xf7\x94\xc41\xba\x96\xe4\x14\xe7%\xea\xf8^mc ZLa\xf0kJ\x7f\x8f\x8dq\x8f\xb8%y\xa6IQ\xa4\xb3\xca\xba\x0b\xb3q\xae\xd8\xb7XY\x04\xfb\x01\xd3]P$\xad\x01\x07~\xf5fo1_\xa1\x9eD<.\xedg\xb8\xeck\x90\xc5\xe0^\xaf\x91\xf6Q,\xcb<]\xcc\xdftA\xbeh\x96\xe1\xaar\xfa\xbf\xf1\xf6\xb7\xb4\xeb@Z@r\xb8n\xa2\xd1Cy\x16\x10!\xb1f@\xcdt\xd3\x14\xce2\xef\xf7\xf9\x10R\x13r\xb8\xf7\xe5\x02C\xb3\xe4\x10\x9b\x96\xfd]\x0b%N?b\x13\xbf>E\xd6\xa1\xab\xd1-\xaf\xb3O\x18\x82,I\xcf\xdc1"V\xc1\x86"\x02\xbdW\x19\xd0fZ\xf1\x0e\x05\xa4\x8c\x81\xd3P\xb3\xf1A\xd6A}\xb6\xf6&\xb4\x8d\xc9\x11\x17\xd7\x13\x83\x04\x85Jn\xb2\xa0V\xd3\xe5\xf5\xc8z~\x01}\xa3\x8b\x87\xa2\x07D\x8d"\xc2h\x14-\xeb\x19\xeb\xedf#\xe8i\xe9\xafa\x1e\xf6p\xf1\x0e \xf9\x9a\x9dN7\x0f\x0e\xfc#\x95\xf3\xf0\xf7&"\xa7_\xfe\x88@\xd5\xed\x9fn-\xe6o\xda\x9c\t\x88\x1f\xd6K5K\xb8\xf6\x021\xe8\x94n\xb2\xd7\x9b\x12m:q\x00\xb5\xa5;\xc0\x1f\x8d\xc3a\x04/\xee\xaf\xd3\xc8\xa2\x9dP!\xb6\xfe\x04\xe1\xf3\xfb\xc7=Wy\xedk\x9f\xd1\xb9\x17w\xec\xe3|\x10N)=\nfH[,\xb4T\x0bQ\x13\x1b\x17\x89?\xb5\x1d\x11\x84[\xf9\xfea?\xa0\xe1\x01D\xb3\x06<\xac\x99\xce\xbd\x88:ox\x84\xd8\x8c\xa5+\x89\x92|\x14p\x80\x1d\xb3M\xaa\xbfV\xbc\x10\xd0\x15\x81\r\xe6\xa7\xbc\xf5\x18\n\x0b-v}>kEy\x1b\x01\xa1\xbc\xd8A\rI\xaa\xc5\xb5\x8e\xf1\xe7\x04\\\xea\xa9+u\xd1\t\xa1bm;\x1f\x9eD\xb6\xd7\xcc{\xb9\x1d\xf4j$?\xf8\xa2\xf2\x8a>\x13/\x16\xbcs\xfc(~\xbd\x94.\x7f\xe6\x11\xe1\xf7s\x19\xc8\xfc\xb2g\x1b[\x1c@\xf5\xbb~\x1e\xfb\xb0\x9d\xfc#\xdd\xf7\xda^\xa5\n\x941\xb9Z\xccO\xbb\xb4\xbd\xf1m1\x7f\xcac\x80rIl\xff\x89\x18\xc9l\xf2\xce\xcf>#\xd7\x05\x9c]\x9bp\x1c@\xa1z\xfd\xe7\x19O,k\xb0C\x87\xd5|O4\xc4r\x05I\xa7\xd1\x16\x12\xc8\xeae\xe9\xb3o\xd2>\x8a\x9f\x07\xb0N\xf9\xdf \x0c\xb7\xfe\xed\xdeul#\x1a\xb5\xfcL*\xbb\xb3\x0011\xa13\xe2G\x18\xce\xb3\x1f\x80y\x00\xd1\xc0\xfbE/\x95gC\xe4\x1b\xaf\xede\x033UN\xb4\xee\xf5\xfa+\x06w\xf4*e\xc7\xfa\x15\x8a \xe7\xdb\xb7*\x03p\xfb:yo@\x17\xdb\xa9!I\xd8;~\x1b\xebd\x93\x9e\x11v\xa5\xeey\xf4\x01k\x06\x95\x0f\xf4\xb8\\\xd0\x1e\xfd\x86_\xeep\x1aG\xcd\x94\xbc\xceA\x95Z\xfa\xba_\xc6\x13\x8b^x\x88\x16"\xf4\x03\x8a\xa6\xeb\x9c\xfb\xdc2\xc9\x02z\xa8!\x19\xb9\xda\x96\xcd>`p\xa3\x15\xfe\xbc@^\x08A\xe9\xdd[\xcf\xad\\\x89\x83]KV\x92(\xfd\x9f\xabk\xac\x97\xd2\x9f\xff\xe5\xcdj\xbc\xdb\xa9\xb0\xa65\x85\x83\x11V\xab\xce\xcd\xb6jo\xdc\x17\x1fb{y\xc2.\x16E\xb8k\xba#\x908\x15\xbaL\x80\x0cF\xfd\xeb\x07\x15Gk\xa5\xc9|\xeaF\x06zT\x93\xd1\xbbA\xf7\x97\x12\xbb\x136\xb6\x93\xe1y\xfd\x1f\x93\x156H\xf1h\xd9\xff\rB\x0b\x030\xaf\x8d\xb3?\xc4\x1c\xc8P\xc6\x90\xe3\xb9\xce\xbf\xbcb\xc3/\xc7\xe4\xec"z\x93\x1c\xfbv\x05\xcb\x82\x80\xeb\xf6\xf1\x1bf\xf2\xe8\xac\xa5\xfdz\xae,!\xaa\x1ffk\x96A\xaf\xa0\x18\xb9\x9e\x93?\xbc\x81\x13\xa2\xbb\x19\xbd\xb9\xd5\x86\x1f\x8ewz\xf8J\xa9\xcc\xb2\x82\x80\xeb\xf3\xb4+\x1e\x17.\x8c\x98\x95\x17t\x0f$ =\xa7\n\x89\n\xbf^\xa9\xb9m\xe7Z\x90x2\xdfLr\x0c\xf6\xfb\xe0\x0f\xa5n,\x16\x17\xd3Fm+\xad\x19\x02\x94\xe1\xdaO\xd9\xcd\x89\xb2\xd1\xcd\xb2\xc6\xd5\xf2\xe8\xa3\x19\xb3\x9d\x15\t\xf7\xa0\x82\x1d\xf8\xb5\x99\xb6\x84\xeb\xaft\xe8\x1f\x11F\x13\xa3\xf2\xff\xdd\xa9\xf7\xa9\xc3(\xa0y\x15\xef\xbb\xea\x84\xe0\xa5\x9e\xafs\x85\xdcW\x8a\x0e\x9a\x89\xa8\x9c\x0b\xe8\x1c\x88F\xf9X\xd0o4w9\x94f\x9dK]\xff\xb7(\x01\\T\x02\x91\xff\xf0\xad\'\x96Mt\xe3\x97Q\x0e\xcf\xf3\x1d\x14IB\xa9\x04\xcb_C\xaaG|(f\xfc}\xb2\xef\xccXa\x99\x17C\xe5*W~\xe8\xf4\xa835\x08\xa5:\n\x8cXM\xb7M\x9a\xebB\xe8\x1c\xa3\x7f\xa7\xd7\xf9c\xc1V:w\xc5\xde\xbfGz\x8b\xe1S9\x89\x1d\xcd\xfb\xff>\x9d~\xd3\x901\x04\xac\xed.\xc5\xdf\xce\x7f@\x0em\x08\x9d\x1fs\xf1\xeb\x04\xd8\xfam82\x03\'O\xcaO\x10Ej4Y\x8d\xf2R\x0f\x05\x06\xbf\xb1SS\x93\x7f\xf0\xbauo\xa9m\xdf\x80\xec\x8b\xfd\xdc\xfa\xb3\xd4\x1fyt\xb5\x15\xf3\xef\x1b\tQ\xb1\xc7B\x08\xc6\x07GKR7\n\xc21\r\x9e\xb5\xb1\xe11\x05\x00\xe7xo\xb5\x04r\xb4p\xed\xefs\x84I-C\x0cp\x99\xae\x96\xc5\xd2\xdbB\xdbJ.\xc7\x1b-b\x0b\xc22\x18N\x1fI0\x83\x02\x9e\x83\xc8\xff\xba\x94\x81-\xa6O\xc7X\xf1\xf9\x9a\x16"\xd7\xebA\xd2\x1f\xc1\x8d\x17\xc2\xce \x91>\x93\x9c\xf2\x8f\xb2\x92\x05\xa8\xacu\xee\xe9\xc5\xcc\xd3\xe6o9\xfc!\xf2\xeb\xbd7\x8c\xbd\x92\xdd\x88\x01a?.qx{>,\xae\x9aO\xf8\xb4\xedJ \xf3r/K\xa2\xcc>#6\xbc\xae\x08\xe0\xd6\xd2\xbe\xbf\x1a"b?\xac#!G\xb1\xd2Gw\xeduw\x8ch[\xe6{\x86\x93\xb8\xf1A\xcc\xa0T\r\x10\xf9_\xcb\xff\xe5\xe10\xc5=v\x81\xcfb\x07N\xcdX\x8dXm\xc3\xb32\x02\xc7\xcf\xea\x0c\x99\xf9\xdfe\xd1\xe7\x7fhIL!\xc0EZ[\x0e\x0f\xd6I\x9d\xcdZ\xd9l\xef\x8e\xed\x86B\x83\x86>\xe5\xc0\xe24\xea\x8f\xf2!G\xb0\x8aY\xe60;\xe9\x91\xa3\xd4\xa0y\xc1l\xb4\xf3r\x8d?\xd5#\xba\x91\xa4\xf3\xb1\xb5=\x8e\xc4\xc9\xf9\xeb@Qp\x82`\xc2\x96\xe3P\xc81\x8c\xd6r\x8f\x02\xea\x8e\x19&f\xff]>\x01=\x9f\xe4P]\x17e+\xea\xbdqq\xf7x\xb0>\xd1X\xdd\x87Y7\xeb\xa9\xe4i\xd0\xff\xcb)r\xb4\xe2\x11\xeb\xd3B\x9f\xba\xfe\xbf\xc7\x07\x9f\xc2o<A\xb0\xe8\x17\xcb^\xd5\xba\xe11\x9d\xf6\xc9$<\xb8.\x1a\x8cu\x9eq\x81\xe7\x13u|\xa7\x12?\x16f\xfb\xeb\'\xd9\xbd\x93p>\xe2y\xbd\xa5|\x0c_q\xa7\xf7 \xc7\x99\xf7h\xd0\x9f\\\x06g\x8d\xf3\xe5B\xf3\xb7,~\xa2\xdc\xe5\'!\xc8Q2\xa1\xe8\xa6\xf8\xb2\xd2z\x87;\x7f0\x03\xe1\x1a\x88`\x11d\xa3\x81\xc5\xd6%o\x8d\xdb\x9d\xcf\x89\xa8\x93pt\xce\xd9\xf5D\x86\x11\xc8\xf8\xeev\xe4\xee\x8d\x7f\x95\xfd\xa1\xf2\xa5OylX]!\xc0]\xaau\xe3\x87\xaa\x1b\xfd1\x8b\x8a@\xeeL\xb3\xc7Yg#\xa4\xdb\xd8B\x12\x8a\xa0r59/K\x92\xceo\xc4q\xe0c\xaab\xad\xcdM\x19\x01\x15T\xb8\x8f\'\xccF\xfe\x88\xda\x9d\x8b0j\x1f9\xe7\x12W\x0b\xe9\x18\xad\x9b\xfc\xd3f\x9f\x01\x8e\xe8\x19\xe0K5C\xfc\xaa\x14\x04\xf47F\xfa\xf9\xaa\xeb_\'*\x0c\xa0\xb3H\xb9\xe3{\x1c\x81\xed//m\x01f;\xd80n\xa7\x10\xe0\xf8\xa4\x10~b\x83\xcf~\xa9\x9fe\x9b\xaeI\x90\xbeN-\xac*\xefD\x0fu\xe5x\xb7@\xf4\x82\x1c\xff.\x08$\xe9m\xc7\xad\xb9/\x9c\x9a\xe5\xc3_\x12\x9d\x9f\xa00\xb7\x7f\xc3/9\xba\xdd\xe2x\x81+$\x11<8\xeb\x11\xdd\x01I\x87X\x92\xa2\xd6\xcf\x84OC\x8e&\x92?\x07*^\xa3Z\xe0\x13\xe4\xf7\xd0o\x14\x1d\xc0g\x19\xac\xc39"\x89t\x16:\x19\x9c\xc2\x90\x0f\xd8>\xff\xe6=\x12\x8fL\xee\x1b\xdd\xbe\xae)\xe3\x92Mu\xe6Ka\x88\xbf-;\x8f\x95 \xa0\xb7\xe1?kN\xad\xc87O\n>?;\xbfB\x85\x84\xb1\xc1\xc2\n\xcdQ\xbc\x97s\xbfK\xa2\xcbt;\xa9\xe1\x8c\x01#\xf5\xcd\x99Ox&\xfd\x84r\xaf\xe4\x9a\x1d\x18\xa4-\x896V\xe6\xb2I\xea,\x1d\x8b\xa7\xac\xfb\x0c\xc6\xc7\x0c]\xb2\x1fU\x16\x92?a\xab\x02<\xfc\x88"\x8e\x8e\xd7;\x1c\x90#c\x97,z\xc6Q\rD\x8e\xea$\x06\xd5lfB\xa1\xa8\x9b\xe8\xfce\x1e\xc7M\xbbNz[\\\xb6\xff\xbb \xeb\x1d,b\xf6\xad{\xab\xf4\xe2_\xe0\xa8\x8c\x1d9\xff\'n\x83\x82<\x06\x93\xa3\xef\x00\x97u\x19\x9cQ?\xd9\xf0=V\xc1\x91\xf2t3u\xe2\xbd\xcc\xbd\xf7\xc9e\xd7\x90\x84d\xd5id\x13\x05\xa6\x99\xb3\x8c\xf6\xfd@\x8a\xe9v7f\xbbr\x1a\xd9=3\x8a\xd66\xfaJ\xe1a\xbe\x19\xc4\xe5u\xdc\xb7\xb1If\xebU\x01{\x9d\x16\xeb/\x851T\x99\xb6L\x7f\xba[\xc9R\x9f\x83\x88\xe7qs*\x9b\xd9\x86:\xb2K\x8d\x86,m%\xfa6\xf7\x9a\xe5a\xc3c*\xb7\xfd\xf9\xcf\xf7\x99\xf8\x87\xdc\xa4\x1d%6\x10\x90\xfc\x89\x12\xac&6\xa8+D~\xa7\xfdq\xdd\x1f\xc4[\xaf\x96\xcd\xeb\x19\xdf\x071\xd5\x83\xf3\x8c\x00-2\x00\xacs\x7f9\xed\x13i\xb2\x99\x81C\xdd\xb4go\xa9\xf8f\xef\xc3\x05/\x82\t7\xb2T@\x00Go\x00\x80U*\x8c\x00\xf0\xe1\x16\x05\x80\x0e\xaa\xff<\xee\\\xc1\xba&0\xa3\xe6-\xa4\x04D\xf1\xd8-\xa7\xf4\x03\xfc*\xa71\xf04\xb2\xe2\xa755\xe51i.[\x08\xdcW\x81\x90\x91\xe4@]\x10o*\xb6\xe5\xf7\x10\xd01z\x8b\xcd\xb7\xb6h\xf8\xee\xeey\x89\x02\xac\xa75\x18\x1a\xb3\xc7\xdcVM;IW}wa7!\xb0S\xc0\x85X\xbd"\x9d\xed\xb68\xb4w\xde8L\x01m\x02\x18\xa2\xb9\xe7\x01\xb6\xb1B\xe3\xdd\xbb\n>\xed#.*X\xa8\x01\xd2d0\x02Y\xad\x04#\x13\xd8\xae%\xc0{\x1b\x00\xc8e\x13\xec2\x12d\xb2\xa6\xc4\xce\x080@\xd8\xbf\x03\xd0\x98\x89\xa8\x1a\xb1\xbe\xba\xf3\x00\xd8\x19k\xd6\xa2.j?\xe1?\x8bQ\x89O\x01\x08\x10\x1aP{-\x10\xebf]urv\xa2e\x1d\x03\x13v\x04PLm\xab\xe1\x12\x90\xf7\xdb\xf1v)vF\x80lh[\x02\xbd\xf2$\x0c\x7f\xbb\xcf/Y\x02\xfc\xaa \x80{|<$\x1f\x9fF\x89\xea\x04\x04\x00\x81\x93\x06\x11@\xad%\xf9\x8f\x96\xfd\x97\x99 \xdak\x08\xa0\x8e\xe6\x1e\xd9\xd1\xdb\xa9\xa0:C&\x0bp\x0f(M\xd4\xa0\x82\xdf\x01 \xe2\xb3 \x008\x1e\xd2\x000~y\xbck\xffl\xfb\xa8\x198Z\xe6\x96\xb3\xa5\x0c\x80\x8d\xb9\xe6\x04\x9d\xad\x0c\x89\x8d\x05@\x05\x8f~\x03Gk\xe6\x10m_j!\x14\xc0\xce\xde\x95\xdba\x1f\xeao\x9e\xa4\xe3\xba\x17\x0b\xdaM8;\x7f\x0c\xbah\x04\x80\xfd\x7f\xcd\x0e\xb2\xe5\x18z\xdc\x06\xc0\x90\x8dd\x02>\x9dS\x9d6\xdf\x02 \x80V\xee\x83\x00$G:M+V\x16\xc4K!\xa2\x9a\xa3\'E\xaa\xdaUwr"\xaf~\xa0\xef\n\xe3c\xc5\xefR\xe6\xb8\xec\xbep\x9d\xadt\x85\xf3\xd5U8>hV\x97\x91\xc2\x96\xa3\xf2>\x1clX`\xa6\xf6N\xc1\xfa\xa1\xado\xc2c\xaf\xbd;+\x03\xce\xa6\x93\x0f\xae\xf1\x020\xd1\xfb\xd7\x04\x0c\xe92f\xc8A\x84\xc3c<\\\xc2\xad}\xf6\xf4&\xf1\xd1`iY|\xe0\xa3\x85b\xf9\xde\xae\xba\xc0EeD\x8bO*\x9c6\x9c\x82~1\x00\x84[\x14\xdc\xe50\xc9?Qk-;~]\x0b\x12!\x18\x81\xc6\x86\xe0oo\xc6\x9dW~\x9d:;^+\xe2\xa6\x8f^O\x07i_\xdc\xe45\x04\x04\xea\x83Dm0[\xc5+\xd4+\x0f\x06\xfa\x16\xfe\x16\xaa\xc2?\x86\xad\xb6%\xca\xc2e0b\xa1\xdf-\xfb\x1b\x9a\xb4\xe7\xd3fK\xde_\n[\xb3\x01U\x9f\x89b\x82\x8c\xc0N\xc7\xa5\x9f\x8f\x14[\xfeh\xa2*\xa1\x98\x18\x9f\x9fp\x0e\xbd\xd1\x93\xc9\xd3\xbb\xce\xe6\x87\x83\xffH\xa2\x80HA\xb0M\x12\x04\xb4\x1d\xa0\x03\xdd}\x19\xf3\x99\xf0\x93\xee\x86\xd7\xb4\x8d\x8f\x99\xa61\xc7\x15\xffHz\x80M\xea\n\xf5\xca\x10\x10^\x1a\xc5O\xec\x11\xb3B\xc4\xf5\xbdE\xed\xd1\xbdZW(\x7f\xc4\x80\xad$\xab\x8a\x0b\xc0*\x9c\x84>/\x02\x98\x1fU\x8a\xb6b\xdb\x99\xa4\xdb\xdd\xec\x02-MA]\x8e\x80>d\xa32\xd1Qp\xf4\xd8\xee\x14C\x86b\xd6\xea\xfa\xd7\xe9\xc9\xbc=\t@\xc5u\x85Z4\x04\xe4\x93\'\x15e\xd1\xd1\xc8\x9d\xba\xffBLH\x08\x95\xf4F,\x13D\xa7\x8aH\xfd\xe4~d\xe9g\x15\xbe!\xa3 \x9d\xb4\xcc\xe777\xf1\x82\xf0\xa7\x1f\xe0w.\xc7H\xe3\xc3$:f\n\xea!\x05\x83v\xe8y.Q%c\x05\xe9~J\xc2(\x91\xec\x14\x90cK\xb0U%\xc9Z3\x02v#9\r\xd9g\xf3\xe1\x96U\xa8\xbez\x18-\x92\xcb\xaag:\x88h\x8c\xba@\xc6|\x92\xa65]r\xe7\xae\x97\x99\x85k8\xad\xbd\xc9p]\x17CJW\xd8!\xd1\x12\xb0\x8f\r\x00\xb9\xc9\xe8\xff"\xb5\x01\xda\r\x97\x0e\xcd\x03Y\xb5\xc3]\x00{E\x89G\xf5\xa2\x89\xee\xdd!\'\xa1*\xaa \xd6\xe1\xf78\x85[\xfc\xd0\xcb\x9a\x1c\xc9\x05\xab\xee$3\x8e\x11\x12\xddm\nj`a\xb1\xca\xcd0\xe4\xd1+ Y@\x86x\x16*SJb\xe3\xa6!\x859\xdb\x0b\x04\xfb\x81\x7f\x100\x19q\n\xda#q_\xa1\x1e~\x07\x98G<\xf8\x96^\x8dg\xa4y`\xc1\x10K(\x9e\xc5\x1eG\x8a\xfa\x02\xe6\xcb+u=\x92\x13\xf9\x9b\xfd\x00&\xf8$4K\x19\xc4z\xab\x9d\xef\x15e\x03a\x91B\x08?\xb1.\xbemnh\xa3\xc5\xf6\xf19\xdak\x87\x8dG\xf2\xe2\xf2\xb2\x05\x9cw\xda\xec~v\x87\x82\x0e\x9f"\xfc\xa0\x83_\x97\xf0w\xb2lBC\x08d!\xcc\xc0\xaco\x0c\xc7\xe8k<8\x86\x0b(\x8eO\x06\xcc\xb7\xe4\xff%]\xc7a\xf3\xf3?\x0b\x02\xe6\xa1}\xb0\xb59\x1b\xcc\x93\xd7PY/\xfe8\x8c\xcc\x96c\xb6+\x8fi\x11\x02\xb4\xedx4\xfaj^6\xf0\x0b\x98\xdf\xbc&\xa6d\xd9\xc8!nO5\xce\xee\x1bN=a}E\xce\xff\xf9i\x97_c+p\xbdg\xf5}\x17\x99\x08\xe8\x01\xf9m\n:\xeco\x03(\x83\xb8@_\xfc\xf6mf~\x0f\xee?\x04&\xd2(\x01\xbb\xe3\xcf [\x99\x89\xfd\xdbaoS\xb0\xc1\xb1\xd1B\x80\xd9\xdc\x98\x02)%]|3Oq\x0b\xad\r>-\x1b<\xc0\x9eN\xbe\xb0\xa5\x18\x9dQ\xebU!\xfc\xaf\x9b\xd2\xd8F \xb6\x9d\x9a\x1a\x18\x02\xf2o\x02\xbbZ\xbd\xcf\x034\xfa\xe3\'\xa6x\x90\xb4!\x0bz\xba\xec\xc0\xfc\xba\xfc\xfb[(\xb3\xff\x7f\x85Mp\xdcxg\x083`\x06\xf3\xe5\xde\xd2\x071\x8b\x1fR\x0bj\xc8\xa3\xe6\xd4\xd9k\x06Th\xebD\'\xd5\xf9[*\xf7f)\x03/\xb7B\xce\xf7\xcal\xd0b\xd0\xae9\xf2\xf6/\x19\x81\xc4\x8dK\x9f\xe6\xde\xfd\xd7/\xec\xffr\x82\x9e\x06%b\x835\x1d\x06u\x99\xed\xca\xe3\x06\xde\'\x97UN\xe2\xa3\xc6>,4\x1d\xb0,&\x19\x02\xf2\xac\xf9-p\\W-VV\xceb\xfb\x94\xba\xed[\xce\xf5\x9eJem\x1c \xc7>\xdf\x9b\xd7\xe7\x0f\xe8U\x0b\x89\xd1\tl\xe9\xd57\xfd\xfd\x87:\xf0\xae\xb7W\x01\xab\x15\x7fHP/\x0b\x84-\x96\x0c\x9d*B\x8e\x18y\x00\xbbC\xbc\x1b}w{\xdb\xcbV\xf7\x0f\xd8\xa6\xafS\xfb\xc8i\x15F q\xfd\xfc~%\xcb\xf6\xf9\x8bwEt\xcd\x8e0g\x1c|\x97=\xc1\xcf\xa0?z\xa9\xe9/\xf6\xbfA\xbf\xdd\x04J\xa2\xcb\\\xfe.\xa8\x85\x1c!\xdd\x85\x82|\xcb\xcft\x9d\xae\x91\xe4\x8a\xf4\xeb\xbd\xd51\xd7\xa6}\xcf\xe4\xcc7\xb0wU\xfb^3\xf8\xb2\x97O0j\xc4\x98x,>*^!_\xa3p\xf5\xbc/+\xd2\x9fe  \xe4\x06=~\xd4Z\xb6yJ\xadd7\xaeg\x03M\x80\xc9\xfa\xad\x0c\xf9C\xba\xf3\xea\x8e\xd8\x99/\xfb\xc7.[\xdd\xcd\xd1x\xa6\x0eE Q\r\xc4\xbe\x9c8\x0e\x04\xba\x9c\xf9\xec\x87\xcc4\xf0^^\xff.\x89\xce\'z\x8e\xd2\x07^\ne\\P3\xdb%\xdeG\xddD4C\xf7s\xee\x9a\xf3\x9b\xe2#\xcf G\xa9\xfb\xb2\x86\x01)Y\tn\xb4\x18hp\xd6\x1aw\xfe\xfc\xd2BkC\x88}\xcd\x1c\xa9\x00u\x0eb\x81\xd3\xcfyx\xa6\xba\xd2H\xf5-a\xe9\xfc.p\x0c\x8b\xef|\x80\xe5*\x92\xcaK\x1cR\xfd4\xb0\xc3\xba\x83-d\x1f\xa7]Cjb]\x07\xaa G\x13\xb6\nHZ\x9e\xa7\x10`R\x94\x01;ib?\xd8n\xe9\xe7\xa3y\xce$\xfe\xbc:\x8a_ \x86\x9b\x86<\xac?G\xb4\x99\xa9!\x04\x8e\xf0/\x0e\xa7\x88\x83j\x0bW\xfdz\x9cb\x16\xaf\xd6\xa8\'R\x85\xc3;\xf2\x0eQ\xc0\xaaM\x19\xe6\x0bg+\xf7\xa3\x8b\x1fX\xd9\xfc\x99\x10\x94\x93\xd1\xc9-\nj\xd0E\x16\xec\x03\x1f\xed4.\xe9\xdd\xef\x07\xea\xc4\x01\x12\xc2>\xe7\xe4\xb4\x07r\xfc\x82`\xbb\xbf\xaa\xde\xa6(\x11\xaaW\'\xd3}\xb3\xb0\xd3\xbe\xd4;6\xf6\x9a\xb1\'\x0f\xfd\xbd<\xd8\x93\x1d\xbbf\xb7\xf3\x90\x86\x14\xce\x0cg\x0f0\xae\xf8\x95\xdc\xd7\x08\xd9\xaf\x8c|\xb6\x7f\x93\xb8\xce\xea`\xdeG\xa0d\xc9\x82\xeer\xed++\xa4/T\x89\x8dUa\xfdj\x04b\xa4C\x12\x01\x06\x8dgL\x0e\x84a\xe3\x1e\x16\x00L\x9e\x03c\x9bm\xb2\x1e\xbf\xe2\xe1d\xf3\x84\xc3\x90\x17\n\xaar\xda\x02\xbd\x92\xdf\xae\xbf\xad\x02:*P\x19\x9c\x1e\x1b\xf4\xfb\xb9\x1btf\x7f{r\xe2\n\x06\x0cF\x8c\xaa\xb1\x80\xfd\xc8\xd2\xe3\xbc\xd0\xe9\xcaC|\xc2\xc6\xf3\xd2\x0e\x8a\xd7\x96\xef\xe7\xcf\xfe%\x03\xe1\x16\xc9\x13\xf2{\xbf\xf2j\xd06\xaf\x8f\xdd4\x87\xae\xf5u\xef&Z8\xfb%\xa3\xe2\x9c=\x93\xf3\xe3\x0e\x89\x9f\xda5\x18\x01\xfbm|\xc8\xd9;\x86Y\xe1(\xdd\x9d`\xd0}\xe8\xab5\x86\xc9\x0b\t`\x01k1\xe7\x1f\x17{\xa8z\x85\xb7\xfd1\xbb\xca\t\xbc\xf1G\x89\xbd\xcd\xafk\xa3\xc8\xad\x8b\x03\xe4d2zpa\xe3:\x94Z*\xac\x00\x95\x17\xa9\xf4\x0e\x9f\x0c\xf1\x8fD%2\xcd\xf6>CG^0Olf\x9dZ@\x0e\xadW\xfd@\xac\xbd\xe377\x02\'H\xa1\x0e\x98#\xc0\xfc\x87 R\xdd\xbd.\xdd\x80\xa8X\xc2\x18B\x08q{x_\xe8|l\xd7o\'#]6\x00?\x19\x94\x1c\xd8\xb3"\xed\x9d+\xa8N?#\x0b\xfd[\xfb\\\x1cn\xbdS\xb6\xf5\x01\xe9F\x08!\xbf\x7f\x11\xaa\x9f\x9c(\x08\x98ybZ\xf3\xd16\xcbS\xc7\x0f[F\xb5\xed\x06\x1a!\x873M\xa1\x9b\xbb\x8f\xaa\xd0\x7f\xfc;\x98\xf8)\xd2\xb9\xd5\x9f-rc\x1b\xf9&;\xacw\x04\xec\x15l\xd5-.Cl3\xcaN\xf8\xed\'\xff\xcc\xfal\x9f\xbf\x10\xee&\xe1\x01^b\xeb\xcd\x8b\xbe\xdbX\xbf\xbe-\xab\xeb\\\x16\xc1\x04\x9a\xb1\xcd\xb7\x12\xdf\xeeh\xf2\x13\x9d_\xdc\xc5N\x0b\xc3\x16\xc5\xec\xf3\xd7\xb8m\xbb\xeaf+}\xc4\xa3\xc2\xc0\xfc\x93\t\xb3\'$\xd8\x0b\x98*p\x81\xf4\x91\x8fiH\xa7_\xe8*\x8e|\x95\xa9M\xdfQ[\xa2\x13t\x13\xec\xe9\x1a1\x81\x1ce\x9e\x12K\x97\xdd\xa6\x1b\x1c\x9ab\xc5\xc9\x95\x80\xfd\xde}T\xcd\xec\xfd\xa7\xca\xe7\xd6\xa8\xb2XX\xa0K\x1d\xd1\xffV:\xfe\xb4\xc2\x97~\x05\xb9i3\xac4\x9e\xe1L3\x0b\xddO\xd1f:~\x0b\xfb\x1c\xee\x10\\\xbf\xa12\xa9\xc5e\x17\x84\xca\\\xde\xdf\xe3\xa8l\x0e\xc7Z\xe6\x8c\xa0\xd3\x949\x80\xfb\xbam\x17j\x81hW[\xc0\xefP\xcc\xd1\xb1>z\xcf\xb4\xf9\xe4S\x9f\xdb\xffE\xccG&$\xf3\x1f^rwb\x98t\x95\xa6\x1b\xffY \xbfZE$cT$\x98\xbf\xb8&a\xeeo\x93|\x0c\xee\x92\xe6t\x8f\x10\xeb\xd3\xb2\xe6\x84:\xf5l\xffmv]\x15\xb8\x81\x84\x0c\xd5D\x11\xd0#\xaeOd\xd5\xd4\xcf\x9c G\x99\xd2}_b\xb0\xdc\x1d\xd4\xf4\xb1! \xcf\xa4s\xe90\xab\x11\x99\x81\x11:\xa9\x97\xc0GD\xc4y\x053A\x85\xf3\xc3/\xac\xe3B\xf9}\xc1\xa9\xa6\xe6\'\xf9\x13!\x16\x99\xe5X<3\xf2U\xd1\xdc\x88gQ\xac\xe2\x1b\xf0\xd9,\xccq\x7f-g\x11\xc0T\xe7\xcd\x14\x03"^\x0b\x08n\xa3&,\x15\xa1\xe8W\xea\xa0\xb0\x85{\xfd\x14C\xc9\xab\xd4\xa1\x9dM\x8dUM\x8d\x90\xc1\xfc\xf66f\x1f\xf9\xa7z\xca\xaf\xc4\xee_\xef\xe1\xd1\xe7\xcfx3`\xe3\n V\x97\x11\xb0\xa7+\xdcX%\xb2\xbc\xd4\x84\x90hr\x15c\xc6W<\xc8l\x16\xa4\xbe\x82_aB\x1c\xd6,\xe8\xd1\x9fD\xf3\xd6\xaf\xd0\x06n\xf4\xe7\x9e\xad\xa4\x96=\xb4f\xa2\xf1\xa0\x8e\xebg\xcfF]\xed\xb3?\xc0[\xb7c\xc5i\x95@\xb4\x9diK\x9b\x99\xfa\xf2O>\xc8\x99\x99\x1c\xe3L\x16?\xb1>`\xe1\xac\x904\xc7\xcb0\x99\xc3C4\xef\xf1\xd1\x0b\xb8b\xe8\x91}\x03\x1f\xd5>\xcd\x90rCM\xd2^#\xa6q\xec\x1c\xa9\x92H\xff\x08$<\x88!\xe5\x17\xf5\x08\x02\xda\xce\xabP\xba{\xd9@X\xb4\x84i\xcb\xfe>\x82\x97\xfaf0\xf0\x9b\xd4\xa9\x8e\xcd\xa3i\x7f\xb2\xde\xe2\xcb\xbb\x8d\xdd\xf8\x14_l\x9e\xce~\x9d*9\x9e\x14\xd4\xd3\x8a\x17\xadC\xfb$\xa3\xe2\xac\xf7\xb9\xf3\x0fC\xd4\xec\xf4\x8c\x88UxC\xb0\xa5oc\xf8\x88\x9f\x82\xf8\xf9M*\xa6\xa3\xe6\xfe\x1a#I\xa9x\xd8\xfa\xe7\xa9\xffN\xb3\x95\xa2\xcdR\xb3\xd93Pn\xd3\x04?\x0b\xc1\xab\x93\xf2tFQb\xfd2\xc9\xceX\x86\xc6\xcaP\xc1LA5O&\xf8;\xf4\xf3\xe2\xc9<\xb1\x08\xcc\xd8\x12\xdeG!\xf946\xf5Feh\x0e\xff\xd2Ew(I\x85\xe8\x99\n\x1d%\x0fN\x8e\x10\x98G\xacHC\x06\xabK\xd7zb\xa4\xb9<-\x94\x06\xd60\xe3;\xb8\x86\x94D\x89\xc05\x85y\x99\xe2\xe8\xa6\xab\x1237O\xf1\xa8p0\xcf\x8b\x11\nw\xf7\xca\xeaY\xdehi\xf3:\x9b\x85Pk\xd9c\x83\x16\x8d\xfd\xfa\xe6\xcf7\xa3\xbf\x89\xc5\x11\xccK\xf3\xa9\xc7YO\x17;\x85\xf4\xe9y/\xe9\x85\xbb(\xdf\'2|G\xff\x89\x14\n\xd3\x88\x02\xf3\xc5\xba\xd4\x1b@;\x1e\xd3\x90\xea\x8c\x8a\x06\xea*\xdbL\x8a\xf7\xff>_\xad\xed\x84\xees\x06\x9dG<\xf5\xa8\x9bN\xd6\x8dIU\xd4\xeb?\x9f\xa8\xdb\xf6c\xddM\x95!O\xad\xf2\x86 f\xba\x90\xc7$L!\xdd\xf6\xfdS6\n\xaai\xb1B\xca|\xfc\xbbJ\xa2E4L\xb2}\x15\xf1\xf6\xf8^&y\xea\xe8\xfa3\xff\xd9K6\x87\x9e\xa1\x14\xf8\x0f\x11\xf8*\xa1\xc9{\x8f\xba\xf8\xc1\xe5jvu\r\xb3\x95\xa6)\xfa84f[\xc0nw\xe3\x04\xbf{\xf9\xe8\xfb\xbb\xee\xffr\x8a\xb5\x16[\x12\xa1j\x19`\xfe\x93 \xa0}\xf4\xe8\x92\xc4\'%a\x13#\xdd\xd3<\xe0\xfe\x06\x1f\xba=\x81\xca\xf2=k\xe3\x80\xb5\xac\xcds!\x8d\xaf\xaeZ7W\xca2b\x8e\x1c\x99?\xbb\x13\xb3\xdf%\x87\xe7\xe3\x0cO\xa8\'\xefd\x07\xf2q^\xd4\xc6\x12L]S\x05>oa:\xed\xf9\xee\xb6\xe9\xc6\x84\xb4y\x99\xd4PI_R\xa3m\xd3G\xe8m6\xd4\x9cZ\xc8\xb6\xc2\x0f3}[\x14\xaen\xb1\xb2\xd9\xb1\xec/\t\xbawTD\xcd\x9e\xa5W\xec\xcf\x85\xc4\xf4\xb7\x8f{\xab\xc5\x9f\xb8\x10\x9c\xc3\xfc\xaeI\xc6u\x9a#Q\x13\x9c\x99\x97\x83S\xc6\xb0\xd5\xfa@\xc7\xe0c9f\xfb\xaf\x82\x80\xd6\xc5C\x0e\r\xc7L\xc1\xc5t\xd0\xdf\xc1\xfa\x9d\x16\x83&\xe2\x9c%T\xd5uwv\x95c\x7f\xf6\xf1\x13W\x8f\x92\xfb\xf6\xc8\xdf\xebH<\xff\x1f)\x85\x88\x0e\xe2)j\x92\xa6\xa2\xab\x9aOu\xb6\x18\x1d\xd2\xd1\x15\xa2\x83\xa7&m\xa4<\xf6l\xdc\x0e\x14\x07+\x81\x9d\xed\xd7}\x14\xb19\xdc\x8aV\xd7\xf9S<\xb5\xd5\xa7\xa0\xf9\xa8\x86\xcam\x94&\']&\x01\xf1\xcd3\xb4\x84\x99\xfe\xb8\xef\x9b\xfd\xea\x99\xc4\x16\x11\x91>p\xdc\xef\xb1RC\xf8\xcc-A8\x92\x97-\xd3\xed}\x166\xa0\x89W\x96V\xa7u7\xb1\xeb\xf9\tb\xa1\x08`\xe8vo&B\x8e\xe6q{\xf3\xa1%D\xf4\xb6L\xdc\x8bc-o\xdf\xf3^\xb6\x85\x11>6\xd9\xd3\xe6\x0c\x9a\x16\x9e\x0b?\xe5\x9b\xf0\xa8\xca\xed"\x8e\xa0]\xf6hma\xf0\xe5u\xd2\x97\xaa;\xe7\x91\xde\xf6p\x96`Uv\xbe\xc8\x87\xea_\xc0\xbc\x94\xcb\x13~\x0b\xc6ry\xbd\xbfg)\x8f\xf3(\xf5l\x96M1t\x1e\xfe\xdf-\xa4\x11\x01\xa7\xd6z+S\xac\xd1\x880+\xc5\xab\x91\xd0\xbaw\xc7\xbe$\xe6(m\xa9\xdfM\xff\x95\x96\x02\x14/\xb8V-\xdb\x1dW\xbd"\xb0k\xb7x\x83#\xd2Sa\xeb\xf5>\xd5\xe8\xae~\xd2VY\xef\xb6\x1f\xb7\x9e\x1a\x89Dy\xf1\x98\xbc\xd4\xa5!\xab\x9eJ\xc3)\x97\xa0\x85\xa3\xbc\xd3\xa3o\xb1\xfb\x1c\xb9O\xca\x95\xdf\xa8\x12\x8e\x14Q\xcc7g\x15\xc99\x94k\xfc\xc1}\xc3\xfev\x9e\xb8sm=\x92\x19l\x07U\xbe\xc5;?Q\x16\xdd\xe3r+\xd8\xf5\x96 \xa0\x8d\xad}m\x9dZ7R\x01[E\ru\xcd\x9ez\xe9\xd1\xfb\xe4\xeb0\xd1\xd5\\\x9d\xef\xa5\xd7cG\x15\xff$\x19D\xe6\x1eM\xb6\xfcF\x8dv\x85h\xf1_8\xcf\x91\xfc\xae\xf0\xc4\xafo\x96\x06\x0f\xceU\xe3\x824\'\x1a\xa2\xbc$+\x92\xcd\x10\xbd~\x0f\xe7\xbc9\xc8\xfd\xc8\x88Q\xa56\r<\xff]\xde\xc2s;\xefP\x7f\xdey\xd7\xad$\xa1\xe8\x01\x14\x89\xeeg9\x80\xb6K.\xcc\x08\xc9V.,Y\xfe\xef7?\xce\xca\x91q\x93\xc7\x94\x84\xb0X\xa3\xa1\xcd&$_\xa2\xd8\xb3\xfa\r\xb7\x94\xa1A\xac_-\t\xd3HRa!\x8ai\xe5/]\x91\x04\x0b\x01F\xb4\x89\x8bP\xe0\xa6\xf2\xf5\xebw\xcb\xd80\x0f\xa6\xd8K\xaf\xed0N\x96!/\x0b~^\x1e`,\t\x1f\xf0t?\x82mu\x01\xdf\xff\x8c\xd5\xc0\xb5\xearm\xd0o7{\xef\xe8\xbf\x16}\xc7x\x0e\xe8\x98\xcd\xe6\xa3Ae+\xcc\xf9\x8f\xac\x0b\x18w\xd9\xa5\xb8\xe8j\x9e\xa0i\xabM\x93\x89\xf3r\xe36\xe4#\x14w{{\xcc\x8c\xde\x04\xf1\xbf\x1a2\xd0\xd8\xf3\xe1`\x17q\xfb\xdd\x8b\xa8k\x88~\xea\x8e\xf9\xfby\xdf\xa7\xbb\x95>G\xa3\xb6\x8aO>D\x17\xc4\x95f.\x87\x0b\x9b\xf9(J\xf5\xad9\xfa:?g\x906\xb4\x0b\xb7|\t\x9c\xfc\x99\xc5\xed\x97\x90\xbd\xdb^Y\xde\x90\x96\t>\xd0}d[v1\xe0\xa3\xf48\xd8%\xc4yR\x93\xeb\x9b\xcc\x17n\xd5RU\xe6\xeb\xcb\x8f\xcd\x9f\x9a5\xa5\xdf\x97\xe5R\xe9\x9b\x01\xe5\xb5.\xba\xf9\x8f\xcf\xca\xadeH\xb7XoO\x8d\xf2\xec=449\x14p\x9d`\x82\x19\xfbK54iv\x80\x0e\x9c0g+\xb0\x9a\x15\x82St]S?\x8e\xd4\x93\xc2\xa4\xaa]\xc6\xb1\x1a,\xfa\xd6S\x17\x93\x90v\xc1\x02\x80\xd1\x9b\xefY(\xc4\x0e+\x99\xd6\xc7.\xac~|\xec\xdd\xe42\xd6a\x1a\xb6\x8d\xda\xcf\x9a\xdd\x9f\x12\xad\t\xd5(\xfb\xbb4\x07\xb1\x08\x99\xf7\x9d\x94\xeb\xae\xcc5\x0f\xdd8;R(\xcac\xbf\xc8\x91\x0b)J\xef\xa1\xc9\xe2X\xb7\xac\xef\xf9\x8fw\x98Oi\x811}y\x92\x86\\\x9chH\xecz\xdb75\x9cC\x154\x0b-\x99e\xd8\x15=\x19\xd0\xd9)Y\xe2\x95E\xdaf\xb9\x86\xb2i\xd9\xf7x\xd2m\x1eUh\xc9\x93\x0e\xcd\xfdK\x8c\x0bv\xc0-\x07\x88\xdb\xff\xcd\xdc\n%P\xd1\xe7\x99\x90\xf2!\x1c0\xba\x98\x84\xd1\xd06\x01)9~\xd7\xde\x86\xed\xe2\n\x84\x1at\x04\x98B9\x9br*\xf5iKk\x1d\xbd\x99\xc5FRRuF\xe2\x1f\x96\xa2\xb0\xdba#o\xf4\x04\'\xcb\xdf\xf1A\xfe\x0ev\x85\x0f\'\x8cw\xbaO\x14\x88\r\xd6\x0b#\xd8\x0f\x86\x18\xa6$I.\x04\xf5,*\x82_\xfcN\x9c\'8\x98\xae\x8eV\xc8\xee]\x14\xe8h\xb8\xb9\xcd\xdaXR\xe7\x159\x11dq\xff\xa0\xfe\xa5P\x06o\x8f\x8d\x90\x9a;\xf5\xb7Eho^Q\xce-zw@\x83D\xa1\xb5\x1d\x9dW4\xb0s\x88\xb5\xea\xe7\xfe\xd8b\x9b\xd4\xf9\x0c\x01\xc36\x98\xa2\xa7\xe3\xdb\xa2@\xbb|\x97T=\x8b.\xd1z\xa6J\x11\xad\xc1)\xf3\xdc\xc6\xe3\xda\xe1\xa9\xdb\xb4\xc3\x8f*\x0e\x02\xcc\xec\xe6\xdcc\xe6\xa1\x9f\\\x0b\x1b\xd9\x95S\x02w\xf557\xb2~\x89a2\x1e3\xe5\xb1\x8a\xaa\x13\xf5\xe4\xac\x90\xabu\x8f\xd9\x7f\xbd\xcb\x1d;\xe5\r6\xa1n\xa5\xba \x04\x1b\xf4:\x89x\x03\xb2\x1a\xaa\x82X&\xd6\x19Ti\xfe\xce,l\xbd\xa5I\xdb\xac\xbf\xc9\x9a\xfd\xcb\xaa\x91\x12\x9e\xebd\x9b\xad{Y\xbd\xc8\xc5(\xf8y\x06\x87\xb1\x98\x06\xe7\xb3\xd7\x07\x8d\xfb\x0bE\xe7\'\x19\xe2G\xff:\x9c&BgJ\xf4\xabpW\xf7\xed\xf0\xf9+!\x0c7\xeb:\x88b\xdc\x92L\x95\xd7\xcf\x9bs\xf2\xb9\xe6\xfe\xfd(\\q!\x08\x87\xce;\xe6I\xda\x8e\x80)Z\xab\x12\xac\x05\xb1L)ly)9\xdf\xda\x7f\xbd\xf0\xabt\xda4{XY\xd8\x8f\x10.\xd3\x11B\xaa\x159;\xab\x84\x0c\xca\xfd\xea\xbeG\xf6\xde\x91\xf8oe-\x8c\xa0nzK\xc1\xf9\xf6c|\xf3\xb4\x91\x08G\t\xd5\xc5\xd5\x82\x9a\x1a\xda\xdb\xe3P\xcf\xf3~\xa5k\x11\x84\xd7\xb4"\x84\xe1\xea"A\n.\xfdV\xdb\x0b\xad\xe6[;W{B\x99\xf9:\xcd\x00\x10\xd2\xbb\xcf\x1c6\xb2s\xf8\xf3$\xd7\xbb0\xd3\xec\x0b^gt\xbbb\xe3\xee\x07h\x18\xe5\xd8\xf6\x0b\xcdl\xd6-\x87\xf5\xb8wYH\xdbF&\xf2Gu\xe7\r\xdfu\xf3^\xa6i\x9d\xaa\xfd\xa8\x88/6\x90\x92@BZ)\xbe,\xcd\xd7\xa6Q\x1e\xdcY\x80\xa5T\xc9k\xd7\xb9\xce\x86\xcd\xd5\xbdq\x9aU\x83\x06-\xce\x84?\xc9\xe3\x9b\xe0\xc5\xae\xa8\x9c\xa4w\xf5\x9c\xa9\xb7o\x9d\xeb\x9f\x7f\xcb8\xe0\xd4\x83o~\xc8\xca#\x90\x06\x1c\xf3$\xfd4\'S"N\xbf-\x91\x0c\xd5A\xaci\x8a\x9a\x1e\xc6\x7fPe\x18\x02\x13\xd5\x81\xb1gD\x9d\x89m5=\xa9\xdc\xa8N\xbe}\xe6\x85i<\t\xca\xfcTRK\x90\x9b\x874\x89yl\x86\xef\x1b\xd7Z\x99\xaf\x18\x0f\x19\xdb\xcc\xa3\x8b\xb86e\xd2b\x1a\xd5X3>\xfb+\x06\xbf!\x05\xfa\xe07\xa4@\xceR=\xfa\x10\x96V\x01\x81\xff?\xdew\x1d\xfb\xb0\xf5\xfe\xb3\xc5\x0f\xdb]\xf30\xdb\xa7\x19\x02B\xbaw\xebV\x82\xd4\r\x12M\xecP{\xad5I\xd3\x1e\x86\x8f\xd6\xab\xa6`\xe0~\xd1\xd1\xfa\xfa\xa8@\xd0q\xfe\xb4d-\xc7\x8c\xfe\x19\xfb\xc9\x16\xf2\x9dq`^w\x9a\xf4\xfe9\xf5\x8a\xe4\xee\xb3\xbb0\xf6\x8c\xeau|\xe7Wc\xe9--\xb60\xf1z\xab\xe5\xcd\xb5\xd7z\x05\xa7\x82z\xbbb\x8c<\x1a-\x03\xa1\xfc\xe5\xcf\xa4\x9e0\x02\xc9}\x13\x84\x97M\x0f\x15\xedI\\}\xb8\xf0\xd8\x0e\xcc\xb4g\xab/S\xdf\xa3\xcf\xe1z\x9d\x1f\xc3\xcc\th6GB\xca-SB\x10\xf8\xbc{\xcf\xd1\xfb\xccO\x05\x1a\x945\x88>?Z\x03 \x94\xec\xa9\xcdz\xb3a8\xdao\xee~\xaf&\x11\xad\xf3U.\xd3\xa6\x94\xc3\xfb\xeb\xa4\xe3\xed\x8f\xe7\xda~\xfd\x890\xf6\xbc\xd2t\xb1\xd1zR\xd8\xc4\xeb_\xa8\x14\xbaCV\xb0\x8f\xe2J vB\xf7\x9a\x8e\x99"\xea\xea\xd3\xde\x87\xa5\x10\xb1f\xabgE\x02r\xe1\xban\x1f=\xa6b\x8b+\xd6P\xd6w\ntn&\xb9j:\x91f\xee\xa9\x85\x9f~[*\x04\x188\xaey1T\'\xf5\x01\xfb#=\x0ew\x8f\xf7_\xdf\x9c}+\x9b=X\x97\x0e\xab\ty\x08;\xcf\xdd]~,\xad\xab?1\xfc\xe1M6\xf9\xe8\xf8\xb9\x91\\\x91\xebHqU\x90\x9e\xfe\xf1\'\x93>\xcb\xcb4\xa9J\x9a9\x98\xcc\xd5\xbd\x9d\x19\xa12go\xb5\x19@\x9e\x9a\x0c\x8d\x99\x0e\x89\xeau\xb6ob\x1d5\xcfA\xd8\xc5\xb0\xe4T\xf6\xb2\xdc\n\x0c\xbf\xc9F\t\x02\xce\xc2j1D\xaa4\x82\xeb\x01#\xfe\x0b\xeeF\xc6.A\xfa\x18_,\x1b\x808[\xec\xa3\x96\xb3\xb4\xb3K\xe2\x02/\xf80\xfeF5p\xea~&\'\x86\xf3Q\xbf\x16\xd1<\xbf\xff_\xc0\x14\xf0\xb6\x94J\xe0\xe3\xafR\x9f2\xb7\xd0\xaf\xfc\xff\x9e\x98\xb1\x9a~\x12O?L\xd52}*\x15\xc9\xbc5\xad_\xe0\xe7ZdW9\xf7\xa0tK\x15q\xea\xcfp!\xe3\xf1\xa0\xcdS}\x92\xf8kQ\xbc\xeb\x1a\xfe_\xe8^x\x01\xa0b\xb6\xbazW\xa7\x97\xfa\xe0e\xacx\xbe\xdf\xfb?r\xcc\xee\x99\xd9\xe1\x0e\x19\x1dp\x0c\xa5\xcb\xb9*\xa9\xfcC\xfb\xa2\x9f\x80w\xe4El3G\xeb\x1awO\xdeY\xf2Y\x0e\xa4\x9b\xa5\x08Pe\xee\xd9\xef\x0f\x8b\xf9\xbe\xa5\xda\xce\xac=\xfa\x7f\x03\xf1\xc4\xba\x8f\xfa\xf6\xde\x8c\xf1\xc91\xea\x7f#\xa0[g\xfd\xb1\x0b\x15\xbaK\xe5\x89J`\xde\x94\xf9\xd5\xd7\xba\xc3U\x1c\x88\x93\xcb|\x15g\x08XR\xe3\x91\xab\xdf=:\x0fe\x1d\xfe\x99\xac\xc0\x98\xaa\x07c}\xb5v\xc7\x98\xdf\x9d\xc46\x80L\xec\xc2\xa8d#\xd2\xcd9\xbe\x96_\x83\xee9\x0f\xbam6\xeb<\xbe*\x7f\x08vh\x13\x04\x9c?\x02\xb5<\xcd\xae\xf4\x9c\xefPG{\xad.\xdd\x18\xad\x08\xbdvHa#\xbb \x93\xdf\xad\x002\x81\xdf$g\x11\xc4\xd2\xe9\x0eM\x7f}\xd1\\v!4?\xa4\x9d\xaad\x8e\xb0\x90K\xbc\x8c\xe87\xa0T\x02\xa9\x8e\x95\xe6l\x8b>>x\x88\xf3\xd6\x93n\xbep\xf9*\xde\xf9A\xf7Il\x87\xbc\xf4\xeb\x99W\xe6\xf3\xa2P\x08L\xd4\x9df\xf6\xfb\xfc\x9e\x9c\xfa#\xc1]\xf8\xc2^\x9d\x87\xaaz,\xd3\xc4\xb5\x98\x00\r\xf1\xdcFn\x18\x11R\xb0Ku\x06\xaa\x01m\xd7\x19"\xd6\xf70\x83\xaa\xfaU\x818\xb3\xcel\x87\xea\xb0\xa4\x89wm\x9b[\xe3\xc1\x87\xb48k\xd6\xe1\xad\x0f\xfa+\xd3\xaej\xe2\x87MR\x8f\x8a\xe9\xf27S\x86ZBqvi7d\xdc4\xdf\xdd\x98)\xb1?\xbc\xbc\x9f\xff\xff\xce\x0b\xf5{/\xe3-K\xb2\x8eS\xd0\x08\xe5\x12\xe1\xcb\x85\xfai\xb1\x8b\xa6V\xaf\xebX\xe7\xd1\x05W<\xbb5\x11DJh\xcc\xa7O\xaf+Q\x8aD\x1cYm\x02G\x89\xcc\n[5\x02\x1a\xaf\xf28\xe0D\xd8\xab\xd87\xbb\t\xa1\xc0\xb6\xfe{\x97\xaf\xe4g\xfe[o\xeb\x990\xdd\xfa:k\x97C)\x0b\xd4\x85\xcdd\n\xdd\x8c\x0c\xb1$A\xed\xf5\xbf\xe5Zl\xca\x85\x14\xa6\xdd\xb1\xee\x7f\x81\xde\x06\xa6q@\x7fe\xb9z\xf3/~-\x13[C\x01\xd1\x03\xe6\x16\x1bG.\xe6\x93Wa\xde\xae!H\x96c\x8b\xc1?\x94\x9b`}\x92\xeb\xcc\xbdi3+\x12~\x07\xf9\xf3\xa6\x15T\x1e\x87\xee\x916z\xf7\xffl1\x8f\x83\x1aZ?\xa2\xfdcW\x9f\xbf\xe5\xc3\x03\xbd\x8f\x12\xb6\xefvB\x9b\x9f\xa8\xbc\x10\xd6r:\xc67\xc8\x06d\xf13\xecq\xedM\xc2w\xf5\xc6\x96\xc0q\xfeu\x01\x86(x\x7f\x82\xb2\x89\xa7\xd7\xe1G\xa9\x1b\xce`\x89\xa5\xa5X\xeb8\x89"\xc0\x96\xb6jao\x0f\xee\x9c4\xe35\xcf\xcb3=\xdax\x92y\x87y\x03\xde\xa9\xac<\xfd\xbe\x91q\xed1\xce\xe5\xb2\xb1\xbf\xbe\xa4\xfc"\xc3\x05\x18)b\xa0\xec\xebY\x93\xe7\x1f*kJ\xca\xeb\x16\xe5q\xcb\xf87\xa5t\xf1\x08}\x06\xcb\xcd\x96\xb2iW\xa4\xca\xe4\xee\xb3P\xb6\x9d\x02evS\xb5\xeff\x81\x7f\xceu\x9c\x8e3O\xcf\xbf\x0e\xea\xc8\xc7s\xe07\xfdN\x99\xe2\xcft\xd8>z\x96}\xdd\xa5\xf2\xbe2e\xd4\xc6\x02\xb2\x15;`n\xc3U\xbe98q\x89\x93\x05\xd2\x85\tJj100\x1dTAK\xef\xc3\xec\x86\x12W\xean\x9f\xbf^P+n\x93\x8c\xde0\xb8#\xf0y\x04w\xba\x04\x85\x0b\x81g\xff\xff\xa1\xea\x04\x01u\x15>\x8fk\xf3l\xdf\xf9\x0e\x0bO\x99\xa6J\xcf%\xa4\xbf\xb4\x9a\xef\x1bf\xfc\xdaz\xf7-\xf6\xbb\xc5\xc5q\x87\x13\xf6\xec\x9fV^sv\xa6\xd6F\xdd\xe3\xf3\n\xc5\xf1\xa9d\x91i\x8e)k\x12\xe9\xb7\x0cn&\xa86\xd6\xf0\xa15X|\xae\x82\xd79\x95=\xf4\xca\x8c\xe4\x9f\x88X\xb9Y\xe6r\xa9\x9d\xe9d6z*\xa9JyY\xc44\x85\x8d\xe2-\x87W\x16\xe3@K\xf3\xe6\xe8T|\x07\x9d\xa16\xfa\xd8\x90\x1a\xc3\xb7w\x89\xc5q\x7f\x05\xeb\xcf\x1d\xc8\x17\x80)s\xfc\xee$\xce\xf7}6\xf9\xf5^\x15#A\xd1\x94\xc6\x9ej?\xd1\xe9\x89\x86\xe5\xe9;9b8\x94\xfc\xdf\x1b\x83\xeap\xfc\xd1\x03\xf2k\t\xebk\x10\xf4\xef\xa7\x1c\xf5\xbcu\x15R\xb8!.L\xa8\x95\xdd\xfag\x8b\x97+%TIA@\xa6\x8e\xa0a\x8a\xb7\xb5\x12&\x94~\x1b\xe8^\x8f}\xa5\xda\xa6C\x12\x99\xcfav>1\r\x9e\x87NEi\xff1;\xcf\x91\xd51;\xfe>\xc7~\x9d\xfa\xf4\tw\x8en\x16\xdb\xfa\xbf\xd0\xa4`1\xaa\x1c\xa8\x01P\xf5\xbd\xe2\x92u>J\x81\xf9LY\xe8e\xe8l\xd7S\x0fK\xadfK$\xdf\nW\x1e\xcf\x04R\x9f\xedw\xf1.\x8bW\xdf\x17\xe3\xba\xb0D\xa1\xa1q\xc2:\xb7k/\xfa\xfb\x8b\xc6\x12\x87hl\xc7(\xaf\xea\xba\x04\xce\xda\xb7J\xc7\xe0\xb55X\xd4R\xc1\xeb\x12\xe2\xafk\xd4W0Q@\xe3\xcb\xa6\x93\xa1\xed\xdc\xa7\x7f\x82\xbf\x9f\xcc6E\x8b\xefO\xba\x18\xcd|1\xcc\x18\xf8\xf6\xbe\x90\xb6,X]\xa6\xc1\xcd\xc7\xf5rd*\xaf\xb2\xeb\x10!u\xa3\xd0M\xe8^\x9e\x10[\xc2\xf4\xa2\xe7K\x16\n\xe2\x9em\x1a\xa4[yY\xde\xaf\xcc\x18\x9bn\\\xd2\xb2\xc6\x0cAg\xfa\xcb\xea\xa6\x12\x91\xf5>\x93r\x1a\xf5\xc1\xa3\xeaq\xc3\xd0\x86\xb2\xab\x9f\'\xd3\xee\xbd\xdd%\x97\xec\xce\xce[\x1f\x10\xe6x\xe3xpXc#WFuI\xbe\xf7\r\x8d\x12\xc8\x95\xb3\xcaj\xeb\xf3W=T\xd2\xcbZ\xe7\x8b\xefv\xd6\x8cWI\xfdSD\xadx\xfez\xcd\x8f\x8c\xbc\xcf6\x85-\xe6G_W%G\xd5i\re\x9c\'H\xfe\xe0H\xf7\xfeR\xbeK\xd8oD\xe1\x8a\xa6\xf8\x19\x9a5R^B\x10#ZB\xbc\x8c\xf0\xcaocc\x04bi\xfe\xd4\xb6i(\x14\x08\x08\xf7\xd0\xc6j\xe4\xc3eRJ\xb7\x13\x98\xa3\xb1\xbc\xa66\xe5t\x03\x9c\xe5\xf3T\xf39OBE\r\xbd\x93\xbd!\x97E\xbe\x86\x97H\x8b\x9dE\xf8F\xaf\xd2R@\xfc\x99\x16\x1b8u \xf6\xf4\xd3\xa2g\xe6\xbf\xbb\x8c\xc0\xe5w.\xfay\x87z\xeb\x17\xf4\x99\xc9\xb3%hH\xdf\xee\xaf\xdd\x95AD\x88m\xb4v\xcd\xf8\xf7E\x91\xc1\xf5\xd2x\x8f\x14\xa1ZT\x85m6\x97\xa6\xd9q\xb0\xb3\xf1\xd0\xa0\xf9S\x93w\xcb\xe9\xac\x1c\xb92\xe4\xdf\xdf\xe1\xde\x8dp\xb3 \x0b\x01q\xfc\xf9\xa4\xa2\xca2f\x90\xd5\xa4\x8c.\x7f+\xe9\x90\x01\x9aH\x11\xc7Y\xf6#\x18\xc9\x04\xde\x1b#\xed\xc4o1\xf3U\xde\x0f\xe7t\xa0C\xa0\x85\xa4\xee\xad\xd3\xffL\xf8 \xb5s\xfbx\x96_S\x7f\x9cK\x9af\x86[R\xe8V\xbay\x1e\xdf\xb6U\n\xb8Qn! Z\xa8\xe05Nd\x19\xb7,A+\xedH\xbc%\xe1\xa9\x08\xe2\xb9jeriz\xec\xe84\xc5d\x89*\xf8\xc4>\xb3yQ\rv\xfb\xfcj\x033\x1dD\xe6]+\x90\xb4\x00=\x82\x13\\\xf26,\xc1c\x9e\xf1\xc2\x06\xfb>Z\x1e\xdc\xa2 \xe8\xbcy\xd3\xb4\x96\x9fnc\x82\x8b\x1b!\\\xafk\xee\xd4\xaf\xa8\x89\x10\x0f\xa50\x16\x0b):P-\xf1\x03\x97\xe0H\xa2\xe6\xeb\xa3?69Db\xcd\x98\xe5\x866\xcem\xfa\xab\xcc\xca\x8d\xa6\xd6&|\xb3\x01\xa1\x0f\'\xf2v,\x95}+t\xaba\xbc\x15\xcc\xa7-\xec.\xb4q\x98\x7f\xce\xf1Y\xcb%\x95\xfb\xc1\xcdv\x89\x04e\xfa\x1fP\x18qNn\xd1S\x81\x8f\xad/\xf7\xdeg\xcd\x7f\r\x9b\xd5\xcd\xaa\x95\x9b-\x03\xda\xa1\xebUt5\xe7.\x93\xa8}\xed\xe0F\x9ds\xf1\x80\xee\xfc\xa2\xe8\x00\xf5U\xccG\xa9\xbd\xd0\xda\x10\x9b\x1a\x0f\xba\xc8\xd1\xe09HFuI\x05\x8c\xbe\x91\x01XP\xf0\xbe\xcb\xe9\xd4\xec\xd4&3rpj_\xc7\xa9\xdfBk\xd1\xf21#.\xfe5\x1a\x83\xde7\xd8}u\xca\xc7\xca\xf0Z\xe51\xdf\xe5\xfbi\xde\xfa\xc3\xe8\xdd\xb1\x08\x82(\xf7\x08V\n\xa9\x17Pd\xe50z\xc7\xb5g\xd8\xb9vr\xeaP\x91nd\xcez\xb8\xe4\xd1\xfdyt\xaaV\xed\xa28\r\xb9%\x053\xe4\xf1]\xd6\xbb\xda\x0e\x88\x82\xdf\xd8\x92\xcc\xd5\x17G\x9c\x14\xbf\xf38\x86\xd5T/Ey\x9f=Z\xa7\xfe\xd4\\\xc2j\xbb\x82\xd0\xa5\x1a\x18\xdd8zRv\xa5\xbd\xa0\x17\xdf\xdd\xc7\x17\xe9 \x91\xe5\xa0\xea\xfc\x11yG\xfe4\x9d\xb6\x88\xdfik\xf6\x04}\xb6\x95\x1fl\xb0BU\x0e\x90\x88\xea:h\xc9.\xf4D5$\xa2\xf3M\xeb\xd7f\xba\xc2VM\x12\xbb\xfa\xe7\xbcKY=\xd2ob\xf5\xc2"\xabr\x93\xa96\xe1\xf3{t"I\x10H\x18\x19{\x1f\xe7{k\x97\xd5\xd1\x91\x10\xa5\xe3\xe8\xb9[\xf1\xe7\xd9\x17k\xb6\xbfK\xee\xdb]\x96\xde\xdf\xb6,\x953\x07\xc8\xd3+\xbd\x9bx\x83\xef)\xf4\xd8)\x15\xb2\xe4\x9a\xa0C\x06\x1d-<\xb2]p\x97\xfen\xa6\xb7\xc8\xc3\xc4\xb2N\xeb\x9d\xfa\xc5$\xbc\x0f&Cc\x82"#B\x9f\x08\x02\tv\xbe\x7f\xcdt=\x07\xa5y\xe2r\xb9#\xb7\x84\xa9\x021\xa0\x12\x87\x7f&+%\xfc\xc4Fu1M6\x89%\x19\\l;lB\xe1\xf3\x1frEvw\x82J\xc3\x001V\xddB\xcek/)$\x90\xa6\x15e\x143e`\xdc\x16\xa9J\xbdP\xff\xe8\xf8mKWgl\xb1\xd74\x16\x96\x00\xb0`Ev\xf5\xfa\xacw\x8e\xc8\xcd\xcd|\x83F\x8eniQp\x06\xe3\xd3$=/3\xa9^\xa5P\t\xd5\xbc\x92\x88P\x89\x13\x92;\xfbuG\x075\x97T\x99\xdc\x9d`\xeb\x9c$\x02I\xe5\xeb\x83m\x88\xad\xb3rK\xe0\n\xeei\xe8\xb8\xa4\xbc&\xfdb>\xbb43\xdb\x8c\xee\xeb\x0bx\xb24\xb2\xd0\xf6\x18\xac\xe0\x9d\x1f\xd1\xbdV\xa7\xfb\xa5u<\xf0\xb5\x94\x0f\xc7URK\xf0\xce${\x96Typ?G&\xbe\xce\xf7\x00+\x12I\x9c\xf4<`\xb8K\xc1\x95\xcbe\xce\x8bu\xff}QT9X\x9717{`\xef\xfc.\xd4,\x1b<\x17\xee\x12\x9a\xc8\xf4;\xd3\xf9e\xa6\x8c\x83\xba\x88LH|%<\xb8m\x8dZ\xbe\x01H\x98\x9c"\xde\x98\x0fy\xa2\'\xd1\xfd\xbf\x0bc\x8cg\x9a\xfe\xfb6\x13\x0e*HVXf5\t\xd6\x0b\x9cv\xb8\xdc\xd8\xa9]\xb7\xc7\xcc\xe7\x86w\xfd?\x8a\x05G|\x880\xfeBT\x8fH\xc5(x\xb9\xa5\xd8\xe1\x1c\xeb\xce\xa6N!T\xd2\xe4\x87\xddp\xee\xc8|\xb8\xb7\xc3L\x92x\xf7\xb5\xa9\\\xe6_M\xb2\xc7\xfe\xd4L&0\xafL\xfe\x15*8\x9dr\x84s\xde\xd3\xcf\xfdJKb\x98\xb1\xf7\x1f\xfbAW\xa4\xab? \xbf\xb6\x0f\xb2:\x1e/\xe6\x8b\\\xbc\x14A&D\x84^\x08\x02\xc7\x1f\xf8\x87<K\xb0\xfdih\xfa\xf9\x7fYt\xa3\xd9\xbb\xdb\x07Y\xffn3P\x9d\t\xcd\x8e\x98\xe3\xd3\xb6\x0b\xabZ\x89q\xe97\x83n\xe2#:kgE\xa9\x8d\xdc\xb7\x9e@@)Z\xc6=\x15\'J\x97PH\x7f\xa9\xc3\xe6\xc8\x7f\x0b\xccxP>\x1c\xa4v\x1f:\xc5kK\x1d\x04\xc7\xbf\xd0e\x93\xf8\xff?\x0b3\x7fd\x9f\xf9\xd0#W\xcfQ\xcb\xe9\xb8\xab\x99\xf0.\xdb!\xadQ`{\xdd=\xa0\xb4d?\x8cjM\xbf\xf1H\x9b\x1e\xab#a\x91\xc4G\xef\x9en\xa7\xe6&D\xacM\xf8\xac\x02\xab1\xe5\xd2\xae\xbd"\x15\xa4s\x13!\xba\xad\xe8\xba\xa2\xf2/\x0e\xe2\xf9\xd9\x17^\xac\xad0\xdb\xfb\xfb:\xbb\xf9\x0e\x9e\xf3\xd1\x95\x0bY\xa2\x8c\xc0\x901\xef\xe0\xd6\xa9p\xfa\xe5\xf4\xdd\xd9$v\xf7\xefdI\xae%\xac\xaf\x96\n\x17(d\xcfl\xc0ol\xce\xa5k\xae\xc9V7@\xac9\xd1\x91\x84\xfb80\xc88S>\xaf\x84\xcc\x01\x1fVG\xd7\xf5Z\x01L\xc5\xb71\x81S\xda\xb5\xfa\xdc\xc2W\xbat\x87\xb1\xa8\xb5\xa0\xf8\x14\x93\xfdw\x94/\xeavm\x842\x12\x96\xc4\xe7\\\xbe\x03\x8e\xba\xa83\xb5+6\xa4i\xd1{g\x95\xf5y\xfe\xe4\xe0\xa2\x9e\xa9\xed\x17\xd9\xce2\xe7\xb5%\xbb]\xbf\x86)\x85\xf6F\x87y7\xf1u\x04f:7W\xf3A\x84 p\xbc\xbap\xc5\xd1n\xa7\x84um-\nm\x8e\x9a\xc0&\xcf \xfd\xfa\xb3\'\xbeU\xd31H\xb2\x81\xf1\xa9\xef[\xb9F"H\x81R\xc2\xc5\xf1YN\xa7\xd8\xc0Ro1Bt\x7f\xf2sF mx*O\x84+w\xae2M\x80\xed\xe4T\x06\xf7\xee28\x1bl\x1f\x1e>\x04\x8b\x16\x88\x8d\xbd5\x9dIb\xdb\x1f\x0f\xde8\x86\xa8\xab\x1b\x02\x1f\xd4Tz"g\x92[\x07\x1d/\x93\x07\xd8n\xf5\xecOHf\xf9TS\x98\x02\xea\xcd\x86R\x95\xaf)\xe2\xeb\xe4\xba\xceR\xeb\xd7\xb71\xf3\xb9\n\xd3aqE\x80\x83nb\xb1\xf3\x9a_\xe7\x8c\xec\x9f(\x05\xdcd(I\xb6X\xea\xc0pz\xb8y\xbc\x11\xe4y\xe7;\xeb d\x8a\xd2?O\xf5{\x97\xf19\xe7\x9aS\xd8"\xac\xa2\xe5\xa9\xc5B\xa6s\x88WXt\x98g\x879\xee/~\xf0*OD\'[\xd6\xe4j\xff\x99Y\x8c\t\x0c\xf3kY!Y\xe7\xd8\x93\x839P\xc4\xe2%\xbc\x0b^l\xd0h\xca\xe0\xee\x83\x11/\xe5/b\xad!\x92x[\xf4?(\x94\x05\xe4\xc8)\x15~\xd79A2-Z\xc1DY7\xeb\xa1\xbd\x9f\xfdt\x92C\xb1\x8b\xc4%\xd9G\xf0\xd8\x8b\x8dF\x84\xd4U\xeeJ\x8e\xfef\x978\xd2H\xde-\xd3\xdc\xd0j\xad\xa6\xe8\xa0\x04Z\xa5\xd1\x07\x1b\xf4Q4{\xd7 \xe5\xda[5{rA\xba\x81s\xb9\xbc\x1f\xa9D\xdf\xa6\xf2\xc9\x8b\xb8\xcb8\xf5\x9bEQs\xcd6\xef\xf0\x89\x1b?\xb2\xae\x0b\x01GE\x94Ij\xe7\x89M\x91\x93\x92\xbf\x7f\xe9e\x9f\x05\xe297^\x08g}\xc56\xf9QD\x87A\xca\x9f\x10\xac\xe8?\xdd{\xca\xd3\xa4\x99\xef\xea\x98\x81\n\xfa\x0e8\xea\xbb\x13\x82O6\xfd\x1a\xd5?\x97\xd2\xa59\x99m\xad\xa3\x8a+\xd6<\xe7\xa5\xff\xd0o\x16\x92I\x89J`\x86\'f*\xdciy\xe2\xda\x8fX]\x14;<\xc4 vB&?\xe6\x16\x02\x8e\x96,\xe1R\xcdFk\xa1\t\xf65\xcb\x07\x18\xd1\t\x9b\x07\x8a>\xcc}\xebj-\xd6l\xcaR\x1f\xd0\xfd\x9d\xa3\xa7q$\x82\x9dc\x1e<\xf2+J\xdb\xe4\x90|\xe2\x14-K\x83\xb3\xfd\xa0\xf9\xe7\xe4\x1eoN\xcc\x19\xbe\x84\xaf\xb4\x18\r\xdb\xbdr\xed\x7f3\x19uKJ\x14k\xd5\xd2\xd4\x04\x7f\x9d\xa3\x80F\x9a\xcdP\x8fM?QG\xa7\xea\xe9pz>\xf5\x8c\x01c\x1f\xc5\xa0\xf8\xcc\xcf=\x02\x93m\xf5\xc8\xb8\x03\x8f\x93\xad\xea#x\xedaSI\xcb\x9a>\xabWGA\r\xab\x99\x08c\xf4\x82\x88\x9dm\x89\x85\xcdD\x1bK\x8c\xafx\x17\xb3\xe6\xc6\xf2.D#\xc1\x10p\xe5c\xca\xc8\x9aM\n\xa2\x13\xa9c\xbf\xbdP$\x924c\xc3\xf7\xb5\'k\xfd\x102/1;\xbf\t\xbc\x8f\x90\xa6q\xfeEo\xf4\x9cy\x88\xe9\x08\xd3w\xf8\x17\xebn\xa1\n\x1f\xc1X)m\xef\xf8m,-ec%\x7f\xc3\xf2\xa0\xf3\xcag_K\x9d\xa2Y\x86\x11N{zxfe\xc6\x90\xfe\xc4\xec\xbb\x12\x03\x05CTY\xcd\xc4\x8eC\xb0\t\xdd\xe9\x95>k\xa1\xd6\x11\x1d\xc7\xd1\x94y\x08\x95\n\x10\xc9S\xa4\xd1\x81MA\xfa\x95\xb98\xcb\x831_\\\xf5\x89\xbc\xf8!Isp\xac\xc2a\xf0\xfa\xd9d\xc2H\xda\xdc\xb0\xc0]\xfd[l\xdf\x1e\xd9\xd9\x16\x8b\x9e\xe2\x18\xc4\xb4\x14\\\xf0vin\xd7\xf9\x9dD\r\x10\x11x\x1d/\xf5;T\x1d\xc5\xbd\xefC\xf7T\xd2\xaas\xcaV\xcb%\x84?\xd8\x90\xcd\xc9\x9a\'\xcd:\xe3\xe7\xae\xeb8\xfad-\xbb\xd5\xdc6\x95\xeaE\xadS\\\x90\xba\\\x0e\xb4\x00TY\xb5hk\x00\xb8~H\xff\xce/\x9a\x15\xdb\x8e\xbd<\xfe\x0cA\x88\x0cC&l\xaa\x02g\xc61\x8d\xde>3qeR~j\x11i)x\x03\xee\xe0\xe9\xbb\x8d\x8e\xcaWd\xb4\xf1Z\x89\x97\x1bZ\x1b\x18\x07!\xfb\xc5\x1b\x06\xc0\x85\x93n@\xbdD\tA1\xe52\xaem\x8f}\xa2\xd3\x85\x1b\xed\x89\xa9\x9d&\xc2\x8e\x84\xe5@X \x92\xeeu\xa7Y\xa3*\xb7\xe2f\xcfQ\x10\xa1z\xf0=\xf4\xdf\xc1\x0eS4:\xa9\xda\x11\xe5\xf9\xf4\xe0\x93 p\xd4){\x86y\xfb\x9f\xb0\xbfn\x92\xd3O\r\xb4b\xf3\xcd\xd3\xb1\xf1\xf2\xde\xfa.\x99\xd5\x199Rh"\xed\'\xdc\xfd\x90\xd8\xbc%\xd9\xed\xfbHd\xbf\xe4\x89\x9a\xad\x14k\x9cBq\xfen\xaccp?\xcd\x13\xb0F\xc8Wn\x071-\xbc\xa1\xf5\xf0\x05\xe7\xdd\xdc\x1c\x99Wi|\xf5u\xf3\xbc\x13\x0b\x8f\xf8\xafr\xbeb\xaa$\x0c\xae\x02\x7f\xe9\xb3\x14\xfbm\xa1\x99\xd9D\x87\xc9j\x0bgfykx\x1a\x92r\xb7\x88\xe4\xea\xa9\xc9\xb3|\xbf\xc5R\xf6J\xb6\xado\x8ai\x82\x00+U?\xcb\xafS\xb8\xd5\xc3\xca7\xf9F\xfc\x8c\xf2d\xd1\xff\xf3\xde\xcf\xd0\xd1?\xc6\xe7S\xa73}\xeeI\x82\x96b\xa9\xefd\xfeo\xa9\x11p\\\x15I\x91\x15?\x1d\xe0X\x91\xda\x92i\xcb\x86\x81\x91e\xc7\x04"\x07\xdbi\xa3\x12C\x19\x15.\x7fq!\xf9\xe8\xe2\xdb\xd4\x8cdI\xe0\x88L&\x99.\x16\x0c\xbb\x87\xf3\xf3\xec\xd2Pmy\xfc\xea\x8d:\x97U\xd2\x8d1\x93\xf3W\xcd\xc6\xa1t\x9e[\xf6\\\xb7\xe0\x9cc\xd8\xfe\x88;\xb8\xfel\xaa\xbf\x13R>d2\xda5\x95\xfek\xf3\xc5\te8,+\x91H:\xeaV(\xd7\x8f;\x82\xa6Z\xbba\x9c\x95\xb1\xb8"\x9f\x92\xb7\xb9\xaa\x87\x1f\x84\xb2\x9c\xafHP=\xbb`\xd9>\x1d{\xf8\x19\xe6\xbb\x03\x94`\\\x7f"\r\xb3e_\x15\xee\xd9\xe2\xbc\xb0\xc0\xb9\x10\x0bB\xa8\x06\xb7\xd1$*o\xc4/\xc1]\xa0\xb0&\xec(\xb3q5\xf8\xe3dQ\x0f\xa9Is\x12\xc3\xd5\xcc\xcer\x87\x06\xc2@\x03\x92\x86\x84\xfe\x18\xd9i\x00\xd1\xa9\xfa\x9cNu\xb1\xf4\xbdu\xd4\x1fJ\xbe\x97\xfb\x9c\x9e\xf6\x1e\xc7\xa0,\x9c\xc3\xbfA\xdd\xac\x8c\x0e\xd7\xd3\xd2\xa1o\'[\x93"\xa0\xea1\xb7\x01\xe1\x0e\xbc\xb8\x90`-\xbe~\x9c\xfdXL\xfe\xf1\x15e\xe7\x94\xbe\x96S\xbf\xc0\x9f\x85\xc4\x11%\x10\x19\x91vZ3\x9c\x91\x85}\xc7\x8a\xf0{\x81\xb4hX\xc0zh\x94wSC\x0b;\x8b8\x04\xc4{W\xd9z\x16i\xee.YZ\xd9\xac[\x02\xc2@M\x89\xac\\\\\x04T\x9d\x8d\x07`xH\xa1Z\x8b\xf5\xd9c\xc5\xae\x80\xb9\xc0\xacR\xd1\x96Ab~k6h\xf7\x8c\xc5\x87\x11`\xacp\xc6\xe0\xb8\xe1\xb7\xcfg\x00\x97\xf3}\x84\x9a\xf6Yc]\x08N\xb4\x9a\x82\xf1\xb1\x06\xd3)\xed\xbc;_\xad[4\xd1\x0e\x0be\xf7\xb7\x93\xc9t\xae\xaf<\xc6*\xdf\xfc7d\xbf\x16\x9f`\x01q\x97\x03\x16H%\xdd\x132\xc2\x04\xc7\xba% \x8d\xb2\xd6\x1e\xc9\xe1\xdc,\xd6<_\xe9\x8a\x83\xc9\x91\x05j\xc74\xcb(0\x8d\x05\xff~0\xc5\xd9\x05\xb4\xb8\x93\xfb\x0c,>\xcb\xecy\xa0\xf1T\x1cL\xfe\xbf\xddz\xa2^IHPG\xeb\xb2\x85Y[\x16\xb5\x1e\xb0\x95\xd4\xaf\x05d\x92\xa5vPC]T\x7f)\x97e\x1d\xf8\x95\t\xf4{\xccEc\x86\xfaCw\xf5\xbf\xe4_3B\x1a\x1e\x07\x1a%\x8f\r8\xce\x9c\x16\xcf\xe6\xb4\x9d\xd0\x98)\xb3\x16\xa6\x07-q\x97Ui\xab\xec\x16\xd8\xa028H\xfd\x11\x0c\xf7[\xf3\xf7u!|b\xc3\xee|\xf5\xd4Q\xb1\xcd]\xd9^%-\x97~\x10*u\x0c\x18\xd9O_\x8d?\xf9\xb1}Y\xa0\xbe?\xc1|\x97:\xf2fzC\x05A\x0c\'\x9d\x9f1\x98\xee\x95!\x9e\x18tY7\x9cA)\x14\xa2\xd9\x894\x94\xdc3y\xfe\xa5\xd2\xb7\x16\x9a\xaa|\xfd\xcc\xa2\xa9a\xb6\x11\xf4\xba\x00 X\xd6\x19f\\\xd3\x89\x17kc)\x1dw\xabz\xb4\xf9T\x11\xd3\xe8P\xd2\x0f\xfam\x00D\xd06\x88I\xb8k\x8f,\xb8mLc\xb7Uw\x9b\xbcKJ\xd4\xdc0b\xea\xf8x\xceb\xa9\xc6\xd2\x9ci#JU!6\xb6Yu5\xa30EY\xa5\x82J=\x13\x95("\x19\xd0\xbb\xa9)\xa2\x01\x1f\xf4\xb5\xf48\xe6xx\xfbd\x1b\xffp\x90\xbe\x17[x\xcc\x1f\x9dJ\xc2\xc7\x93{\xc8A\xbal\xea\x062\x14\xa43\x81\x8f\x0c\xd7\x1c~\x96\x86k\xb3\x85\xd7M\x95S\xb9\xc5\xb4\x15\x0eDK\xce\xce\xc3\n\x0c\x80\x88\xa0\x9b\x83L\xfa&\xe6k\x18\xa3S\xca(\x1b\x1a\xab\xda\xcc\xa7\n\xe4d\x9d\x86\x95\x9cqE\x16D6O\x15Dv>\xf8Z\x19\xee=\xca+\xb4\xddv\x08X\xea\x18U\x7f%\xf5\x15\xf5\xce\xfd\x92/k\xc4/\xfa\x1a\xe1\xd3&\r\x8e/\x028\x19\xe9js\xc1;\xdf\x04\xecl\x7fX\x88\xbb\x92\x9by\x99\xec\xab\x93\x9e\x10\xff/\xea\x95+u\x1b\x00\x11\xb3\xf4\x97}\x13\xd2b\xdco\xc3\xb1\x95\xd3i\r\xb7?h\xcb7\xc0\xaf\xa3;\xcfb\xeb\x90\x8eUp\xb2\x96\x9f\xc1\xa8\x1e\xf6\x0en\xed$\xd4LJ6\x17\xdfzu#I!Yz\x86/D\'\xe6\x0c\xe5\xe8z3\xe6%\xf7\xb1 \xb0\n\x1a\x91I\xf5A\xda\x92\xf6\xa2v\xa5\xae\x1e[\xb2\xf1l#\xdb_k\x97k\x15\x9c\xdbej\xf7D#\xd9&\r\x10\xb9\xce\x9e7\x15\xeeZ\x16\xb2\xa3\xeaJ\x91[!v\xf6\xf9\xda\\\xd4\x0e%\xdaH\x16\x97!]%\x0fcK\x12\xf6\xfe\xa0\xf4\xfd\xbdc*\xe7-\x9b\x8a\x11\x9c\x82\xf6W\x8b\xed\x93Sc\xf1u\xaa\xc2\xe9\xb9t\x19P\xb5\x1a\x08\x1a\x1bc|\x90(\xb8\xcf\xf8\xfc\x8aw\xad\x04\xba\x91[\xd5t"\xb6\x16u\x1b\x0eI\xdd\xcb\xf0\x9d\xa4\xe1\x0c\x01\xe8\xd6\x92\xed\xda\xfe;7\xb7(t4\xb6;\xb1\x9f\x84+*\x83\xf0\xe3G1\xcb/\xcf\xef\xea\xe8\xd1I\xa3\xe0q\xde\xc1\xf2?\x0e\xea\xc8{\x01\xab(\xa38\x84\x91\x9c\xd5D\xf1 \x90K#\x03\xcb.i:\xa1\xe5\xf3\xc3\xe2\xfb\xe6\x93\xda3F\xd7\xa5\x91\xf6\xa3\xad\x89\xbd\xedw\xe2\x87\xe3\xdc&fZ\x1b\xcb\xbb\xd5\x1cm\x9c\x1c\xed\xa9U<\xef\x16\xc6\'\xa6jZvj\xd7\xff\x1ex\x11\x1afX\xf7\x1c:\xe9\xf0\x04\xa5\xc2}\xac\xe1\xb6L\x86\xc0\x0e17W\x7f\x8d9K\xb5;\xd4L.\xb7\xa8t\x1da\x8a/\t8p\xfa \xc7\x17\\5\xbe\xa7\xc5P\xf5\xfesZL\xbfc\x878\x1b\x86\x0b\xc4\x882\x02\xdc\xd3\x01\xf7\x9c\x07\x8a&\x1a[\x9c~_\xf3\xfa\x9e\xe9X1\xf1V]\xfd\x0f4\x1c.\x9b\x1fv\xe5>3%\xb8\xb8\x8d\xa3\xd7\xdf\xfc\xd8%\xddD\xaf\x93%\'\x82aKs\xb8\xbf"\x1a|\xcc[\x87\xbe\x03g\xa6\xfd\x8bR\x9b}" y\x9a\xdeH!\xa4\xdc;\x91\xd9B\xd5\x1a\x93\xe2\x9b6\xf1\xa2\xdc#U\x12%W\xbe\x16\xad\xe5P\x02\x0f\xe0\x8c\x06C\xd43bq\xd9\xd6\x8b\tS\x8fv\x8d\xd8+\x89g-\xdb\xc7m\x86\xa30\x11\x81\x9e\xc1\xc8\xc0\x03E\x89yV\xbf\xbe\xe2\xecx\xf6M\xd0\x15\x03\x00\x91\xce.\xe7\x81\xd5W\xd5LW\x8c\x0fn%\x07R\x01\x1d\x94\x81\xf4\xcd\xff\'\x91\xf4~?\xac\x07\xa7l\xda.\x15\xe6\x16\xe5t\xa5\'\x8d($\xfff\x85\xb6\xadR\xc9\xc96\xbc\x0c)\xb3\r\xaf:+\xaf8%\xb0\xe2\\\x90\x86-\x93\xe6\xf6mV\x8c\x80h\xb6\xd2H\xb5T\x08\t\xab\x0cN\x7f3:\xaa\xfe\x80|v*\x8bW\xad\xe6\xa12\xce\xfao\x9f4xd!@B\xb33\xf6E\x7f\x1fh\xed\xaa\xda\x96Y\xf8\xccP\xd7\xdf\xa7o\x8bMU&}v\x84m\x93\x8d\xbf\xbbH\xe5\x87\xaa\x92B\x02m\xf4j\x85\x9d\xe3O8\xe8\xf8\xe2\xf3]7tr\xf5\xba\x8e5}\x7fv\nH\xbf<L\xd2]v/\x9b\xd5\xddu\xd9\xc2t\xaf2t\xab\x83?W\xda\xa4\xcd\xc9\x03\xfd\x19)\xa0\xde\x0f3Y)\xae\xde\xd8do\xf2\x8d\xdc\xa9V4\x81R\x95y\x16p\x0b\x02z\x0b\xdc\xf9\x14\xd6X\xdf\x1fh\xe4Y\x8b6\x1a\xdb<\x80\xaf\x0b\x9cS\x03\x01\xff\x14\x00[\xa5\xf7T~\x04\xf4h\xfd\tn\xfa\xe8\x1e3Y\xc0?j\xa8\xcb\n\t\xba\x04J\x9b\x1d\x89\x07\x896\x0fa\xa2P\x1fq\x03SF\xc0\x167\xb0\x16!\xceR\x12\x8f\x1d0\xf6\xf6\xaa\xdc9\xe5\x1a\xe0\xf9XN\xde\x0cd\x95\xb8\xa2zVeE\xef\xeemZ}?\x19\xbe\x95\xd8B\xab\x12V\x07\xf4!z\x93\xe8[\xf2\xc3%\xb7S\xaf\x81>\x87\xe7\xa6\xf4k\xf62\xe2!T\xce\x8f\xb7\x81\xfeJ8\xf6y\x8f\x03*\xa3\xf1\x99\xbb\xf9\xbbv\x05.\x82\x80\xfe\x8d\xcc\x1d\xb6|\xdc\x1d\xc0\x17-\xdcpB#\xc8C\x03\x8b\x19D\x18\x00u\xd3\xcb|*\x99\x92\x0e\t\xe79M\x935m\xca\x0c\x98\xa4\xeeB{\xd4\x94,\x0c\x00\xeb\xdfJ\x11\xcf\xdba=\xbf\xe2\x00+]\tr\xf3\x9a\x97\x0f\xd3\x90\\\x7f\xc5\x0c\xa2\xc3\xb48\x92\xa8C\xc5\x02\x1a&<%\xc7%\xea\xe8\xf8\xf1\x87\xbc\t\xd5s\xfa4\x8a\xe4\xe0\x96\x02F\xd5\x800\xf8\xe7@*\xe7\xc7]h\x8dS=n\x129\xa3#\x86\xc1N\xd7o\x81T\xe2\xdb\x89j\x9f\xdb\x06L\x9c\x9ej\x9e\nkrW\xed\x94\xac\x01\x89*\xbb\t>\'\x1f\xd6\xf3\xe5\x07\xc5E\xa8\x04\x89\xfad)_\x97\xe1\xc56)*\xab\x8c\xb6\xd91\xfbn\x8a}&Yr\xc2m\xc0\x92\xe5\xeb\xa1\x1e\xb2z\x07\xf0\xcd\xd9\xb9\xcb~mh\xc3\x08\xd8\xc2\x96#\x9bq:\xf6\x0f\xce\x03JX\xf8\xf0\xe4FzP\xb4)\x04\xbeU\nd\xdc\xe7\xb6hZuc&Ke\xda\xb5\xdb\x8c\x7fV>KUH\xee\xa8\xa2\xda=Lz\xff\x87\xa8\xd6\xc3T\xc3\xea\xc3\xdb\xc7\xf4\x99\xa0j\x87\x9d\xe9\xba\xeate\x16\xf2\xde\xfeq\xef\x90\xaaMX\xed\xbb\x0f\x9c*\xad\x05\xbf\xe9\x88y\xdd7\xf0e\x04l\x95\xd5\x83\xee\x93\xa3\x05\xb6\x08ZG,\xb6o\x80\xe8\xd7\xccRN\xfd\t\xc4\xadq\xcc\x13\xf7\xe4\xa4,PB\xc7E\xdd?\xb6\x9a6\xf1jv\xb1i\xe8o\x04R\xc5Tb8\xea\xff&\x91\xe6E\xee\xa5t\x9c:_\x07Q\xf2\xca\xa6\xfd\x1f\xd7\xb3W\xe4\xc8vn=!mG\'m"\x9e&\xd1U\xc6\xd6\xbaodC\x83\x18\xacSa\xc6\x8f\x8c\x7f\xfc\xcc\x16\x98\x08\x82\xd5/4\xdc\xa6\x1ex\xc4A\xcc>Q?~r\xd1!K#~\x00/\xb3\x17\x99O\x9eiT\xe6\xfe\xb8\x0f\xa7\x8a\xe0\xf5\xc3\x9d\x9f-\xff\xbbO\xfc\xbaJ\x95\xfb\x1d\xe0\x80I\xbc^\xd5V\xbc\xfc!\t\xdd7\xaf}\x8d8\xcd\x91\x87\xc9O\xdd\xa8\xe9\xd8:A\x03\x01#e\xd8\xaeoW\xb09\xde\x89\xea\xd1\xa0t\xde\x8a+\x1f1\x8b\xaaya/|\x87=7\x89\xaaf39\x89N\xcd}\x08<\xab\xba\xab\xbdP\xadV~\xf5\x11'


class ChatBubble(QFrame):
    def __init__(self, text: str = "", sender: str = "", is_user: bool = True, loading: bool = False,
                 use_custom_wrap: bool = False, minimum_width: int = 200, maximum_width: int = 400,
                 no_ui: bool = False):
        super().__init__()
        self.text = text
        self.sender = sender
        self.is_user = is_user

        self.loading = loading
        self.loadingAnimation = None

        self.use_custom_wrap = use_custom_wrap
        self.minimum_width = minimum_width
        self.maximum_width = maximum_width

        if not no_ui:
            self.textLabel: QLabel = None
            self.loadingLabel: QLabel = None
            self.loadingLayout: QHBoxLayout = None
            self.loadingFrame: QFrame = None
            self.init_ui()
            self.update_text(text)

    @staticmethod
    def ready_text(text: str, limit: int) -> str:
        # Function to format the text to wrap at the character limit
        if not text or limit <= 0:
            return ""

        words = text.split()
        wrapped_text = ""
        line_length = 0

        for word in words:
            if len(word) > limit:
                # If the word itself exceeds the limit, split the word
                if line_length > 0:
                    wrapped_text += '\n'  # Start a new line if there is already text
                    line_length = 0

                while len(word) > limit:
                    wrapped_text += word[:limit] + '\n'
                    word = word[limit:]

                # Add the remaining part of the word to the line
                wrapped_text += word + ' '
                line_length = len(word) + 1
            elif line_length + len(word) <= limit:
                # Add the word to the current line
                wrapped_text += word + ' '
                line_length += len(word) + 1
            else:
                # Start a new line if the word doesn't fit
                wrapped_text += '\n' + word + ' '
                line_length = len(word) + 1

        return wrapped_text  # .strip()

    def calculate_char_limit(self):
        metrics = QFontMetrics(self.font())
        average_char_width = metrics.averageCharWidth()
        parent_width = max(self.minimum_width,
                           min(self.maximum_width,
                               self.parentWidget().width() if self.parentWidget() else self.width()
                               ))
        return max(10, parent_width // average_char_width)

    def update_text(self, text: str):
        finished_text = text
        if self.use_custom_wrap:
            # Calculate character limit based on current width
            char_limit = self.calculate_char_limit()
            finished_text = self.ready_text(text, char_limit)
        self.textLabel.setText(finished_text)

    def init_ui(self):
        layout = QVBoxLayout()

        info_label = QLabel(f"{self.sender} - {QDateTime.currentDateTime().toString('hh:mm:ss')}")
        info_label.setStyleSheet("font-size: 8pt; color: gray;")

        self.textLabel = QLabel()
        if not self.use_custom_wrap:
            self.textLabel.setWordWrap(True)
        self.textLabel.setStyleSheet("background-color: transparent;")

        self.setMinimumWidth(self.minimum_width)
        self.setMaximumWidth(self.maximum_width)

        # Update size policy to prefer minimum space but allow expansion
        self.textLabel.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.MinimumExpanding)
        self.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Minimum)
        self.textLabel.setContentsMargins(5, 5, 5, 5)

        layout.addWidget(info_label)
        layout.addWidget(self.textLabel)
        layout.setSpacing(4)
        layout.setContentsMargins(10, 5, 10, 5)

        if self.loading:
            self.textLabel.hide()
            # Setup for loading animation
            self.loadingFrame = QFrame(self)
            loadingLabel = QLabel(self)
            decompressed_data = brotli.decompress(LOADING_ANIM)

            # Create a QBuffer from the decompressed data
            buffer = QBuffer()
            buffer.setData(QByteArray(decompressed_data))
            buffer.open(QBuffer.ReadOnly)

            # Use the buffer with QMovie
            self.loadingAnimation = QMovie()
            self.loadingAnimation.setCacheMode(QMovie.CacheMode.CacheAll)
            self.loadingAnimation.setDevice(buffer)
            self.loadingAnimation.setScaledSize(QSize(128, 128))
            loadingLabel.setMovie(self.loadingAnimation)
            loadingLabel.setFixedSize(QSize(120, 80))
            loadingLayout = QHBoxLayout(self.loadingFrame)
            loadingLayout.addStretch(1)
            loadingLayout.addWidget(loadingLabel, alignment=Qt.AlignmentFlag.AlignCenter)  # Center horizontally
            loadingLayout.addStretch(2)
            layout.addWidget(self.loadingFrame)
            self.loadingAnimation.start()

        if self.is_user:
            layout.setAlignment(Qt.AlignmentFlag.AlignRight)
            self.setStyleSheet("background-color: lightgreen; border-radius: 10px; border-bottom-right-radius: 0px;")
            self.textLabel.setAlignment(Qt.AlignmentFlag.AlignRight)
            info_label.setAlignment(Qt.AlignmentFlag.AlignRight)
        else:
            layout.setAlignment(Qt.AlignmentFlag.AlignLeft)
            self.setStyleSheet("background-color: lightblue; border-radius: 10px; border-bottom-left-radius: 0px;")
            self.textLabel.setAlignment(Qt.AlignmentFlag.AlignLeft)
            info_label.setAlignment(Qt.AlignmentFlag.AlignLeft)
        self.setLayout(layout)

    def update_content(self, new_text):
        # Call this method to update text and stop loading animation
        if not self.textLabel.isVisible():
            self.textLabel.show()
            self.loadingAnimation.stop()
            if self.loadingFrame:
                self.loadingFrame.hide()
                self.layout().removeWidget(self.loadingFrame)
                self.loadingFrame.deleteLater()
                self.loadingFrame = None

        self.text = new_text
        self.update_text(self.text)

    def resizeEvent(self, event: QResizeEvent) -> None:
        self.update_text(self.text)
        return super().resizeEvent(event)


class MDChatBubble(ChatBubble):
    def __init__(self, text: str = "", sender: str = "", is_user: bool = True, loading: bool = False,
                 minimum_width: int = 200, maximum_width: int = 400, width_offset: int = 15, no_ui: bool = False):
        super().__init__(text, sender, is_user, loading, False, minimum_width, maximum_width, True)
        self.width_offset = width_offset

        if not no_ui:
            self.textLabel = self.loadingLabel = None
            self.init_ui()
            self.update_text(text)

    def update_text(self, text: str):
        # Calculate character limit based on current width
        char_limit = self.calculate_char_limit()
        wrapped_text = self.ready_text(text, char_limit)
        # Save Markdown to a temporary file
        temp_file, temp_path = tempfile.mkstemp(suffix='.md')  # Creates a temp file
        with os.fdopen(temp_file, 'w') as file:
            file.write(wrapped_text)
        # Create a QUrl and load it into QTextBrowser
        url = QUrl.fromLocalFile(temp_path)
        self.textLabel.setSource(url)
        char_height = self.calculate_char_height(wrapped_text)
        self.textLabel.setFixedHeight(char_height)

    @staticmethod
    def interpolate(value, x_points, y_points):
        # Ensure the value is within the bounds of the x_points
        if value <= min(x_points):
            return y_points[0]
        if value >= max(x_points):
            return y_points[-1]

        # Find the interval the value falls into
        for i in range(len(x_points) - 1):
            if x_points[i] <= value <= x_points[i + 1]:
                # Perform linear interpolation
                x0, y0 = x_points[i], y_points[i]
                x1, y1 = x_points[i + 1], y_points[i + 1]
                return y0 + (y1 - y0) * (value - x0) / (x1 - x0)

    def calculate_char_height(self, text):
        metrics = QFontMetrics(self.font())
        char_height = metrics.height()
        line_count = len(text.split("\n"))
        print(text.split("\n"))
        # (lines * char_height) + ((3.201449 + (3.290262 - 3.201449)/(1 + (lines/527.4672)**3.500717))
        x_points = [1, 2, 3, 6, 11, 17, 23, 28, 56, 278, 556, 2778, 5556, 11111, 16667, 22223]
        y_points = [11, 4, 8, 4, 5.1, 3.3, 3.3, 3.3, 3.29, 3.25, 3.21, 3.203, 3.201, 3.2019, 3.2002, 3.20007]

        multiplier = self.interpolate(line_count, x_points, y_points)
        print(multiplier, line_count)
        return max(20, (line_count * char_height) + (multiplier * line_count))  # (5.36 * lines -> 1000)  (1.112 ** lines -> 100)  (lines ** 1.2702 --> 1000)

    def init_ui(self):
        layout = QVBoxLayout()

        info_label = QLabel(f"{self.sender} - {QDateTime.currentDateTime().toString('hh:mm:ss')}")
        info_label.setStyleSheet("font-size: 8pt; color: gray;")

        self.textLabel = QTextBrowser()
        self.textLabel.setOpenExternalLinks(True)
        self.textLabel.setStyleSheet("background-color: transparent;")
        self.textLabel.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
        self.textLabel.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)

        self.setMinimumWidth(self.minimum_width)
        self.setMaximumWidth(self.maximum_width)

        # Update size policy to prefer minimum space but allow expansion
        self.textLabel.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.MinimumExpanding)  # Needed?
        self.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Minimum)

        layout.addWidget(info_label)
        layout.addWidget(self.textLabel)
        layout.setSpacing(4)
        layout.setContentsMargins(10, 5, 10, 5)

        if self.loading:
            # Setup for loading animation
            self.loadingLabel = QLabel(self)
            decompressed_data = brotli.decompress(LOADING_ANIM)

            # Create a QBuffer from the decompressed data
            buffer = QBuffer()
            buffer.setData(QByteArray(decompressed_data))
            buffer.open(QBuffer.ReadOnly)

            # Use the buffer with QMovie
            self.loadingAnimation = QMovie()
            self.loadingAnimation.setCacheMode(QMovie.CacheMode.CacheAll)
            self.loadingAnimation.setDevice(buffer)
            self.loadingAnimation.setScaledSize(QSize(128, 128))
            self.loadingLabel.setMovie(self.loadingAnimation)
            self.loadingLabel.setFixedSize(QSize(120, 80))
            layout.addStretch()
            layout.addWidget(self.loadingLabel, alignment=Qt.AlignmentFlag.AlignCenter)  # Center horizontally
            layout.addStretch()
            self.loadingAnimation.start()

        if self.is_user:
            layout.setAlignment(Qt.AlignmentFlag.AlignRight)
            self.setStyleSheet("background-color: lightgreen; border-radius: 10px; border-bottom-right-radius: 0px;")
            self.textLabel.setAlignment(Qt.AlignmentFlag.AlignRight)
            info_label.setAlignment(Qt.AlignmentFlag.AlignRight)
        else:
            layout.setAlignment(Qt.AlignmentFlag.AlignLeft)
            self.setStyleSheet("background-color: lightblue; border-radius: 10px; border-bottom-left-radius: 0px;")
            self.textLabel.setAlignment(Qt.AlignmentFlag.AlignLeft)
            info_label.setAlignment(Qt.AlignmentFlag.AlignLeft)
        self.setLayout(layout)

    def update_content(self, new_text):
        # Call this method to update text and stop loading animation
        self.text = new_text
        self.update_text(self.text)
        self.loadingAnimation.stop()
        self.loadingLabel.hide()
        self.layout().removeWidget(self.loadingLabel)
        self.loadingLabel.deleteLater()

    def resizeEvent(self, event: QResizeEvent) -> None:
        self.update_text(self.text)
        parent = self.parent()
        while parent.parent() is not None:
            if isinstance(parent, QScrollArea):
                break
            parent = parent.parent()
        if parent is not None:
            offset_width = parent.viewport().width() - self.width_offset
            self.setMinimumWidth(min(offset_width, self.minimum_width))
            self.setMaximumWidth(min(offset_width, self.maximum_width))
        return super().resizeEvent(event)


class ChatArea(QScrollArea):
    def __init__(self, parent=None):
        super().__init__(parent=parent)
        self.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOn)
        self.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
        self.setWidgetResizable(True)

        self.content = QWidget()
        self.layout = QVBoxLayout()
        self.layout.setAlignment(Qt.AlignmentFlag.AlignTop)
        self.layout.addStretch(1)
        self.content.setLayout(self.layout)
        self.setWidget(self.content)

        self.messages = []

    def send_chat_message(self, text: str = "", sender: str = "", is_user: bool = True,
                          is_loading: bool = False) -> ChatBubble:
        bubble = ChatBubble(text, sender, is_user, loading=is_loading)
        self.update_conversation(bubble)
        self.messages.append(bubble)
        return bubble

    def send_chat_messages(self, texts: list, senders: list, is_user_list: list, is_loading_list: list) -> list:
        num = len(texts) + len(senders) + len(is_user_list) + len(is_loading_list) // 4
        return_lst = []
        for i in range(num):
            bubble = self.send_chat_message(texts[i], senders[i], is_user_list[i], is_loading_list[i])
            return_lst.append(bubble)
        return return_lst

    def update_conversation(self, chat_bubble: Union[ChatBubble, MDChatBubble]) -> Union[QWidget, QHBoxLayout]:
        # Create a horizontal layout to control the side alignment
        bubble_layout = QHBoxLayout()
        bubble_layout.addWidget(chat_bubble)
        # bubble_layout.setContentsMargins(0, 0, 0, 0)

        if chat_bubble.is_user:
            bubble_layout.insertStretch(0, 1)  # Add stretch to right to push bubble left
            bubble_layout.setContentsMargins(20, 0, 0, 0)  # Left margin
        else:
            bubble_layout.addStretch()  # Add stretch to left to push bubble right
            bubble_layout.setContentsMargins(0, 0, 20, 0)  # Right margin

        # Create a wrapper widget to hold the layout
        wrapper_widget = QWidget()
        wrapper_widget.setLayout(bubble_layout)
        self.layout.addWidget(wrapper_widget)

        return wrapper_widget

    def get_all_messages(self):
        return self.messages

    def get_all_messages_from_sender(self, sender: str) -> list:
        return_lst = []
        for bubble in self.messages:
            if bubble.sender == sender:
                return_lst.append(bubble)
        return return_lst

    def get_all_messages_from_senders(self, senders: list) -> dict:
        return_dict = {sender: [] for sender in senders}
        for bubble in self.messages:
            if bubble.sender in senders:
                return_dict[bubble.sender].append(bubble)
        return return_dict

    def resizeEvent(self, event: QResizeEvent):
        super().resizeEvent(event)
        for bubble in self.messages:
            bubble.resizeEvent(event)


def local_test():
    from PySide6.QtWidgets import QMainWindow, QApplication, QPushButton
    import sys
    class ChatTestWindow(QMainWindow):
        def __init__(self):
            super().__init__()

            self.setWindowTitle("Chat Test")
            self.setGeometry(100, 100, 400, 600)

            self.chat_area = ChatArea(self)

            test_button = QPushButton("Add Test Message", self)
            test_button.clicked.connect(self.add_test_message)

            layout = QVBoxLayout()
            layout.addWidget(self.chat_area)
            layout.addWidget(test_button)

            container = QWidget()
            container.setLayout(layout)
            self.setCentralWidget(container)

        def add_test_message(self):
            # Add a test message to the chat area
            self.chat_area.send_chat_message("Hello, this is a test message!" * 30, "User", True, False)
            bubble = self.chat_area.send_chat_message("", "User2", False, True)
            import time
            time.sleep(3)
            bubble.update_content("HELL")

    app = QApplication(sys.argv)
    main_win = ChatTestWindow()
    main_win.show()
    sys.exit(app.exec_())


if __name__ == '__main__':
    local_test()
